athena_get_session: Gets the full details of a previously created session,...

View source: R/athena_operations.R

athena_get_sessionR Documentation

Gets the full details of a previously created session, including the session status and configuration

Description

Gets the full details of a previously created session, including the session status and configuration.

See https://www.paws-r-sdk.com/docs/athena_get_session/ for full documentation.

Usage

athena_get_session(SessionId)

Arguments

SessionId

[required] The session ID.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.