athena_get_session_endpoint: Gets a connection endpoint and authentication token for a...

View source: R/athena_operations.R

athena_get_session_endpointR Documentation

Gets a connection endpoint and authentication token for a given session Id

Description

Gets a connection endpoint and authentication token for a given session Id.

See https://www.paws-r-sdk.com/docs/athena_get_session_endpoint/ for full documentation.

Usage

athena_get_session_endpoint(SessionId)

Arguments

SessionId

[required] The session ID.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.