athena_get_work_group: Returns information about the workgroup with the specified...

View source: R/athena_operations.R

athena_get_work_groupR Documentation

Returns information about the workgroup with the specified name

Description

Returns information about the workgroup with the specified name.

See https://www.paws-r-sdk.com/docs/athena_get_work_group/ for full documentation.

Usage

athena_get_work_group(WorkGroup)

Arguments

WorkGroup

[required] The name of the workgroup.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.