cloudsearch_build_suggesters: Indexes the search suggestions

View source: R/cloudsearch_operations.R

cloudsearch_build_suggestersR Documentation

Indexes the search suggestions

Description

Indexes the search suggestions. For more information, see Configuring Suggesters in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_build_suggesters/ for full documentation.

Usage

cloudsearch_build_suggesters(DomainName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).


paws.analytics documentation built on May 30, 2026, 9:16 a.m.