cloudsearch_define_analysis_scheme: Configures an analysis scheme that can be applied to a text...

View source: R/cloudsearch_operations.R

cloudsearch_define_analysis_schemeR Documentation

Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options

Description

Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_define_analysis_scheme/ for full documentation.

Usage

cloudsearch_define_analysis_scheme(DomainName, AnalysisScheme)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

AnalysisScheme

[required] Configuration information for an analysis scheme. Each analysis scheme has a unique name and specifies the language of the text to be processed. The following options can be configured for an analysis scheme: Synonyms, Stopwords, StemmingDictionary, JapaneseTokenizationDictionary and AlgorithmicStemming.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.