cloudsearch_define_expression: Configures an Expression for the search domain

View source: R/cloudsearch_operations.R

cloudsearch_define_expressionR Documentation

Configures an Expression for the search domain

Description

Configures an Expression for the search domain. Used to create new expressions and modify existing ones. If the expression exists, the new configuration replaces the old one. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_define_expression/ for full documentation.

Usage

cloudsearch_define_expression(DomainName, Expression)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

Expression

[required] A named expression that can be evaluated at search time. Can be used to sort the search results, define other expressions, or return computed information in the search results.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.