cloudsearch_define_suggester: Configures a suggester for a domain

View source: R/cloudsearch_operations.R

cloudsearch_define_suggesterR Documentation

Configures a suggester for a domain

Description

Configures a suggester for a domain. A suggester enables you to display possible matches before users finish typing their queries. When you configure a suggester, you must specify the name of the text field you want to search for possible matches and a unique name for the suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_define_suggester/ for full documentation.

Usage

cloudsearch_define_suggester(DomainName, Suggester)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

Suggester

[required] Configuration information for a search suggester. Each suggester has a unique name and specifies the text field you want to use for suggestions. The following options can be configured for a suggester: FuzzyMatching, SortExpression.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.