cloudsearch_delete_analysis_scheme: Deletes an analysis scheme

View source: R/cloudsearch_operations.R

cloudsearch_delete_analysis_schemeR Documentation

Deletes an analysis scheme

Description

Deletes an analysis scheme. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_delete_analysis_scheme/ for full documentation.

Usage

cloudsearch_delete_analysis_scheme(DomainName, AnalysisSchemeName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

AnalysisSchemeName

[required] The name of the analysis scheme you want to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.