cloudsearch_delete_expression: Removes an Expression from the search domain

View source: R/cloudsearch_operations.R

cloudsearch_delete_expressionR Documentation

Removes an Expression from the search domain

Description

Removes an Expression from the search domain. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_delete_expression/ for full documentation.

Usage

cloudsearch_delete_expression(DomainName, ExpressionName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

ExpressionName

[required] The name of the Expression to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.