cloudsearch_delete_index_field: Removes an IndexField from the search domain

View source: R/cloudsearch_operations.R

cloudsearch_delete_index_fieldR Documentation

Removes an IndexField from the search domain

Description

Removes an IndexField from the search domain. For more information, see Configuring Index Fields in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_delete_index_field/ for full documentation.

Usage

cloudsearch_delete_index_field(DomainName, IndexFieldName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

IndexFieldName

[required] The name of the index field your want to remove from the domain's indexing options.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.