cloudsearch_delete_suggester: Deletes a suggester

View source: R/cloudsearch_operations.R

cloudsearch_delete_suggesterR Documentation

Deletes a suggester

Description

Deletes a suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_delete_suggester/ for full documentation.

Usage

cloudsearch_delete_suggester(DomainName, SuggesterName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

SuggesterName

[required] Specifies the name of the suggester you want to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.