cloudsearch_describe_scaling_parameters: Gets the scaling parameters configured for a domain

View source: R/cloudsearch_operations.R

cloudsearch_describe_scaling_parametersR Documentation

Gets the scaling parameters configured for a domain

Description

Gets the scaling parameters configured for a domain. A domain's scaling parameters specify the desired search instance type and replication count. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_describe_scaling_parameters/ for full documentation.

Usage

cloudsearch_describe_scaling_parameters(DomainName)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).


paws.analytics documentation built on May 30, 2026, 9:16 a.m.