cloudsearch_update_availability_options: Configures the availability options for a domain

View source: R/cloudsearch_operations.R

cloudsearch_update_availability_optionsR Documentation

Configures the availability options for a domain

Description

Configures the availability options for a domain. Enabling the Multi-AZ option expands an Amazon CloudSearch domain to an additional Availability Zone in the same Region to increase fault tolerance in the event of a service disruption. Changes to the Multi-AZ option can take about half an hour to become active. For more information, see Configuring Availability Options in the Amazon CloudSearch Developer Guide.

See https://www.paws-r-sdk.com/docs/cloudsearch_update_availability_options/ for full documentation.

Usage

cloudsearch_update_availability_options(DomainName, MultiAZ)

Arguments

DomainName

[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

MultiAZ

[required] You expand an existing search domain to a second Availability Zone by setting the Multi-AZ option to true. Similarly, you can turn off the Multi-AZ option to downgrade the domain to a single Availability Zone by setting the Multi-AZ option to false.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.