View source: R/cloudsearch_operations.R
| cloudsearch_update_scaling_parameters | R Documentation |
Configures scaling parameters for a domain. A domain's scaling parameters specify the desired search instance type and replication count. Amazon CloudSearch will still automatically scale your domain based on the volume of data and traffic, but not below the desired instance type and replication count. If the Multi-AZ option is enabled, these values control the resources used per Availability Zone. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.
See https://www.paws-r-sdk.com/docs/cloudsearch_update_scaling_parameters/ for full documentation.
cloudsearch_update_scaling_parameters(DomainName, ScalingParameters)
DomainName |
[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
ScalingParameters |
[required] The desired instance type and desired number of replicas of each index partition. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.