datapipeline_evaluate_expression: Task runners call EvaluateExpression to evaluate a string in...

View source: R/datapipeline_operations.R

datapipeline_evaluate_expressionR Documentation

Task runners call EvaluateExpression to evaluate a string in the context of the specified object

Description

Task runners call evaluate_expression to evaluate a string in the context of the specified object. For example, a task runner can evaluate SQL queries stored in Amazon S3.

See https://www.paws-r-sdk.com/docs/datapipeline_evaluate_expression/ for full documentation.

Usage

datapipeline_evaluate_expression(pipelineId, objectId, expression)

Arguments

pipelineId

[required] The ID of the pipeline.

objectId

[required] The ID of the object.

expression

[required] The expression to evaluate.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.