datazone_accept_subscription_request: Accepts a subscription request to a specific asset

View source: R/datazone_operations.R

datazone_accept_subscription_requestR Documentation

Accepts a subscription request to a specific asset

Description

Accepts a subscription request to a specific asset.

See https://www.paws-r-sdk.com/docs/datazone_accept_subscription_request/ for full documentation.

Usage

datazone_accept_subscription_request(
  domainIdentifier,
  identifier,
  decisionComment = NULL,
  assetScopes = NULL,
  assetPermissions = NULL
)

Arguments

domainIdentifier

[required] The Amazon DataZone domain where the specified subscription request is being accepted.

identifier

[required] The unique identifier of the subscription request that is to be accepted.

decisionComment

A description that specifies the reason for accepting the specified subscription request.

assetScopes

The asset scopes of the accept subscription request.

assetPermissions

The asset permissions of the accept subscription request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.