datazone_associate_governed_terms: Associates governed terms with an asset

View source: R/datazone_operations.R

datazone_associate_governed_termsR Documentation

Associates governed terms with an asset

Description

Associates governed terms with an asset.

See https://www.paws-r-sdk.com/docs/datazone_associate_governed_terms/ for full documentation.

Usage

datazone_associate_governed_terms(
  domainIdentifier,
  entityIdentifier,
  entityType,
  governedGlossaryTerms
)

Arguments

domainIdentifier

[required] The ID of the domain where governed terms are to be associated with an asset.

entityIdentifier

[required] The ID of the asset with which you want to associate a governed term.

entityType

[required] The type of the asset with which you want to associate a governed term.

governedGlossaryTerms

[required] The glossary terms in a restricted glossary.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.