datazone_batch_get_attributes_metadata: Gets the attribute metadata

View source: R/datazone_operations.R

datazone_batch_get_attributes_metadataR Documentation

Gets the attribute metadata

Description

Gets the attribute metadata.

See https://www.paws-r-sdk.com/docs/datazone_batch_get_attributes_metadata/ for full documentation.

Usage

datazone_batch_get_attributes_metadata(
  domainIdentifier,
  entityType,
  entityIdentifier,
  entityRevision = NULL,
  attributeIdentifiers
)

Arguments

domainIdentifier

[required] The domain ID where you want to get the attribute metadata.

entityType

[required] The entity type for which you want to get attribute metadata.

entityIdentifier

[required] The entity ID for which you want to get attribute metadata.

entityRevision

The entity revision for which you want to get attribute metadata.

attributeIdentifiers

[required] The attribute identifier.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.