datazone_batch_put_attributes_metadata: Writes the attribute metadata

View source: R/datazone_operations.R

datazone_batch_put_attributes_metadataR Documentation

Writes the attribute metadata

Description

Writes the attribute metadata.

See https://www.paws-r-sdk.com/docs/datazone_batch_put_attributes_metadata/ for full documentation.

Usage

datazone_batch_put_attributes_metadata(
  domainIdentifier,
  entityType,
  entityIdentifier,
  clientToken = NULL,
  attributes
)

Arguments

domainIdentifier

[required] The domain ID where you want to write the attribute metadata.

entityType

[required] The entity type for which you want to write the attribute metadata.

entityIdentifier

[required] The entity ID for which you want to write the attribute metadata.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

attributes

[required] The attributes of the metadata.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.