datazone_create_account_pool: Creates an account pool

View source: R/datazone_operations.R

datazone_create_account_poolR Documentation

Creates an account pool

Description

Creates an account pool.

See https://www.paws-r-sdk.com/docs/datazone_create_account_pool/ for full documentation.

Usage

datazone_create_account_pool(
  domainIdentifier,
  name,
  description = NULL,
  resolutionStrategy,
  accountSource
)

Arguments

domainIdentifier

[required] The ID of the domain where the account pool is created.

name

[required] The name of the account pool.

description

The description of the account pool.

resolutionStrategy

[required] The mechanism used to resolve the account selection from the account pool.

accountSource

[required] The source of accounts for the account pool. In the current release, it's either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.