datazone_create_asset: Creates an asset in Amazon DataZone catalog

View source: R/datazone_operations.R

datazone_create_assetR Documentation

Creates an asset in Amazon DataZone catalog

Description

Creates an asset in Amazon DataZone catalog.

See https://www.paws-r-sdk.com/docs/datazone_create_asset/ for full documentation.

Usage

datazone_create_asset(
  name,
  domainIdentifier,
  externalIdentifier = NULL,
  typeIdentifier,
  typeRevision = NULL,
  description = NULL,
  glossaryTerms = NULL,
  formsInput = NULL,
  owningProjectIdentifier,
  predictionConfiguration = NULL,
  clientToken = NULL
)

Arguments

name

[required] Asset name.

domainIdentifier

[required] Amazon DataZone domain where the asset is created.

externalIdentifier

The external identifier of the asset.

If the value for the externalIdentifier parameter is specified, it must be a unique value.

typeIdentifier

[required] The unique identifier of this asset's type.

typeRevision

The revision of this asset's type.

description

Asset description.

glossaryTerms

Glossary terms attached to the asset.

formsInput

Metadata forms attached to the asset.

owningProjectIdentifier

[required] The unique identifier of the project that owns this asset.

predictionConfiguration

The configuration of the automatically generated business-friendly metadata for the asset.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.