datazone_create_asset_type: Creates a custom asset type

View source: R/datazone_operations.R

datazone_create_asset_typeR Documentation

Creates a custom asset type

Description

Creates a custom asset type.

See https://www.paws-r-sdk.com/docs/datazone_create_asset_type/ for full documentation.

Usage

datazone_create_asset_type(
  domainIdentifier,
  name,
  description = NULL,
  formsInput,
  owningProjectIdentifier
)

Arguments

domainIdentifier

[required] The unique identifier of the Amazon DataZone domain where the custom asset type is being created.

name

[required] The name of the custom asset type.

description

The descripton of the custom asset type.

formsInput

[required] The metadata forms that are to be attached to the custom asset type.

owningProjectIdentifier

[required] The identifier of the Amazon DataZone project that is to own the custom asset type.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.