View source: R/datazone_operations.R
| datazone_create_connection | R Documentation |
Creates a new connection. In Amazon DataZone, a connection enables you to connect your resources (domains, projects, and environments) to external resources and services.
See https://www.paws-r-sdk.com/docs/datazone_create_connection/ for full documentation.
datazone_create_connection(
awsLocation = NULL,
clientToken = NULL,
configurations = NULL,
description = NULL,
domainIdentifier,
environmentIdentifier = NULL,
name,
props = NULL,
enableTrustedIdentityPropagation = NULL,
scope = NULL
)
awsLocation |
The location where the connection is created. |
clientToken |
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request. |
configurations |
The configurations of the connection. |
description |
A connection description. |
domainIdentifier |
[required] The ID of the domain where the connection is created. |
environmentIdentifier |
The ID of the environment where the connection is created. |
name |
[required] The connection name. |
props |
The connection props. |
enableTrustedIdentityPropagation |
Specifies whether the trusted identity propagation is enabled. |
scope |
The scope of the connection. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.