datazone_create_data_product: Creates a data product

View source: R/datazone_operations.R

datazone_create_data_productR Documentation

Creates a data product

Description

Creates a data product.

See https://www.paws-r-sdk.com/docs/datazone_create_data_product/ for full documentation.

Usage

datazone_create_data_product(
  domainIdentifier,
  name,
  owningProjectIdentifier,
  description = NULL,
  glossaryTerms = NULL,
  formsInput = NULL,
  items = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where the data product is created.

name

[required] The name of the data product.

owningProjectIdentifier

[required] The ID of the owning project of the data product.

description

The description of the data product.

glossaryTerms

The glossary terms of the data product.

formsInput

The metadata forms of the data product.

items

The data assets of the data product.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.