datazone_create_data_product_revision: Creates a data product revision

View source: R/datazone_operations.R

datazone_create_data_product_revisionR Documentation

Creates a data product revision

Description

Creates a data product revision.

See https://www.paws-r-sdk.com/docs/datazone_create_data_product_revision/ for full documentation.

Usage

datazone_create_data_product_revision(
  domainIdentifier,
  identifier,
  name,
  description = NULL,
  glossaryTerms = NULL,
  items = NULL,
  formsInput = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where the data product revision is created.

identifier

[required] The ID of the data product revision.

name

[required] The name of the data product revision.

description

The description of the data product revision.

glossaryTerms

The glossary terms of the data product revision.

items

The data assets of the data product revision.

formsInput

The metadata forms of the data product revision.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.