datazone_create_domain_unit: Creates a domain unit in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_domain_unitR Documentation

Creates a domain unit in Amazon DataZone

Description

Creates a domain unit in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_domain_unit/ for full documentation.

Usage

datazone_create_domain_unit(
  domainIdentifier,
  name,
  parentDomainUnitIdentifier,
  description = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where you want to crate a domain unit.

name

[required] The name of the domain unit.

parentDomainUnitIdentifier

[required] The ID of the parent domain unit.

description

The description of the domain unit.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.