View source: R/datazone_operations.R
| datazone_create_environment | R Documentation |
Create an Amazon DataZone environment.
See https://www.paws-r-sdk.com/docs/datazone_create_environment/ for full documentation.
datazone_create_environment(
projectIdentifier,
domainIdentifier,
description = NULL,
name,
environmentProfileIdentifier = NULL,
userParameters = NULL,
glossaryTerms = NULL,
environmentAccountIdentifier = NULL,
environmentAccountRegion = NULL,
environmentBlueprintIdentifier = NULL,
deploymentOrder = NULL,
environmentConfigurationId = NULL,
environmentConfigurationName = NULL
)
projectIdentifier |
[required] The identifier of the Amazon DataZone project in which this environment is created. |
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which the environment is created. |
description |
The description of the Amazon DataZone environment. |
name |
[required] The name of the Amazon DataZone environment. |
environmentProfileIdentifier |
The identifier of the environment profile that is used to create this Amazon DataZone environment. |
userParameters |
The user parameters of this Amazon DataZone environment. |
glossaryTerms |
The glossary terms that can be used in this Amazon DataZone environment. |
environmentAccountIdentifier |
The ID of the account in which the environment is being created. |
environmentAccountRegion |
The region of the account in which the environment is being created. |
environmentBlueprintIdentifier |
The ID of the blueprint with which the environment is being created. |
deploymentOrder |
The deployment order of the environment. |
environmentConfigurationId |
The configuration ID of the environment. |
environmentConfigurationName |
The configuration name of the environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.