datazone_create_glossary: Creates an Amazon DataZone business glossary

View source: R/datazone_operations.R

datazone_create_glossaryR Documentation

Creates an Amazon DataZone business glossary

Description

Creates an Amazon DataZone business glossary.

See https://www.paws-r-sdk.com/docs/datazone_create_glossary/ for full documentation.

Usage

datazone_create_glossary(
  domainIdentifier,
  name,
  owningProjectIdentifier,
  description = NULL,
  status = NULL,
  usageRestrictions = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which this business glossary is created.

name

[required] The name of this business glossary.

owningProjectIdentifier

[required] The ID of the project that currently owns business glossary.

description

The description of this business glossary.

status

The status of this business glossary.

usageRestrictions

The usage restriction of the restricted glossary.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.