datazone_create_group_profile: Creates a group profile in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_group_profileR Documentation

Creates a group profile in Amazon DataZone

Description

Creates a group profile in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_group_profile/ for full documentation.

Usage

datazone_create_group_profile(
  domainIdentifier,
  groupIdentifier = NULL,
  rolePrincipalArn = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which the group profile is created.

groupIdentifier

The identifier of the group for which the group profile is created.

rolePrincipalArn

The ARN of the IAM role that will be associated with the group profile. This role defines the permissions that group members will assume when accessing Amazon DataZone resources.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.