View source: R/datazone_operations.R
| datazone_create_notebook | R Documentation |
Creates a notebook in Amazon SageMaker Unified Studio. A notebook is a collaborative document within a project that contains code cells for interactive computing.
See https://www.paws-r-sdk.com/docs/datazone_create_notebook/ for full documentation.
datazone_create_notebook(
domainIdentifier,
owningProjectIdentifier,
name,
description = NULL,
metadata = NULL,
parameters = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook. |
owningProjectIdentifier |
[required] The identifier of the project that owns the notebook. |
name |
[required] The name of the notebook. The name must be between 1 and 256 characters. |
description |
The description of the notebook. |
metadata |
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters. |
parameters |
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.