View source: R/datazone_operations.R
| datazone_create_project | R Documentation |
Creates an Amazon DataZone project.
See https://www.paws-r-sdk.com/docs/datazone_create_project/ for full documentation.
datazone_create_project(
domainIdentifier,
name,
description = NULL,
resourceTags = NULL,
glossaryTerms = NULL,
domainUnitId = NULL,
projectProfileId = NULL,
userParameters = NULL,
projectCategory = NULL,
projectExecutionRole = NULL,
membershipAssignments = NULL
)
domainIdentifier |
[required] The ID of the Amazon DataZone domain in which this project is created. |
name |
[required] The name of the Amazon DataZone project. |
description |
The description of the Amazon DataZone project. |
resourceTags |
The resource tags of the project. |
glossaryTerms |
The glossary terms that can be used in this Amazon DataZone project. |
domainUnitId |
The ID of the domain unit. This parameter is not required and if it is not specified, then the project is created at the root domain unit level. |
projectProfileId |
The ID of the project profile. |
userParameters |
The user parameters of the project. |
projectCategory |
The category of the project. Set to 'ADMIN' designates this as an administrative project for the Amazon DataZone domain. |
projectExecutionRole |
The default project IAM role that is used to access project resources and run computes such as Glue and Sagemaker. |
membershipAssignments |
The members to be assigned to the project. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.