datazone_create_subscription_grant: Creates a subsscription grant in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_subscription_grantR Documentation

Creates a subsscription grant in Amazon DataZone

Description

Creates a subsscription grant in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_subscription_grant/ for full documentation.

Usage

datazone_create_subscription_grant(
  domainIdentifier,
  environmentIdentifier,
  subscriptionTargetIdentifier = NULL,
  grantedEntity,
  assetTargetNames = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which the subscription grant is created.

environmentIdentifier

[required] The ID of the environment in which the subscription grant is created.

subscriptionTargetIdentifier

The ID of the subscription target for which the subscription grant is created.

grantedEntity

[required] The entity to which the subscription is to be granted.

assetTargetNames

The names of the assets for which the subscription grant is created.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.