datazone_create_subscription_request: Creates a subscription request in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_subscription_requestR Documentation

Creates a subscription request in Amazon DataZone

Description

Creates a subscription request in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_subscription_request/ for full documentation.

Usage

datazone_create_subscription_request(
  domainIdentifier,
  subscribedPrincipals,
  subscribedListings,
  requestReason,
  clientToken = NULL,
  metadataForms = NULL,
  assetPermissions = NULL,
  assetScopes = NULL
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which the subscription request is created.

subscribedPrincipals

[required] The Amazon DataZone principals for whom the subscription request is created.

subscribedListings

[required] The published asset for which the subscription grant is to be created.

requestReason

[required] The reason for the subscription request.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

metadataForms

The metadata form included in the subscription request.

assetPermissions

The asset permissions of the subscription request.

assetScopes

The asset scopes of the subscription request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.