datazone_create_subscription_target: Creates a subscription target in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_subscription_targetR Documentation

Creates a subscription target in Amazon DataZone

Description

Creates a subscription target in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_subscription_target/ for full documentation.

Usage

datazone_create_subscription_target(
  domainIdentifier,
  environmentIdentifier,
  name,
  type,
  subscriptionTargetConfig,
  authorizedPrincipals,
  manageAccessRole,
  applicableAssetTypes,
  provider = NULL,
  clientToken = NULL,
  subscriptionGrantCreationMode = NULL
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which subscription target is created.

environmentIdentifier

[required] The ID of the environment in which subscription target is created.

name

[required] The name of the subscription target.

type

[required] The type of the subscription target.

subscriptionTargetConfig

[required] The configuration of the subscription target.

authorizedPrincipals

[required] The authorized principals of the subscription target.

manageAccessRole

[required] The manage access role that is used to create the subscription target.

applicableAssetTypes

[required] The asset types that can be included in the subscription target.

provider

The provider of the subscription target.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

subscriptionGrantCreationMode

Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.