datazone_create_user_profile: Creates a user profile in Amazon DataZone

View source: R/datazone_operations.R

datazone_create_user_profileR Documentation

Creates a user profile in Amazon DataZone

Description

Creates a user profile in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_create_user_profile/ for full documentation.

Usage

datazone_create_user_profile(
  domainIdentifier,
  userIdentifier,
  userType = NULL,
  sessionName = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which a user profile is created.

userIdentifier

[required] The identifier of the user for which the user profile is created.

userType

The user type of the user for which the user profile is created.

sessionName

The session name for IAM role sessions.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.