View source: R/datazone_operations.R
| datazone_delete_asset_filter | R Documentation |
Deletes an asset filter.
See https://www.paws-r-sdk.com/docs/datazone_delete_asset_filter/ for full documentation.
datazone_delete_asset_filter(domainIdentifier, assetIdentifier, identifier)
domainIdentifier |
[required] The ID of the domain where you want to delete an asset filter. |
assetIdentifier |
[required] The ID of the data asset. |
identifier |
[required] The ID of the asset filter that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.