datazone_delete_asset_type: Deletes an asset type in Amazon DataZone

View source: R/datazone_operations.R

datazone_delete_asset_typeR Documentation

Deletes an asset type in Amazon DataZone

Description

Deletes an asset type in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_delete_asset_type/ for full documentation.

Usage

datazone_delete_asset_type(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which the asset type is deleted.

identifier

[required] The identifier of the asset type that is deleted.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.