datazone_delete_domain: Deletes a Amazon DataZone domain

View source: R/datazone_operations.R

datazone_delete_domainR Documentation

Deletes a Amazon DataZone domain

Description

Deletes a Amazon DataZone domain.

See https://www.paws-r-sdk.com/docs/datazone_delete_domain/ for full documentation.

Usage

datazone_delete_domain(
  identifier,
  clientToken = NULL,
  skipDeletionCheck = NULL
)

Arguments

identifier

[required] The identifier of the Amazon Web Services domain that is to be deleted.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

skipDeletionCheck

Specifies the optional flag to delete all child entities within the domain.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.