datazone_delete_domain_unit: Deletes a domain unit

View source: R/datazone_operations.R

datazone_delete_domain_unitR Documentation

Deletes a domain unit

Description

Deletes a domain unit.

See https://www.paws-r-sdk.com/docs/datazone_delete_domain_unit/ for full documentation.

Usage

datazone_delete_domain_unit(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The ID of the domain where you want to delete a domain unit.

identifier

[required] The ID of the domain unit that you want to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.