datazone_delete_form_type: Deletes and metadata form type in Amazon DataZone

View source: R/datazone_operations.R

datazone_delete_form_typeR Documentation

Deletes and metadata form type in Amazon DataZone

Description

Deletes and metadata form type in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_delete_form_type/ for full documentation.

Usage

datazone_delete_form_type(domainIdentifier, formTypeIdentifier)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which the metadata form type is deleted.

formTypeIdentifier

[required] The ID of the metadata form type that is deleted.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.