datazone_delete_project: Deletes a project in Amazon DataZone

View source: R/datazone_operations.R

datazone_delete_projectR Documentation

Deletes a project in Amazon DataZone

Description

Deletes a project in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_delete_project/ for full documentation.

Usage

datazone_delete_project(domainIdentifier, identifier, skipDeletionCheck = NULL)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which the project is deleted.

identifier

[required] The identifier of the project that is to be deleted.

skipDeletionCheck

Specifies the optional flag to delete all child entities within the project.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.