datazone_disassociate_governed_terms: Disassociates restricted terms from an asset

View source: R/datazone_operations.R

datazone_disassociate_governed_termsR Documentation

Disassociates restricted terms from an asset

Description

Disassociates restricted terms from an asset.

See https://www.paws-r-sdk.com/docs/datazone_disassociate_governed_terms/ for full documentation.

Usage

datazone_disassociate_governed_terms(
  domainIdentifier,
  entityIdentifier,
  entityType,
  governedGlossaryTerms
)

Arguments

domainIdentifier

[required] The ID of the domain where you want to disassociate restricted terms from an asset.

entityIdentifier

[required] The ID of an asset from which you want to disassociate restricted terms.

entityType

[required] The type of the asset from which you want to disassociate restricted terms.

governedGlossaryTerms

[required] The restricted glossary terms that you want to disassociate from an asset.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.