datazone_get_account_pool: Gets the details of the account pool

View source: R/datazone_operations.R

datazone_get_account_poolR Documentation

Gets the details of the account pool

Description

Gets the details of the account pool.

See https://www.paws-r-sdk.com/docs/datazone_get_account_pool/ for full documentation.

Usage

datazone_get_account_pool(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The ID of the domain in which the account pool lives whose details are to be displayed.

identifier

[required] The ID of the account pool whose details are to be displayed.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.