datazone_get_notebook: Gets the details of a notebook in Amazon SageMaker Unified...

View source: R/datazone_operations.R

datazone_get_notebookR Documentation

Gets the details of a notebook in Amazon SageMaker Unified Studio

Description

Gets the details of a notebook in Amazon SageMaker Unified Studio.

See https://www.paws-r-sdk.com/docs/datazone_get_notebook/ for full documentation.

Usage

datazone_get_notebook(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.

identifier

[required] The identifier of the notebook.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.