datazone_get_notebook_export: Gets the details of a notebook export in Amazon SageMaker...

View source: R/datazone_operations.R

datazone_get_notebook_exportR Documentation

Gets the details of a notebook export in Amazon SageMaker Unified Studio

Description

Gets the details of a notebook export in Amazon SageMaker Unified Studio.

See https://www.paws-r-sdk.com/docs/datazone_get_notebook_export/ for full documentation.

Usage

datazone_get_notebook_export(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook export exists.

identifier

[required] The identifier of the notebook export.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.