datazone_get_notebook_run: Gets the details of a notebook run in Amazon SageMaker...

View source: R/datazone_operations.R

datazone_get_notebook_runR Documentation

Gets the details of a notebook run in Amazon SageMaker Unified Studio

Description

Gets the details of a notebook run in Amazon SageMaker Unified Studio.

See https://www.paws-r-sdk.com/docs/datazone_get_notebook_run/ for full documentation.

Usage

datazone_get_notebook_run(domainIdentifier, identifier)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run exists.

identifier

[required] The identifier of the notebook run.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.