datazone_get_user_profile: Gets a user profile in Amazon DataZone

View source: R/datazone_operations.R

datazone_get_user_profileR Documentation

Gets a user profile in Amazon DataZone

Description

Gets a user profile in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_get_user_profile/ for full documentation.

Usage

datazone_get_user_profile(
  domainIdentifier,
  userIdentifier,
  type = NULL,
  sessionName = NULL
)

Arguments

domainIdentifier

[required] the ID of the Amazon DataZone domain the data portal of which you want to get.

userIdentifier

[required] The identifier of the user for which you want to get the user profile.

type

The type of the user profile.

sessionName

The session name for IAM role sessions.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.