View source: R/datazone_operations.R
| datazone_list_account_pools | R Documentation |
Lists existing account pools.
See https://www.paws-r-sdk.com/docs/datazone_list_account_pools/ for full documentation.
datazone_list_account_pools(
domainIdentifier,
name = NULL,
sortBy = NULL,
sortOrder = NULL,
nextToken = NULL,
maxResults = NULL
)
domainIdentifier |
[required] The ID of the domain where exsting account pools are to be listed. |
name |
The name of the account pool to be listed. |
sortBy |
The sort by mechanism in which the existing account pools are to be listed. |
sortOrder |
The sort order in which the existing account pools are to be listed. |
nextToken |
When the number of account pools is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of account pools, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListAccountPools to list the next set of account pools. |
maxResults |
The maximum number of account pools to return in a single call to ListAccountPools. When the number of account pools to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListAccountPools to list the next set of account pools. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.