View source: R/datazone_operations.R
| datazone_list_accounts_in_account_pool | R Documentation |
Lists the accounts in the specified account pool.
See https://www.paws-r-sdk.com/docs/datazone_list_accounts_in_account_pool/ for full documentation.
datazone_list_accounts_in_account_pool(
domainIdentifier,
identifier,
nextToken = NULL,
maxResults = NULL
)
domainIdentifier |
[required] The ID of the domain in which the accounts in the specified account pool are to be listed. |
identifier |
[required] The ID of the account pool whose accounts are to be listed. |
nextToken |
When the number of accounts is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of accounts, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListAccountsInAccountPool to list the next set of accounts. |
maxResults |
The maximum number of accounts to return in a single call to ListAccountsInAccountPool. When the number of accounts to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListAccountsInAccountPool to list the next set of accounts. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.