View source: R/datazone_operations.R
| datazone_list_data_source_run_activities | R Documentation |
Lists data source run activities.
See https://www.paws-r-sdk.com/docs/datazone_list_data_source_run_activities/ for full documentation.
datazone_list_data_source_run_activities(
domainIdentifier,
identifier,
status = NULL,
nextToken = NULL,
maxResults = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which to list data source run activities. |
identifier |
[required] The identifier of the data source run. |
status |
The status of the data source run. |
nextToken |
When the number of activities is greater than the default value for the |
maxResults |
The maximum number of activities to return in a single call to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.