datazone_list_data_source_runs: Lists data source runs in Amazon DataZone

View source: R/datazone_operations.R

datazone_list_data_source_runsR Documentation

Lists data source runs in Amazon DataZone

Description

Lists data source runs in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_list_data_source_runs/ for full documentation.

Usage

datazone_list_data_source_runs(
  domainIdentifier,
  dataSourceIdentifier,
  status = NULL,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which to invoke the list_data_source_runs action.

dataSourceIdentifier

[required] The identifier of the data source.

status

The status of the data source.

nextToken

When the number of runs is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of runs, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to list_data_source_runs to list the next set of runs.

maxResults

The maximum number of runs to return in a single call to list_data_source_runs. When the number of runs to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to list_data_source_runs to list the next set of runs.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.