View source: R/datazone_operations.R
| datazone_list_domains | R Documentation |
Lists Amazon DataZone domains.
See https://www.paws-r-sdk.com/docs/datazone_list_domains/ for full documentation.
datazone_list_domains(status = NULL, maxResults = NULL, nextToken = NULL)
status |
The status of the data source. |
maxResults |
The maximum number of domains to return in a single call to |
nextToken |
When the number of domains is greater than the default value for the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.