View source: R/datazone_operations.R
| datazone_list_environments | R Documentation |
Lists Amazon DataZone environments.
See https://www.paws-r-sdk.com/docs/datazone_list_environments/ for full documentation.
datazone_list_environments(
domainIdentifier,
awsAccountId = NULL,
status = NULL,
awsAccountRegion = NULL,
projectIdentifier,
environmentProfileIdentifier = NULL,
environmentBlueprintIdentifier = NULL,
provider = NULL,
name = NULL,
maxResults = NULL,
nextToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain. |
awsAccountId |
The identifier of the Amazon Web Services account where you want to list environments. |
status |
The status of the environments that you want to list. |
awsAccountRegion |
The Amazon Web Services region where you want to list environments. |
projectIdentifier |
[required] The identifier of the Amazon DataZone project. |
environmentProfileIdentifier |
The identifier of the environment profile. |
environmentBlueprintIdentifier |
The identifier of the Amazon DataZone blueprint. |
provider |
The provider of the environment. |
name |
The name of the environment. |
maxResults |
The maximum number of environments to return in a single call to |
nextToken |
When the number of environments is greater than the default value for the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.