View source: R/datazone_operations.R
| datazone_list_notebook_runs | R Documentation |
Lists notebook runs in Amazon SageMaker Unified Studio.
See https://www.paws-r-sdk.com/docs/datazone_list_notebook_runs/ for full documentation.
datazone_list_notebook_runs(
domainIdentifier,
owningProjectIdentifier,
notebookIdentifier = NULL,
status = NULL,
scheduleIdentifier = NULL,
maxResults = NULL,
sortOrder = NULL,
nextToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which to list notebook runs. |
owningProjectIdentifier |
[required] The identifier of the project that owns the notebook runs. |
notebookIdentifier |
The identifier of the notebook to filter runs by. |
status |
The status to filter notebook runs by. |
scheduleIdentifier |
The identifier of the schedule to filter notebook runs by. |
maxResults |
The maximum number of notebook runs to return in a single call. When the number of notebook runs exceeds the value of |
sortOrder |
The sort order for the results. |
nextToken |
When the number of notebook runs is greater than the default value for the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.