datazone_list_notebooks: Lists notebooks in Amazon SageMaker Unified Studio

View source: R/datazone_operations.R

datazone_list_notebooksR Documentation

Lists notebooks in Amazon SageMaker Unified Studio

Description

Lists notebooks in Amazon SageMaker Unified Studio.

See https://www.paws-r-sdk.com/docs/datazone_list_notebooks/ for full documentation.

Usage

datazone_list_notebooks(
  domainIdentifier,
  owningProjectIdentifier,
  maxResults = NULL,
  sortOrder = NULL,
  sortBy = NULL,
  status = NULL,
  nextToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which to list notebooks.

owningProjectIdentifier

[required] The identifier of the project that owns the notebooks.

maxResults

The maximum number of notebooks to return in a single call. When the number of notebooks exceeds the value of MaxResults, the response contains a NextToken value.

sortOrder

The sort order for the results.

sortBy

The field to sort the results by.

status

The status to filter notebooks by.

nextToken

When the number of notebooks is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of notebooks, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to list_notebooks to list the next set of notebooks.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.