Lists all members of the specified project.
See https://www.paws-r-sdk.com/docs/datazone_list_project_memberships/ for full documentation.
datazone_list_project_memberships(
domainIdentifier,
maxResults = NULL,
nextToken = NULL,
projectIdentifier,
sortBy = NULL,
sortOrder = NULL
)[required] The identifier of the Amazon DataZone domain in which you want to list project memberships.
The maximum number of memberships to return in a single call to
list_project_memberships. When
the number of memberships to be listed is greater than the value of
MaxResults, the response contains a NextToken value that you can use
in a subsequent call to
list_project_memberships to list
the next set of memberships.
When the number of memberships is greater than the default value for the
MaxResults parameter, or if you explicitly specify a value for
MaxResults that is less than the number of memberships, the response
includes a pagination token named NextToken. You can specify this
NextToken value in a subsequent call to
list_project_memberships to list
the next set of memberships.
[required] The identifier of the project whose memberships you want to list.
The method by which you want to sort the project memberships.
The sort order of the project memberships.