datazone_list_projects: Lists Amazon DataZone projects

View source: R/datazone_operations.R

datazone_list_projectsR Documentation

Lists Amazon DataZone projects

Description

Lists Amazon DataZone projects.

See https://www.paws-r-sdk.com/docs/datazone_list_projects/ for full documentation.

Usage

datazone_list_projects(
  domainIdentifier,
  userIdentifier = NULL,
  groupIdentifier = NULL,
  name = NULL,
  projectCategory = NULL,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain.

userIdentifier

The identifier of the Amazon DataZone user.

groupIdentifier

The identifier of a group.

name

The name of the project.

projectCategory

A parameter to filter projects by their category.

nextToken

When the number of projects is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of projects, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to list_projects to list the next set of projects.

maxResults

The maximum number of projects to return in a single call to list_projects. When the number of projects to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to list_projects to list the next set of projects.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.