View source: R/datazone_operations.R
| datazone_list_subscription_requests | R Documentation |
Lists Amazon DataZone subscription requests.
See https://www.paws-r-sdk.com/docs/datazone_list_subscription_requests/ for full documentation.
datazone_list_subscription_requests(
domainIdentifier,
status = NULL,
subscribedListingId = NULL,
owningProjectId = NULL,
owningIamPrincipalArn = NULL,
approverProjectId = NULL,
owningUserId = NULL,
owningGroupId = NULL,
sortBy = NULL,
sortOrder = NULL,
maxResults = NULL,
nextToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain. |
status |
Specifies the status of the subscription requests. This is not a required parameter, but if not specified, by default, Amazon DataZone returns only |
subscribedListingId |
The identifier of the subscribed listing. |
owningProjectId |
The identifier of the project for the subscription requests. |
owningIamPrincipalArn |
The ARN of the owning IAM principal. |
approverProjectId |
The identifier of the subscription request approver's project. |
owningUserId |
The ID of the owning user. |
owningGroupId |
The ID of the owning group. |
sortBy |
Specifies the way to sort the results of this action. |
sortOrder |
Specifies the sort order for the results of this action. |
maxResults |
The maximum number of subscription requests to return in a single call to |
nextToken |
When the number of subscription requests is greater than the default value for the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.