datazone_post_time_series_data_points: Posts time series data points to Amazon DataZone for the...

View source: R/datazone_operations.R

datazone_post_time_series_data_pointsR Documentation

Posts time series data points to Amazon DataZone for the specified asset

Description

Posts time series data points to Amazon DataZone for the specified asset.

See https://www.paws-r-sdk.com/docs/datazone_post_time_series_data_points/ for full documentation.

Usage

datazone_post_time_series_data_points(
  domainIdentifier,
  entityIdentifier,
  entityType,
  forms,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain in which you want to post time series data points.

entityIdentifier

[required] The ID of the asset for which you want to post time series data points.

entityType

[required] The type of the asset for which you want to post data points.

forms

[required] The forms that contain the data points that you want to post.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.