View source: R/datazone_operations.R
| datazone_put_data_export_configuration | R Documentation |
Creates data export configuration details.
See https://www.paws-r-sdk.com/docs/datazone_put_data_export_configuration/ for full documentation.
datazone_put_data_export_configuration(
domainIdentifier,
enableExport,
encryptionConfiguration = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The domain ID for which you want to create data export configuration details. |
enableExport |
[required] Specifies that the export is to be enabled as part of creating data export configuration details. |
encryptionConfiguration |
The encryption configuration as part of creating data export configuration details. The KMS key provided here as part of encryptionConfiguration must have the required permissions as described in KMS permissions for exporting asset metadata in Amazon SageMaker Unified Studio. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.