datazone_query_graph: Queries entities in the graph store

View source: R/datazone_operations.R

datazone_query_graphR Documentation

Queries entities in the graph store

Description

Queries entities in the graph store.

See https://www.paws-r-sdk.com/docs/datazone_query_graph/ for full documentation.

Usage

datazone_query_graph(
  domainIdentifier,
  match,
  maxResults = NULL,
  nextToken = NULL,
  additionalAttributes = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain.

match

[required] List of query match clauses.

maxResults

The maximum number of entities to return in a single call to query_graph. When the number of entities to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to query_graph to list the next set of entities.

nextToken

When the number of entities is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of entities, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to query_graph to list the next set of entities.

additionalAttributes

Additional details on the queried entity that can be requested in the response.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.