datazone_reject_predictions: Rejects automatically generated business-friendly metadata...

View source: R/datazone_operations.R

datazone_reject_predictionsR Documentation

Rejects automatically generated business-friendly metadata for your Amazon DataZone assets

Description

Rejects automatically generated business-friendly metadata for your Amazon DataZone assets.

See https://www.paws-r-sdk.com/docs/datazone_reject_predictions/ for full documentation.

Usage

datazone_reject_predictions(
  domainIdentifier,
  identifier,
  revision = NULL,
  rejectRule = NULL,
  rejectChoices = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain.

identifier

[required] The identifier of the prediction.

revision

The revision that is to be made to the asset.

rejectRule

Specifies the rule (or the conditions) under which a prediction can be rejected.

rejectChoices

Specifies the prediction (aka, the automatically generated piece of metadata) and the target (for example, a column name) that can be rejected.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.