View source: R/datazone_operations.R
| datazone_reject_subscription_request | R Documentation |
Rejects the specified subscription request.
See https://www.paws-r-sdk.com/docs/datazone_reject_subscription_request/ for full documentation.
datazone_reject_subscription_request(
domainIdentifier,
identifier,
decisionComment = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which the subscription request was rejected. |
identifier |
[required] The identifier of the subscription request that was rejected. |
decisionComment |
The decision comment of the rejected subscription request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.