datazone_remove_entity_owner: Removes an owner from an entity

View source: R/datazone_operations.R

datazone_remove_entity_ownerR Documentation

Removes an owner from an entity

Description

Removes an owner from an entity.

See https://www.paws-r-sdk.com/docs/datazone_remove_entity_owner/ for full documentation.

Usage

datazone_remove_entity_owner(
  domainIdentifier,
  entityType,
  entityIdentifier,
  owner,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where you want to remove an owner from an entity.

entityType

[required] The type of the entity from which you want to remove an owner.

entityIdentifier

[required] The ID of the entity from which you want to remove an owner.

owner

[required] The owner that you want to remove from an entity.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.