datazone_remove_policy_grant: Removes a policy grant

View source: R/datazone_operations.R

datazone_remove_policy_grantR Documentation

Removes a policy grant

Description

Removes a policy grant.

See https://www.paws-r-sdk.com/docs/datazone_remove_policy_grant/ for full documentation.

Usage

datazone_remove_policy_grant(
  domainIdentifier,
  entityType,
  entityIdentifier,
  policyType,
  principal,
  grantIdentifier = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where you want to remove a policy grant.

entityType

[required] The type of the entity from which you want to remove a policy grant.

entityIdentifier

[required] The ID of the entity from which you want to remove a policy grant.

policyType

[required] The type of the policy that you want to remove.

principal

[required] The principal from which you want to remove a policy grant.

grantIdentifier

The ID of the policy grant that is to be removed from a specified entity.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.