datazone_search: Searches for assets in Amazon DataZone

View source: R/datazone_operations.R

datazone_searchR Documentation

Description

Searches for assets in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_search/ for full documentation.

Usage

datazone_search(
  domainIdentifier,
  owningProjectIdentifier = NULL,
  maxResults = NULL,
  nextToken = NULL,
  searchScope,
  searchText = NULL,
  searchIn = NULL,
  filters = NULL,
  sort = NULL,
  additionalAttributes = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain.

owningProjectIdentifier

The identifier of the owning project specified for the search.

maxResults

The maximum number of results to return in a single call to search. When the number of results to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to search to list the next set of results.

nextToken

When the number of results is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of results, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to search to list the next set of results.

searchScope

[required] The scope of the search.

searchText

Specifies the text for which to search.

searchIn

The details of the search.

filters

Specifies the search filters.

sort

Specifies the way in which the search results are to be sorted.

additionalAttributes

Specifies additional attributes for the search action.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.