datazone_search_listings: Searches listings in Amazon DataZone

View source: R/datazone_operations.R

datazone_search_listingsR Documentation

Searches listings in Amazon DataZone

Description

Searches listings in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_search_listings/ for full documentation.

Usage

datazone_search_listings(
  domainIdentifier,
  searchText = NULL,
  searchIn = NULL,
  maxResults = NULL,
  nextToken = NULL,
  filters = NULL,
  aggregations = NULL,
  sort = NULL,
  additionalAttributes = NULL
)

Arguments

domainIdentifier

[required] The identifier of the domain in which to search listings.

searchText

Specifies the text for which to search.

searchIn

The details of the search.

maxResults

The maximum number of results to return in a single call to search_listings. When the number of results to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to search_listings to list the next set of results.

nextToken

When the number of results is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of results, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to search_listings to list the next set of results.

filters

Specifies the filters for the search of listings.

aggregations

Enables you to specify one or more attributes to compute and return counts grouped by field values.

sort

Specifies the way for sorting the search results.

additionalAttributes

Specifies additional attributes for the search.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.