datazone_start_data_source_run: Start the run of the specified data source in Amazon DataZone

View source: R/datazone_operations.R

datazone_start_data_source_runR Documentation

Start the run of the specified data source in Amazon DataZone

Description

Start the run of the specified data source in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_start_data_source_run/ for full documentation.

Usage

datazone_start_data_source_run(
  domainIdentifier,
  dataSourceIdentifier,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which to start a data source run.

dataSourceIdentifier

[required] The identifier of the data source.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.