datazone_start_metadata_generation_run: Starts the metadata generation run

View source: R/datazone_operations.R

datazone_start_metadata_generation_runR Documentation

Starts the metadata generation run

Description

Starts the metadata generation run.

See https://www.paws-r-sdk.com/docs/datazone_start_metadata_generation_run/ for full documentation.

Usage

datazone_start_metadata_generation_run(
  domainIdentifier,
  type = NULL,
  types = NULL,
  target,
  clientToken = NULL,
  owningProjectIdentifier
)

Arguments

domainIdentifier

[required] The ID of the Amazon DataZone domain where you want to start a metadata generation run.

type

The type of the metadata generation run.

types

The types of the metadata generation run.

target

[required] The asset for which you want to start a metadata generation run.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

owningProjectIdentifier

[required] The ID of the project that owns the asset for which you want to start a metadata generation run.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.