datazone_start_notebook_export: Starts a notebook export in Amazon SageMaker Unified Studio

View source: R/datazone_operations.R

datazone_start_notebook_exportR Documentation

Starts a notebook export in Amazon SageMaker Unified Studio

Description

Starts a notebook export in Amazon SageMaker Unified Studio. This operation exports a notebook to a specified file format and stores the output in Amazon Simple Storage Service.

See https://www.paws-r-sdk.com/docs/datazone_start_notebook_export/ for full documentation.

Usage

datazone_start_notebook_export(
  domainIdentifier,
  notebookIdentifier,
  owningProjectIdentifier,
  fileFormat,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which to export the notebook.

notebookIdentifier

[required] The identifier of the notebook to export.

owningProjectIdentifier

[required] The identifier of the project that owns the notebook.

fileFormat

[required] The file format for the notebook export. Valid values are PDF and IPYNB.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.