View source: R/datazone_operations.R
| datazone_start_notebook_run | R Documentation |
Starts a notebook run in Amazon SageMaker Unified Studio. A notebook run represents the execution of an Amazon SageMaker notebook within a project. You can configure compute, network, timeout, and environment settings for the run.
See https://www.paws-r-sdk.com/docs/datazone_start_notebook_run/ for full documentation.
datazone_start_notebook_run(
domainIdentifier,
owningProjectIdentifier,
notebookIdentifier,
scheduleIdentifier = NULL,
computeConfiguration = NULL,
networkConfiguration = NULL,
timeoutConfiguration = NULL,
triggerSource = NULL,
metadata = NULL,
parameters = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run is started. |
owningProjectIdentifier |
[required] The identifier of the project that owns the notebook run. |
notebookIdentifier |
[required] The identifier of the notebook to run. |
scheduleIdentifier |
The identifier of the schedule associated with the notebook run. |
computeConfiguration |
The compute configuration for the notebook run, including instance type and environment version. |
networkConfiguration |
The network configuration for the notebook run, including network access type and optional VPC settings. |
timeoutConfiguration |
The timeout configuration for the notebook run. The default timeout is 720 minutes (12 hours) and the maximum is 1440 minutes (24 hours). |
triggerSource |
The source that triggered the notebook run. |
metadata |
The metadata for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters. |
parameters |
The sensitive parameters for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.