datazone_start_notebook_sync: Starts a notebook sync in Amazon SageMaker Unified Studio

View source: R/datazone_operations.R

datazone_start_notebook_syncR Documentation

Starts a notebook sync in Amazon SageMaker Unified Studio

Description

Starts a notebook sync in Amazon SageMaker Unified Studio. This operation syncs a notebook from a Git repository into a project.

See https://www.paws-r-sdk.com/docs/datazone_start_notebook_sync/ for full documentation.

Usage

datazone_start_notebook_sync(
  domainIdentifier,
  owningProjectIdentifier,
  sourceLocation,
  gitMetadata = NULL,
  notebookId = NULL,
  name = NULL,
  description = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which to sync the notebook.

owningProjectIdentifier

[required] The identifier of the project that will own the synced notebook.

sourceLocation

[required] The source location of the notebook to sync. This specifies the Amazon Simple Storage Service URI of the notebook file.

gitMetadata

The Git metadata for the notebook sync, including repository, branch, and commit information.

notebookId

The identifier of an existing notebook to sync. If not specified, a new notebook is created.

name

The name of the notebook. The name must be between 1 and 256 characters.

description

The description of the notebook.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.