datazone_update_account_pool: Updates the account pool

View source: R/datazone_operations.R

datazone_update_account_poolR Documentation

Updates the account pool

Description

Updates the account pool.

See https://www.paws-r-sdk.com/docs/datazone_update_account_pool/ for full documentation.

Usage

datazone_update_account_pool(
  domainIdentifier,
  identifier,
  name = NULL,
  description = NULL,
  resolutionStrategy = NULL,
  accountSource = NULL
)

Arguments

domainIdentifier

[required] The domain ID where the account pool that is to be updated lives.

identifier

[required] The ID of the account pool that is to be updated.

name

The name of the account pool that is to be updated.

description

The description of the account pool that is to be udpated.

resolutionStrategy

The mechanism used to resolve the account selection from the account pool.

accountSource

The source of accounts for the account pool. In the current release, it's either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.