View source: R/datazone_operations.R
| datazone_update_domain | R Documentation |
Updates a Amazon DataZone domain.
See https://www.paws-r-sdk.com/docs/datazone_update_domain/ for full documentation.
datazone_update_domain(
identifier,
description = NULL,
singleSignOn = NULL,
domainExecutionRole = NULL,
serviceRole = NULL,
name = NULL,
clientToken = NULL
)
identifier |
[required] The ID of the Amazon Web Services domain that is to be updated. |
description |
The description to be updated as part of the |
singleSignOn |
The single sign-on option to be updated as part of the |
domainExecutionRole |
The domain execution role to be updated as part of the |
serviceRole |
The service role of the domain. |
name |
The name to be updated as part of the |
clientToken |
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.