datazone_update_environment: Updates the specified environment in Amazon DataZone

View source: R/datazone_operations.R

datazone_update_environmentR Documentation

Updates the specified environment in Amazon DataZone

Description

Updates the specified environment in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_update_environment/ for full documentation.

Usage

datazone_update_environment(
  domainIdentifier,
  identifier,
  name = NULL,
  description = NULL,
  glossaryTerms = NULL,
  blueprintVersion = NULL,
  userParameters = NULL,
  environmentConfigurationName = NULL
)

Arguments

domainIdentifier

[required] The identifier of the domain in which the environment is to be updated.

identifier

[required] The identifier of the environment that is to be updated.

name

The name to be updated as part of the update_environment action.

description

The description to be updated as part of the update_environment action.

glossaryTerms

The glossary terms to be updated as part of the update_environment action.

blueprintVersion

The blueprint version to which the environment should be updated. You can only specify the following string for this parameter: latest.

userParameters

The user parameters of the environment.

environmentConfigurationName

The configuration name of the environment.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.