datazone_update_environment_blueprint: Updates an environment blueprint in Amazon DataZone

View source: R/datazone_operations.R

datazone_update_environment_blueprintR Documentation

Updates an environment blueprint in Amazon DataZone

Description

Updates an environment blueprint in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_update_environment_blueprint/ for full documentation.

Usage

datazone_update_environment_blueprint(
  domainIdentifier,
  identifier,
  description = NULL,
  provisioningProperties = NULL,
  userParameters = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.

identifier

[required] The identifier of the environment blueprint to be updated.

description

The description to be updated as part of the update_environment_blueprint action.

provisioningProperties

The provisioning properties to be updated as part of the update_environment_blueprint action.

userParameters

The user parameters to be updated as part of the update_environment_blueprint action.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.