datazone_update_glossary: Updates the business glossary in Amazon DataZone

View source: R/datazone_operations.R

datazone_update_glossaryR Documentation

Updates the business glossary in Amazon DataZone

Description

Updates the business glossary in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_update_glossary/ for full documentation.

Usage

datazone_update_glossary(
  domainIdentifier,
  identifier,
  name = NULL,
  description = NULL,
  status = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which a business glossary is to be updated.

identifier

[required] The identifier of the business glossary to be updated.

name

The name to be updated as part of the update_glossary action.

description

The description to be updated as part of the update_glossary action.

status

The status to be updated as part of the update_glossary action.

clientToken

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.