datazone_update_notebook: Updates a notebook in Amazon SageMaker Unified Studio

View source: R/datazone_operations.R

datazone_update_notebookR Documentation

Updates a notebook in Amazon SageMaker Unified Studio

Description

Updates a notebook in Amazon SageMaker Unified Studio.

See https://www.paws-r-sdk.com/docs/datazone_update_notebook/ for full documentation.

Usage

datazone_update_notebook(
  domainIdentifier,
  identifier,
  description = NULL,
  status = NULL,
  name = NULL,
  cellOrder = NULL,
  metadata = NULL,
  parameters = NULL,
  environmentConfiguration = NULL,
  clientToken = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.

identifier

[required] The identifier of the notebook to update.

description

The updated description of the notebook.

status

The updated status of the notebook.

name

The updated name of the notebook.

cellOrder

The updated ordered list of cells in the notebook.

metadata

The updated metadata for the notebook, specified as key-value pairs.

parameters

The updated sensitive parameters for the notebook, specified as key-value pairs.

environmentConfiguration

The updated environment configuration for the notebook.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.