View source: R/datazone_operations.R
| datazone_update_project | R Documentation |
Updates the specified project in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_update_project/ for full documentation.
datazone_update_project(
domainIdentifier,
identifier,
name = NULL,
description = NULL,
resourceTags = NULL,
glossaryTerms = NULL,
domainUnitId = NULL,
environmentDeploymentDetails = NULL,
userParameters = NULL,
projectProfileVersion = NULL
)
domainIdentifier |
[required] The ID of the Amazon DataZone domain where a project is being updated. |
identifier |
[required] The identifier of the project that is to be updated. |
name |
The name to be updated as part of the |
description |
The description to be updated as part of the |
resourceTags |
The resource tags of the project. |
glossaryTerms |
The glossary terms to be updated as part of the |
domainUnitId |
The ID of the domain unit. |
environmentDeploymentDetails |
The environment deployment details of the project. |
userParameters |
The user parameters of the project. |
projectProfileVersion |
The project profile version to which the project should be updated. You can only specify the following string for this parameter: |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.