datazone_update_project_profile: Updates a project profile

View source: R/datazone_operations.R

datazone_update_project_profileR Documentation

Updates a project profile

Description

Updates a project profile.

See https://www.paws-r-sdk.com/docs/datazone_update_project_profile/ for full documentation.

Usage

datazone_update_project_profile(
  domainIdentifier,
  identifier,
  name = NULL,
  description = NULL,
  status = NULL,
  projectResourceTags = NULL,
  allowCustomProjectResourceTags = NULL,
  projectResourceTagsDescription = NULL,
  environmentConfigurations = NULL,
  domainUnitIdentifier = NULL
)

Arguments

domainIdentifier

[required] The ID of the domain where a project profile is to be updated.

identifier

[required] The ID of a project profile that is to be updated.

name

The name of a project profile.

description

The description of a project profile.

status

The status of a project profile.

projectResourceTags

The resource tags of the project profile.

allowCustomProjectResourceTags

Specifies whether custom project resource tags are supported.

projectResourceTagsDescription

Field viewable through the UI that provides a project user with the allowed resource tag specifications.

environmentConfigurations

The environment configurations of a project profile.

domainUnitIdentifier

The ID of the domain unit where a project profile is to be updated.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.