datazone_update_subscription_target: Updates the specified subscription target in Amazon DataZone

View source: R/datazone_operations.R

datazone_update_subscription_targetR Documentation

Updates the specified subscription target in Amazon DataZone

Description

Updates the specified subscription target in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_update_subscription_target/ for full documentation.

Usage

datazone_update_subscription_target(
  domainIdentifier,
  environmentIdentifier,
  identifier,
  name = NULL,
  authorizedPrincipals = NULL,
  applicableAssetTypes = NULL,
  subscriptionTargetConfig = NULL,
  manageAccessRole = NULL,
  provider = NULL,
  subscriptionGrantCreationMode = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which a subscription target is to be updated.

environmentIdentifier

[required] The identifier of the environment in which a subscription target is to be updated.

identifier

[required] Identifier of the subscription target that is to be updated.

name

The name to be updated as part of the update_subscription_target action.

authorizedPrincipals

The authorized principals to be updated as part of the update_subscription_target action.

applicableAssetTypes

The applicable asset types to be updated as part of the update_subscription_target action.

subscriptionTargetConfig

The configuration to be updated as part of the update_subscription_target action.

manageAccessRole

The manage access role to be updated as part of the update_subscription_target action.

provider

The provider to be updated as part of the update_subscription_target action.

subscriptionGrantCreationMode

Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.