datazone_update_user_profile: Updates the specified user profile in Amazon DataZone

View source: R/datazone_operations.R

datazone_update_user_profileR Documentation

Updates the specified user profile in Amazon DataZone

Description

Updates the specified user profile in Amazon DataZone.

See https://www.paws-r-sdk.com/docs/datazone_update_user_profile/ for full documentation.

Usage

datazone_update_user_profile(
  domainIdentifier,
  userIdentifier,
  type = NULL,
  status,
  sessionName = NULL
)

Arguments

domainIdentifier

[required] The identifier of the Amazon DataZone domain in which a user profile is updated.

userIdentifier

[required] The identifier of the user whose user profile is to be updated.

type

The type of the user profile that are to be updated.

status

[required] The status of the user profile that are to be updated.

sessionName

The session name for IAM role sessions.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.