elasticsearchservice_get_compatible_elasticsearch_versions: Returns a list of upgrade compatible Elastisearch versions

View source: R/elasticsearchservice_operations.R

elasticsearchservice_get_compatible_elasticsearch_versionsR Documentation

Returns a list of upgrade compatible Elastisearch versions

Description

Returns a list of upgrade compatible Elastisearch versions. You can optionally pass a DomainName to get all upgrade compatible Elasticsearch versions for that specific domain.

See https://www.paws-r-sdk.com/docs/elasticsearchservice_get_compatible_elasticsearch_versions/ for full documentation.

Usage

elasticsearchservice_get_compatible_elasticsearch_versions(DomainName = NULL)

Arguments

DomainName

The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).


paws.analytics documentation built on May 30, 2026, 9:16 a.m.