View source: R/elasticsearchservice_operations.R
| elasticsearchservice_get_upgrade_history | R Documentation |
Retrieves the complete history of the last 10 upgrades that were performed on the domain.
See https://www.paws-r-sdk.com/docs/elasticsearchservice_get_upgrade_history/ for full documentation.
elasticsearchservice_get_upgrade_history(
DomainName,
MaxResults = NULL,
NextToken = NULL
)
DomainName |
[required] The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
MaxResults |
Set this value to limit the number of results returned. |
NextToken |
Paginated APIs accepts NextToken input to returns next page results and provides a NextToken output in the response which can be used by the client to retrieve more results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.