elasticsearchservice_get_upgrade_status: Retrieves the latest status of the last upgrade or upgrade...

View source: R/elasticsearchservice_operations.R

elasticsearchservice_get_upgrade_statusR Documentation

Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain

Description

Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.

See https://www.paws-r-sdk.com/docs/elasticsearchservice_get_upgrade_status/ for full documentation.

Usage

elasticsearchservice_get_upgrade_status(DomainName)

Arguments

DomainName

[required] The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).


paws.analytics documentation built on May 30, 2026, 9:16 a.m.