elasticsearchservice_list_elasticsearch_versions: List all supported Elasticsearch versions

View source: R/elasticsearchservice_operations.R

elasticsearchservice_list_elasticsearch_versionsR Documentation

List all supported Elasticsearch versions

Description

List all supported Elasticsearch versions

See https://www.paws-r-sdk.com/docs/elasticsearchservice_list_elasticsearch_versions/ for full documentation.

Usage

elasticsearchservice_list_elasticsearch_versions(
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MaxResults

Set this value to limit the number of results returned. Value provided must be greater than 10 else it wont be honored.

NextToken

Paginated APIs accepts NextToken input to returns next page results and provides a NextToken output in the response which can be used by the client to retrieve more results.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.