Removes the specified set of tags from the specified Elasticsearch domain.
See https://www.paws-r-sdk.com/docs/elasticsearchservice_remove_tags/ for full documentation.
elasticsearchservice_remove_tags(ARN, TagKeys)[required] Specifies the ARN for the Elasticsearch domain from which you want to
delete the specified tags.
[required] Specifies the TagKey list which you want to remove from the
Elasticsearch domain.