emr_create_persistent_app_ui: Creates a persistent application user interface

View source: R/emr_operations.R

emr_create_persistent_app_uiR Documentation

Creates a persistent application user interface

Description

Creates a persistent application user interface.

See https://www.paws-r-sdk.com/docs/emr_create_persistent_app_ui/ for full documentation.

Usage

emr_create_persistent_app_ui(
  TargetResourceArn,
  EMRContainersConfig = NULL,
  Tags = NULL,
  XReferer = NULL,
  ProfilerType = NULL
)

Arguments

TargetResourceArn

[required] The unique Amazon Resource Name (ARN) of the target resource.

EMRContainersConfig

The EMR containers configuration.

Tags

Tags for the persistent application user interface.

XReferer

The cross reference for the persistent application user interface.

ProfilerType

The profiler type for the persistent application user interface.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.