View source: R/emr_operations.R
| emr_delete_studio_session_mapping | R Documentation |
Removes a user or group from an Amazon EMR Studio.
See https://www.paws-r-sdk.com/docs/emr_delete_studio_session_mapping/ for full documentation.
emr_delete_studio_session_mapping(
StudioId,
IdentityId = NULL,
IdentityName = NULL,
IdentityType
)
StudioId |
[required] The ID of the Amazon EMR Studio. |
IdentityId |
The globally unique identifier (GUID) of the user or group to remove from the Amazon EMR Studio. For more information, see UserId and GroupId in the IAM Identity Center Identity Store API Reference. Either |
IdentityName |
The name of the user name or group to remove from the Amazon EMR Studio. For more information, see UserName and DisplayName in the IAM Identity Center Store API Reference. Either |
IdentityType |
[required] Specifies whether the identity to delete from the Amazon EMR Studio is a user or a group. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.