emr_get_persistent_app_ui_presigned_url: The presigned URL properties for the cluster's application...

View source: R/emr_operations.R

emr_get_persistent_app_ui_presigned_urlR Documentation

The presigned URL properties for the cluster's application user interface

Description

The presigned URL properties for the cluster's application user interface.

See https://www.paws-r-sdk.com/docs/emr_get_persistent_app_ui_presigned_url/ for full documentation.

Usage

emr_get_persistent_app_ui_presigned_url(
  PersistentAppUIId,
  PersistentAppUIType = NULL,
  ApplicationId = NULL,
  AuthProxyCall = NULL,
  ExecutionRoleArn = NULL
)

Arguments

PersistentAppUIId

[required] The persistent application user interface ID associated with the presigned URL.

PersistentAppUIType

The persistent application user interface type associated with the presigned URL.

ApplicationId

The application ID associated with the presigned URL.

AuthProxyCall

A boolean that represents if the caller is an authentication proxy call.

ExecutionRoleArn

The execution role ARN associated with the presigned URL.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.