emr_get_session_endpoint: Returns the Spark Connect endpoint URL and a time-limited...

View source: R/emr_operations.R

emr_get_session_endpointR Documentation

Returns the Spark Connect endpoint URL and a time-limited authentication token for the specified session

Description

Returns the Spark Connect endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a PySpark client to the session. Call this operation again when the token expires to obtain a new one.

See https://www.paws-r-sdk.com/docs/emr_get_session_endpoint/ for full documentation.

Usage

emr_get_session_endpoint(ClusterId, SessionId)

Arguments

ClusterId

[required] The ID of the cluster that the session belongs to.

SessionId

[required] The ID of the session.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.