emr_list_sessions: Lists the sessions on a cluster

View source: R/emr_operations.R

emr_list_sessionsR Documentation

Lists the sessions on a cluster

Description

Lists the sessions on a cluster. You can filter the results by session state. Newer sessions are returned first.

See https://www.paws-r-sdk.com/docs/emr_list_sessions/ for full documentation.

Usage

emr_list_sessions(
  ClusterId,
  SessionStates = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

ClusterId

[required] The ID of the cluster to list sessions for.

SessionStates

An optional filter that limits the results to sessions in the specified states.

NextToken

The pagination token returned by a previous list_sessions call. Use it to retrieve the next page of results.

MaxResults

The maximum number of sessions to return in each page of results.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.