SetTerminationProtection locks a cluster (job flow) so the EC2 instances
in the cluster cannot be terminated by user intervention, an API call,
or in the event of a job-flow error. The cluster still terminates upon
successful completion of the job flow. Calling
set_termination_protection on a
cluster is similar to calling the Amazon EC2 DisableAPITermination API
on all EC2 instances in a cluster.
set_termination_protection is used
to prevent accidental termination of a cluster and to ensure that in the
event of an error, the instances persist so that you can recover any
data stored in their ephemeral instance storage.
To terminate a cluster that has been locked by setting
set_termination_protection to
true, you must first unlock the job flow by a subsequent call to
set_termination_protection in which
you set the value to false.
For more information, seeManaging Cluster Termination in the Amazon EMR Management Guide.
emr_set_termination_protection(JobFlowIds, TerminationProtected)[required] A list of strings that uniquely identify the clusters to protect. This
identifier is returned by run_job_flow and can
also be obtained from describe_job_flows .
[required] A Boolean that indicates whether to protect the cluster and prevent the Amazon EC2 instances in the cluster from shutting down due to API calls, user intervention, or job-flow error.
An empty list.
svc$set_termination_protection(
JobFlowIds = list(
"string"
),
TerminationProtected = TRUE|FALSE
)