emr_terminate_session: Terminates an active session

View source: R/emr_operations.R

emr_terminate_sessionR Documentation

Terminates an active session

Description

Terminates an active session. After you call this operation, the session enters the TERMINATING state and then transitions to TERMINATED.

See https://www.paws-r-sdk.com/docs/emr_terminate_session/ for full documentation.

Usage

emr_terminate_session(ClusterId, SessionId)

Arguments

ClusterId

[required] The ID of the cluster that the session belongs to.

SessionId

[required] The ID of the session to terminate.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.