entityresolution_add_policy_statement: Adds a policy statement object

View source: R/entityresolution_operations.R

entityresolution_add_policy_statementR Documentation

Adds a policy statement object

Description

Adds a policy statement object. To retrieve a list of existing policy statements, use the get_policy API.

See https://www.paws-r-sdk.com/docs/entityresolution_add_policy_statement/ for full documentation.

Usage

entityresolution_add_policy_statement(
  arn,
  statementId,
  effect,
  action,
  principal,
  condition = NULL
)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the resource that will be accessed by the principal.

statementId

[required] A statement identifier that differentiates the statement from others in the same policy.

effect

[required] Determines whether the permissions specified in the policy are to be allowed (Allow) or denied (Deny).

If you set the value of the effect parameter to Deny for the add_policy_statement operation, you must also set the value of the effect parameter in the policy to Deny for the put_policy operation.

action

[required] The action that the principal can use on the resource.

For example, entityresolution:GetIdMappingJob, entityresolution:GetMatchingJob.

principal

[required] The Amazon Web Services service or Amazon Web Services account that can access the resource defined as ARN.

condition

A set of condition keys that you can use in key policies.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.