View source: R/entityresolution_operations.R
| entityresolution_create_id_mapping_workflow | R Documentation |
Creates an IdMappingWorkflow object which stores the configuration of the data processing job to be run. Each IdMappingWorkflow must have a unique workflow name. To modify an existing workflow, use the UpdateIdMappingWorkflow API.
See https://www.paws-r-sdk.com/docs/entityresolution_create_id_mapping_workflow/ for full documentation.
entityresolution_create_id_mapping_workflow(
workflowName,
description = NULL,
inputSourceConfig,
outputSourceConfig = NULL,
idMappingTechniques,
incrementalRunConfig = NULL,
roleArn = NULL,
tags = NULL
)
workflowName |
[required] The name of the workflow. There can't be multiple |
description |
A description of the workflow. |
inputSourceConfig |
[required] A list of |
outputSourceConfig |
A list of |
idMappingTechniques |
[required] An object which defines the ID mapping technique and any additional configurations. |
incrementalRunConfig |
The incremental run configuration for the ID mapping workflow. |
roleArn |
The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution. |
tags |
The tags used to organize, track, or control access for this resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.