entityresolution_create_matching_workflow: Creates a matching workflow that defines the configuration...

View source: R/entityresolution_operations.R

entityresolution_create_matching_workflowR Documentation

Creates a matching workflow that defines the configuration for a data processing job

Description

Creates a matching workflow that defines the configuration for a data processing job. The workflow name must be unique. To modify an existing workflow, use update_matching_workflow.

See https://www.paws-r-sdk.com/docs/entityresolution_create_matching_workflow/ for full documentation.

Usage

entityresolution_create_matching_workflow(
  workflowName,
  description = NULL,
  inputSourceConfig,
  outputSourceConfig,
  resolutionTechniques,
  incrementalRunConfig = NULL,
  roleArn,
  tags = NULL
)

Arguments

workflowName

[required] The name of the workflow. There can't be multiple MatchingWorkflows with the same name.

description

A description of the workflow.

inputSourceConfig

[required] A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

outputSourceConfig

[required] A list of OutputSource objects, each of which contains fields outputS3Path, applyNormalization, KMSArn, and output.

resolutionTechniques

[required] An object which defines the resolutionType and the ruleBasedProperties.

incrementalRunConfig

Optional. An object that defines the incremental run type. This object contains only the incrementalRunType field, which appears as "Automatic" in the console.

For workflows where resolutionType is ML_MATCHING or PROVIDER, incremental processing is not supported.

roleArn

[required] The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.

tags

The tags used to organize, track, or control access for this resource.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.