entityresolution_get_match_id: Returns the corresponding Match ID of a customer record if...

View source: R/entityresolution_operations.R

entityresolution_get_match_idR Documentation

Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow

Description

Returns the corresponding Match ID of a customer record if the record has been processed in a rule-based matching workflow.

See https://www.paws-r-sdk.com/docs/entityresolution_get_match_id/ for full documentation.

Usage

entityresolution_get_match_id(workflowName, record, applyNormalization = NULL)

Arguments

workflowName

[required] The name of the workflow.

record

[required] The record to fetch the Match ID for.

applyNormalization

Normalizes the attributes defined in the schema in the input data. For example, if an attribute has an AttributeType of PHONE_NUMBER, and the data in the input table is in a format of 1234567890, Entity Resolution will normalize this field in the output to (123)-456-7890.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.