entityresolution_list_matching_workflows: Returns a list of all the MatchingWorkflows that have been...

View source: R/entityresolution_operations.R

entityresolution_list_matching_workflowsR Documentation

Returns a list of all the MatchingWorkflows that have been created for an Amazon Web Services account

Description

Returns a list of all the MatchingWorkflows that have been created for an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/entityresolution_list_matching_workflows/ for full documentation.

Usage

entityresolution_list_matching_workflows(nextToken = NULL, maxResults = NULL)

Arguments

nextToken

The pagination token from the previous API call.

maxResults

The maximum number of objects returned per page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.