entityresolution_put_policy: Updates the resource-based policy

View source: R/entityresolution_operations.R

entityresolution_put_policyR Documentation

Updates the resource-based policy

Description

Updates the resource-based policy.

See https://www.paws-r-sdk.com/docs/entityresolution_put_policy/ for full documentation.

Usage

entityresolution_put_policy(arn, token = NULL, policy)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the resource for which the policy needs to be updated.

token

A unique identifier for the current revision of the policy.

policy

[required] The resource-based policy.

If you set the value of the effect parameter in the policy to Deny for the put_policy operation, you must also set the value of the effect parameter to Deny for the add_policy_statement operation.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.