entityresolution_update_id_mapping_workflow: Updates an existing IdMappingWorkflow

View source: R/entityresolution_operations.R

entityresolution_update_id_mapping_workflowR Documentation

Updates an existing IdMappingWorkflow

Description

Updates an existing IdMappingWorkflow. This method is identical to CreateIdMappingWorkflow, except it uses an HTTP PUT request instead of a POST request, and the IdMappingWorkflow must already exist for the method to succeed.

See https://www.paws-r-sdk.com/docs/entityresolution_update_id_mapping_workflow/ for full documentation.

Usage

entityresolution_update_id_mapping_workflow(
  workflowName,
  description = NULL,
  inputSourceConfig,
  outputSourceConfig = NULL,
  idMappingTechniques,
  incrementalRunConfig = NULL,
  roleArn = NULL
)

Arguments

workflowName

[required] The name of the workflow.

description

A description of the workflow.

inputSourceConfig

[required] A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

outputSourceConfig

A list of OutputSource objects, each of which contains fields outputS3Path and KMSArn.

idMappingTechniques

[required] An object which defines the ID mapping technique and any additional configurations.

incrementalRunConfig

The incremental run configuration for the update ID mapping workflow.

roleArn

The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access Amazon Web Services resources on your behalf.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.