entityresolution_update_id_namespace: Updates an existing ID namespace

View source: R/entityresolution_operations.R

entityresolution_update_id_namespaceR Documentation

Updates an existing ID namespace

Description

Updates an existing ID namespace.

See https://www.paws-r-sdk.com/docs/entityresolution_update_id_namespace/ for full documentation.

Usage

entityresolution_update_id_namespace(
  idNamespaceName,
  description = NULL,
  inputSourceConfig = NULL,
  idMappingWorkflowProperties = NULL,
  roleArn = NULL
)

Arguments

idNamespaceName

[required] The name of the ID namespace.

description

The description of the ID namespace.

inputSourceConfig

A list of InputSource objects, which have the fields InputSourceARN and SchemaName.

idMappingWorkflowProperties

Determines the properties of IdMappingWorkflow where this IdNamespace can be used as a Source or a Target.

roleArn

The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to access the resources defined in this IdNamespace on your behalf as part of a workflow run.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.