entityresolution_update_schema_mapping: Updates a schema mapping

View source: R/entityresolution_operations.R

entityresolution_update_schema_mappingR Documentation

Updates a schema mapping

Description

Updates a schema mapping.

See https://www.paws-r-sdk.com/docs/entityresolution_update_schema_mapping/ for full documentation.

Usage

entityresolution_update_schema_mapping(
  schemaName,
  description = NULL,
  mappedInputFields
)

Arguments

schemaName

[required] The name of the schema. There can't be multiple SchemaMappings with the same name.

description

A description of the schema.

mappedInputFields

[required] A list of MappedInputFields. Each MappedInputField corresponds to a column the source data table, and contains column name plus additional information that Entity Resolution uses for matching.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.