firehose_put_record_batch: Writes multiple data records into a Firehose stream in a...

View source: R/firehose_operations.R

firehose_put_record_batchR Documentation

Writes multiple data records into a Firehose stream in a single call, which can achieve higher throughput per producer than when writing single records

Description

Writes multiple data records into a Firehose stream in a single call, which can achieve higher throughput per producer than when writing single records. To write single data records into a Firehose stream, use put_record. Applications using these operations are referred to as producers.

See https://www.paws-r-sdk.com/docs/firehose_put_record_batch/ for full documentation.

Usage

firehose_put_record_batch(DeliveryStreamName, Records)

Arguments

DeliveryStreamName

[required] The name of the Firehose stream.

Records

[required] One or more records.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.