Removes tags from the specified delivery stream. Removed tags are deleted, and you can't recover them after this operation successfully completes.
firehose_untag_delivery_stream(DeliveryStreamName, TagKeys)[required] The name of the delivery stream.
[required] A list of tag keys. Each corresponding tag is removed from the delivery stream.
svc$untag_delivery_stream(
DeliveryStreamName = "string",
TagKeys = list(
"string"
)
)
If you specify a tag that doesn't exist, the operation ignores it.
This operation has a limit of five transactions per second per account.