glue_associate_glossary_terms: Associates one or more glossary terms with an asset in Glue...

View source: R/glue_operations.R

glue_associate_glossary_termsR Documentation

Associates one or more glossary terms with an asset in Glue Data Catalog

Description

Associates one or more glossary terms with an asset in Glue Data Catalog.

See https://www.paws-r-sdk.com/docs/glue_associate_glossary_terms/ for full documentation.

Usage

glue_associate_glossary_terms(
  AssetIdentifier,
  IterableFormName = NULL,
  ItemIdentifier = NULL,
  GlossaryTermIdentifiers,
  ClientToken = NULL
)

Arguments

AssetIdentifier

[required] The unique identifier of the asset to associate glossary terms with.

IterableFormName

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are associated with an item within the iterable form rather than the asset itself.

ItemIdentifier

The identifier of the item within the iterable form. Required when iterableFormName is specified.

GlossaryTermIdentifiers

[required] The list of glossary term identifiers to associate with the asset.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.