glue_batch_get_data_quality_ruleset_evaluation_run: Retrieves the details of multiple evaluation runs in a single...

View source: R/glue_operations.R

glue_batch_get_data_quality_ruleset_evaluation_runR Documentation

Retrieves the details of multiple evaluation runs in a single request

Description

Retrieves the details of multiple evaluation runs in a single request.

See https://www.paws-r-sdk.com/docs/glue_batch_get_data_quality_ruleset_evaluation_run/ for full documentation.

Usage

glue_batch_get_data_quality_ruleset_evaluation_run(RunIds)

Arguments

RunIds

[required] A list of unique run identifiers for the evaluation runs to retrieve.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.