View source: R/glue_operations.R
| glue_batch_get_iterable_forms | R Documentation |
Retrieves multiple items from an iterable form on an asset in Glue Data Catalog in a single request.
See https://www.paws-r-sdk.com/docs/glue_batch_get_iterable_forms/ for full documentation.
glue_batch_get_iterable_forms(
AssetIdentifier,
IterableFormName,
ItemIdentifiers
)
AssetIdentifier |
[required] The unique identifier of the asset. |
IterableFormName |
[required] The name of the iterable form to retrieve items from. |
ItemIdentifiers |
[required] The list of item identifiers to retrieve. Each identifier can be an item ID or item name. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.