glue_batch_get_partition: Retrieves partitions in a batch request

View source: R/glue_operations.R

glue_batch_get_partitionR Documentation

Retrieves partitions in a batch request

Description

Retrieves partitions in a batch request.

See https://www.paws-r-sdk.com/docs/glue_batch_get_partition/ for full documentation.

Usage

glue_batch_get_partition(
  CatalogId = NULL,
  DatabaseName,
  TableName,
  PartitionsToGet,
  AuditContext = NULL,
  QuerySessionContext = NULL
)

Arguments

CatalogId

The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.

DatabaseName

[required] The name of the catalog database where the partitions reside.

TableName

[required] The name of the partitions' table.

PartitionsToGet

[required] A list of partition values identifying the partitions to retrieve.

AuditContext

A structure containing the Lake Formation audit context.

QuerySessionContext

A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.