View source: R/glue_operations.R
| glue_create_glossary | R Documentation |
Creates a business glossary in Glue Data Catalog. A glossary is a container for glossary terms that define business concepts.
See https://www.paws-r-sdk.com/docs/glue_create_glossary/ for full documentation.
glue_create_glossary(Name, Description = NULL, ClientToken = NULL)
Name |
[required] The name of the glossary. |
Description |
The description of the glossary. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.