View source: R/glue_operations.R
| glue_create_glossary_term | R Documentation |
Creates a glossary term within a business glossary in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_create_glossary_term/ for full documentation.
glue_create_glossary_term(
GlossaryIdentifier,
Name,
ShortDescription = NULL,
LongDescription = NULL,
ClientToken = NULL
)
GlossaryIdentifier |
[required] The unique identifier of the glossary in which to create the term. |
Name |
[required] The name of the glossary term. |
ShortDescription |
A short description of the glossary term. |
LongDescription |
A long description of the glossary term. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.