glue_create_glue_identity_center_configuration: Creates a new Glue Identity Center configuration to enable...

View source: R/glue_operations.R

glue_create_glue_identity_center_configurationR Documentation

Creates a new Glue Identity Center configuration to enable integration between Glue and Amazon Web Services IAM Identity Center for authentication and authorization

Description

Creates a new Glue Identity Center configuration to enable integration between Glue and Amazon Web Services IAM Identity Center for authentication and authorization.

See https://www.paws-r-sdk.com/docs/glue_create_glue_identity_center_configuration/ for full documentation.

Usage

glue_create_glue_identity_center_configuration(
  InstanceArn,
  Scopes = NULL,
  UserBackgroundSessionsEnabled = NULL
)

Arguments

InstanceArn

[required] The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.

Scopes

A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.

UserBackgroundSessionsEnabled

Specifies whether users can run background sessions when using Identity Center authentication with Glue services.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.