View source: R/glue_operations.R
| glue_create_integration_table_properties | R Documentation |
This API is used to provide optional override properties for the the tables that need to be replicated. These properties can include properties for filtering and partitioning for the source and target tables. To set both source and target properties the same API need to be invoked with the Glue connection ARN as ResourceArn with SourceTableConfig, and the Glue database ARN as ResourceArn with TargetTableConfig respectively.
See https://www.paws-r-sdk.com/docs/glue_create_integration_table_properties/ for full documentation.
glue_create_integration_table_properties(
ResourceArn,
TableName,
SourceTableConfig = NULL,
TargetTableConfig = NULL
)
ResourceArn |
[required] The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release. |
TableName |
[required] The name of the table to be replicated. |
SourceTableConfig |
A structure for the source table configuration. See the |
TargetTableConfig |
A structure for the target table configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.