glue_delete_attachment: Deletes a form attachment from an asset in Glue Data Catalog

View source: R/glue_operations.R

glue_delete_attachmentR Documentation

Deletes a form attachment from an asset in Glue Data Catalog

Description

Deletes a form attachment from an asset in Glue Data Catalog.

See https://www.paws-r-sdk.com/docs/glue_delete_attachment/ for full documentation.

Usage

glue_delete_attachment(
  AssetIdentifier,
  IterableFormName = NULL,
  ItemIdentifier = NULL,
  AttachmentName
)

Arguments

AssetIdentifier

[required] The unique identifier of the asset from which to delete the attachment.

IterableFormName

The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.

ItemIdentifier

The identifier of the item within the iterable form. Required when iterableFormName is specified.

AttachmentName

[required] The name of the attachment to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.