glue_delete_database: Removes a specified database from a Data Catalog

View source: R/glue_operations.R

glue_delete_databaseR Documentation

Removes a specified database from a Data Catalog

Description

Removes a specified database from a Data Catalog.

See https://www.paws-r-sdk.com/docs/glue_delete_database/ for full documentation.

Usage

glue_delete_database(CatalogId = NULL, Name)

Arguments

CatalogId

The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.

Name

[required] The name of the database to delete. For Hive compatibility, this must be all lowercase.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.