glue_delete_glue_identity_center_configuration: Deletes the existing Glue Identity Center configuration,...

View source: R/glue_operations.R

glue_delete_glue_identity_center_configurationR Documentation

Deletes the existing Glue Identity Center configuration, removing the integration between Glue and Amazon Web Services IAM Identity Center

Description

Deletes the existing Glue Identity Center configuration, removing the integration between Glue and Amazon Web Services IAM Identity Center.

See https://www.paws-r-sdk.com/docs/glue_delete_glue_identity_center_configuration/ for full documentation.

Usage

glue_delete_glue_identity_center_configuration()

paws.analytics documentation built on May 30, 2026, 9:16 a.m.