Delete the entire registry including schema and all of its versions. To
get the status of the delete operation, you can call the
get_registry API after the asynchronous call.
Deleting a registry will disable all online operations for the registry
such as the update_registry,
create_schema,
update_schema, and
register_schema_version APIs.
glue_delete_registry(RegistryId)[required] This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
A list with the following syntax:
list( RegistryName = "string", RegistryArn = "string", Status = "AVAILABLE"|"DELETING" )
svc$delete_registry(
RegistryId = list(
RegistryName = "string",
RegistryArn = "string"
)
)