glue_delete_table_optimizer: Deletes an optimizer and all associated metadata for a table

View source: R/glue_operations.R

glue_delete_table_optimizerR Documentation

Deletes an optimizer and all associated metadata for a table

Description

Deletes an optimizer and all associated metadata for a table. The optimization will no longer be performed on the table.

See https://www.paws-r-sdk.com/docs/glue_delete_table_optimizer/ for full documentation.

Usage

glue_delete_table_optimizer(CatalogId, DatabaseName, TableName, Type)

Arguments

CatalogId

[required] The Catalog ID of the table.

DatabaseName

[required] The name of the database in the catalog in which the table resides.

TableName

[required] The name of the table.

Type

[required] The type of table optimizer.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.