glue_describe_connection_type: The DescribeConnectionType API provides full details of the...

View source: R/glue_operations.R

glue_describe_connection_typeR Documentation

The DescribeConnectionType API provides full details of the supported options for a given connection type in Glue

Description

The describe_connection_type API provides full details of the supported options for a given connection type in Glue. The response includes authentication configuration details that show supported authentication types and properties, and RestConfiguration for custom REST-based connection types registered via register_connection_type.

See https://www.paws-r-sdk.com/docs/glue_describe_connection_type/ for full documentation.

Usage

glue_describe_connection_type(ConnectionType)

Arguments

ConnectionType

[required] The name of the connection type to be described.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.