glue_disassociate_glossary_terms: Removes the association of one or more glossary terms from an...

View source: R/glue_operations.R

glue_disassociate_glossary_termsR Documentation

Removes the association of one or more glossary terms from an asset in Glue Data Catalog

Description

Removes the association of one or more glossary terms from an asset in Glue Data Catalog.

See https://www.paws-r-sdk.com/docs/glue_disassociate_glossary_terms/ for full documentation.

Usage

glue_disassociate_glossary_terms(
  AssetIdentifier,
  IterableFormName = NULL,
  ItemIdentifier = NULL,
  GlossaryTermIdentifiers,
  ClientToken = NULL
)

Arguments

AssetIdentifier

[required] The unique identifier of the asset to disassociate glossary terms from.

IterableFormName

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.

ItemIdentifier

The identifier of the item within the iterable form. Required when iterableFormName is specified.

GlossaryTermIdentifiers

[required] The list of glossary term identifiers to disassociate from the asset.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.