View source: R/glue_operations.R
| glue_get_asset | R Documentation |
Retrieves the metadata for an asset in Glue Data Catalog, including its forms, additional attachments, and associated glossary terms.
See https://www.paws-r-sdk.com/docs/glue_get_asset/ for full documentation.
glue_get_asset(Identifier)
Identifier |
[required] The unique identifier of the asset to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.