glue_get_custom_entity_type: Retrieves the details of a custom pattern by specifying its...

View source: R/glue_operations.R

glue_get_custom_entity_typeR Documentation

Retrieves the details of a custom pattern by specifying its name

Description

Retrieves the details of a custom pattern by specifying its name.

See https://www.paws-r-sdk.com/docs/glue_get_custom_entity_type/ for full documentation.

Usage

glue_get_custom_entity_type(Name)

Arguments

Name

[required] The name of the custom pattern that you want to retrieve.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.