glue_get_dashboard_url: Retrieves the URL for the Spark monitoring dashboard for a...

View source: R/glue_operations.R

glue_get_dashboard_urlR Documentation

Retrieves the URL for the Spark monitoring dashboard for a Glue resource

Description

Retrieves the URL for the Spark monitoring dashboard for a Glue resource.

See https://www.paws-r-sdk.com/docs/glue_get_dashboard_url/ for full documentation.

Usage

glue_get_dashboard_url(ResourceId, ResourceType, RequestOrigin = NULL)

Arguments

ResourceId

[required] The unique identifier of the resource for which to retrieve the dashboard URL.

ResourceType

[required] The type of the resource. Valid values are SESSION and JOB.

RequestOrigin

The origin of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.