glue_get_data_catalog_export_configuration: Retrieves the current export configuration for the Glue Data...

View source: R/glue_operations.R

glue_get_data_catalog_export_configurationR Documentation

Retrieves the current export configuration for the Glue Data Catalog

Description

Retrieves the current export configuration for the Glue Data Catalog. The export configuration controls whether catalog metadata is exported to S3 Tables.

See https://www.paws-r-sdk.com/docs/glue_get_data_catalog_export_configuration/ for full documentation.

Usage

glue_get_data_catalog_export_configuration()

paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.