glue_get_dataflow_graph: Transforms a Python script into a directed acyclic graph...

View source: R/glue_operations.R

glue_get_dataflow_graphR Documentation

Transforms a Python script into a directed acyclic graph (DAG)

Description

Transforms a Python script into a directed acyclic graph (DAG).

See https://www.paws-r-sdk.com/docs/glue_get_dataflow_graph/ for full documentation.

Usage

glue_get_dataflow_graph(PythonScript = NULL)

Arguments

PythonScript

The Python script to transform.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.