glue_get_form_type: Retrieves a form type in Glue Data Catalog by its identifier

View source: R/glue_operations.R

glue_get_form_typeR Documentation

Retrieves a form type in Glue Data Catalog by its identifier

Description

Retrieves a form type in Glue Data Catalog by its identifier.

See https://www.paws-r-sdk.com/docs/glue_get_form_type/ for full documentation.

Usage

glue_get_form_type(Identifier)

Arguments

Identifier

[required] The identifier of the form type to retrieve.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.