View source: R/glue_operations.R
| glue_get_glossary_term | R Documentation |
Retrieves a glossary term in Glue Data Catalog by its identifier.
See https://www.paws-r-sdk.com/docs/glue_get_glossary_term/ for full documentation.
glue_get_glossary_term(Identifier)
Identifier |
[required] The unique identifier of the glossary term to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.