glue_get_glue_identity_center_configuration: Retrieves the current Glue Identity Center configuration...

View source: R/glue_operations.R

glue_get_glue_identity_center_configurationR Documentation

Retrieves the current Glue Identity Center configuration details, including the associated Identity Center instance and application information

Description

Retrieves the current Glue Identity Center configuration details, including the associated Identity Center instance and application information.

See https://www.paws-r-sdk.com/docs/glue_get_glue_identity_center_configuration/ for full documentation.

Usage

glue_get_glue_identity_center_configuration()

paws.analytics documentation built on May 30, 2026, 9:16 a.m.