glue_get_integration_table_properties: This API is used to retrieve optional override properties for...

View source: R/glue_operations.R

glue_get_integration_table_propertiesR Documentation

This API is used to retrieve optional override properties for the tables that need to be replicated

Description

This API is used to retrieve optional override properties for the tables that need to be replicated. These properties can include properties for filtering and partition for source and target tables.

See https://www.paws-r-sdk.com/docs/glue_get_integration_table_properties/ for full documentation.

Usage

glue_get_integration_table_properties(ResourceArn, TableName)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

TableName

[required] The name of the table to be replicated.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.