glue_get_materialized_view_refresh_task_run: Get the associated metadata/information for a task run, given...

View source: R/glue_operations.R

glue_get_materialized_view_refresh_task_runR Documentation

Get the associated metadata/information for a task run, given a task run ID

Description

Get the associated metadata/information for a task run, given a task run ID.

See https://www.paws-r-sdk.com/docs/glue_get_materialized_view_refresh_task_run/ for full documentation.

Usage

glue_get_materialized_view_refresh_task_run(
  CatalogId,
  MaterializedViewRefreshTaskRunId
)

Arguments

CatalogId

[required] The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

MaterializedViewRefreshTaskRunId

[required] The identifier for the particular materialized view refresh task run.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.