glue_get_partition: Retrieves information about a specified partition

View source: R/glue_operations.R

glue_get_partitionR Documentation

Retrieves information about a specified partition

Description

Retrieves information about a specified partition.

See https://www.paws-r-sdk.com/docs/glue_get_partition/ for full documentation.

Usage

glue_get_partition(
  CatalogId = NULL,
  DatabaseName,
  TableName,
  PartitionValues,
  AuditContext = NULL
)

Arguments

CatalogId

The ID of the Data Catalog where the partition in question resides. If none is provided, the Amazon Web Services account ID is used by default.

DatabaseName

[required] The name of the catalog database where the partition resides.

TableName

[required] The name of the partition's table.

PartitionValues

[required] The values that define the partition.

AuditContext

A structure containing the Lake Formation audit context.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.