glue_get_table_optimizer: Returns the configuration of all optimizers associated with a...

View source: R/glue_operations.R

glue_get_table_optimizerR Documentation

Returns the configuration of all optimizers associated with a specified table

Description

Returns the configuration of all optimizers associated with a specified table.

See https://www.paws-r-sdk.com/docs/glue_get_table_optimizer/ for full documentation.

Usage

glue_get_table_optimizer(CatalogId, DatabaseName, TableName, Type)

Arguments

CatalogId

[required] The Catalog ID of the table.

DatabaseName

[required] The name of the database in the catalog in which the table resides.

TableName

[required] The name of the table.

Type

[required] The type of table optimizer.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.