glue_get_tags: Retrieves a list of tags associated with a resource

View source: R/glue_operations.R

glue_get_tagsR Documentation

Retrieves a list of tags associated with a resource

Description

Retrieves a list of tags associated with a resource.

See https://www.paws-r-sdk.com/docs/glue_get_tags/ for full documentation.

Usage

glue_get_tags(ResourceArn)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource for which to retrieve tags.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.