View source: R/glue_operations.R
| glue_list_glossaries | R Documentation |
Lists business glossaries in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_list_glossaries/ for full documentation.
glue_list_glossaries(MaxResults = NULL, NextToken = NULL)
MaxResults |
The maximum number of results to return in the response. |
NextToken |
A continuation token, if this is a continuation call. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.