View source: R/glue_operations.R
| glue_list_glossary_terms | R Documentation |
Lists glossary terms within a business glossary in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_list_glossary_terms/ for full documentation.
glue_list_glossary_terms(
GlossaryIdentifier,
MaxResults = NULL,
NextToken = NULL
)
GlossaryIdentifier |
[required] The unique identifier of the glossary whose terms to list. |
MaxResults |
The maximum number of results to return in the response. |
NextToken |
A continuation token, if this is a continuation call. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.