View source: R/glue_operations.R
| glue_list_integration_resource_properties | R Documentation |
List integration resource properties for a single customer. It supports the filters, maxRecords and markers.
See https://www.paws-r-sdk.com/docs/glue_list_integration_resource_properties/ for full documentation.
glue_list_integration_resource_properties(
Marker = NULL,
Filters = NULL,
MaxRecords = NULL
)
Marker |
This is the pagination token for next page, initial value is |
Filters |
A list of filters, supported filter Key is |
MaxRecords |
This is total number of items to be evaluated. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.