glue_list_integration_table_properties: Lists the integration table properties in your account

View source: R/glue_operations.R

glue_list_integration_table_propertiesR Documentation

Lists the integration table properties in your account

Description

Lists the integration table properties in your account. This operation supports filtering and pagination.

See https://www.paws-r-sdk.com/docs/glue_list_integration_table_properties/ for full documentation.

Usage

glue_list_integration_table_properties(
  Marker = NULL,
  Filters = NULL,
  MaxRecords = NULL
)

Arguments

Marker

The pagination token for the next page of results. The initial value is null.

Filters

A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.

MaxRecords

The maximum number of records to return in the response.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.