glue_list_materialized_view_refresh_task_runs: List all task runs for a particular account

View source: R/glue_operations.R

glue_list_materialized_view_refresh_task_runsR Documentation

List all task runs for a particular account

Description

List all task runs for a particular account.

See https://www.paws-r-sdk.com/docs/glue_list_materialized_view_refresh_task_runs/ for full documentation.

Usage

glue_list_materialized_view_refresh_task_runs(
  CatalogId,
  DatabaseName = NULL,
  TableName = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

CatalogId

[required] The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

DatabaseName

The database where the table resides.

TableName

The name of the table for which statistics is generated.

MaxResults

The maximum size of the response.

NextToken

A continuation token, if this is a continuation call.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.