glue_list_usage_profiles: List all the Glue usage profiles

View source: R/glue_operations.R

glue_list_usage_profilesR Documentation

List all the Glue usage profiles

Description

List all the Glue usage profiles.

See https://www.paws-r-sdk.com/docs/glue_list_usage_profiles/ for full documentation.

Usage

glue_list_usage_profiles(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

A continuation token, included if this is a continuation call.

MaxResults

The maximum number of usage profiles to return in a single response.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.