glue_put_asset: Creates or updates an asset in Glue Data Catalog

View source: R/glue_operations.R

glue_put_assetR Documentation

Creates or updates an asset in Glue Data Catalog

Description

Creates or updates an asset in Glue Data Catalog. If the asset already exists, this operation updates it; otherwise, a new asset is created.

See https://www.paws-r-sdk.com/docs/glue_put_asset/ for full documentation.

Usage

glue_put_asset(
  AssetTypeId,
  Identifier,
  Name,
  Description = NULL,
  Forms,
  ClientToken = NULL
)

Arguments

AssetTypeId

[required] The identifier of the asset type for the asset.

Identifier

[required] The unique identifier of the asset. If an asset with this identifier already exists, it is updated.

Name

[required] The name of the asset.

Description

The description of the asset.

Forms

[required] The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.