glue_put_attachment: Attaches a form to an asset or an iterable form item in Glue...

View source: R/glue_operations.R

glue_put_attachmentR Documentation

Attaches a form to an asset or an iterable form item in Glue Data Catalog

Description

Attaches a form to an asset or an iterable form item in Glue Data Catalog. If an attachment with the same name already exists, it is overwritten.

See https://www.paws-r-sdk.com/docs/glue_put_attachment/ for full documentation.

Usage

glue_put_attachment(
  AssetIdentifier,
  IterableFormName = NULL,
  ItemIdentifier = NULL,
  AttachmentName,
  Content,
  FormTypeId,
  ClientToken = NULL
)

Arguments

AssetIdentifier

[required] The unique identifier of the asset to attach the form to.

IterableFormName

The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.

ItemIdentifier

The identifier of the item within the iterable form. Required when iterableFormName is specified.

AttachmentName

[required] The name of the attachment.

Content

[required] The JSON content of the form, conforming to the schema of the specified form type.

FormTypeId

[required] The identifier of the form type for this attachment.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.