glue_put_data_catalog_export_configuration: Creates or updates the export configuration for the Glue Data...

View source: R/glue_operations.R

glue_put_data_catalog_export_configurationR Documentation

Creates or updates the export configuration for the Glue Data Catalog

Description

Creates or updates the export configuration for the Glue Data Catalog. Use this operation to enable or disable the export of catalog metadata to S3 Tables.

See https://www.paws-r-sdk.com/docs/glue_put_data_catalog_export_configuration/ for full documentation.

Usage

glue_put_data_catalog_export_configuration(
  ExportSetting,
  EncryptionConfiguration = NULL,
  ClientToken = NULL
)

Arguments

ExportSetting

[required] The export setting for the data catalog. Specify ENABLED to start exporting catalog metadata to S3 Tables, or DISABLED to stop exporting. This field is required.

EncryptionConfiguration

The encryption configuration for the exported data. If not specified, the default encryption settings are used.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.