glue_put_data_quality_profile_annotation: Annotate all datapoints for a Profile

View source: R/glue_operations.R

glue_put_data_quality_profile_annotationR Documentation

Annotate all datapoints for a Profile

Description

Annotate all datapoints for a Profile.

See https://www.paws-r-sdk.com/docs/glue_put_data_quality_profile_annotation/ for full documentation.

Usage

glue_put_data_quality_profile_annotation(ProfileId, InclusionAnnotation)

Arguments

ProfileId

[required] The ID of the data quality monitoring profile to annotate.

InclusionAnnotation

[required] The inclusion annotation value to apply to the profile.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.