Puts the metadata key value pair for a specified schema version ID. A maximum of 10 key value pairs will be allowed per schema version. They can be added over one or more calls.
glue_put_schema_version_metadata(SchemaId, SchemaVersionNumber,
SchemaVersionId, MetadataKeyValue)The unique ID for the schema.
The version number of the schema.
The unique version ID of the schema version.
[required] The metadata key's corresponding value.
A list with the following syntax:
list( SchemaArn = "string", SchemaName = "string", RegistryName = "string", LatestVersion = TRUE|FALSE, VersionNumber = 123, SchemaVersionId = "string", MetadataKey = "string", MetadataValue = "string" )
svc$put_schema_version_metadata(
SchemaId = list(
SchemaArn = "string",
SchemaName = "string",
RegistryName = "string"
),
SchemaVersionNumber = list(
LatestVersion = TRUE|FALSE,
VersionNumber = 123
),
SchemaVersionId = "string",
MetadataKeyValue = list(
MetadataKey = "string",
MetadataValue = "string"
)
)