glue_search_assets: Searches for assets in Glue Data Catalog using full-text...

View source: R/glue_operations.R

glue_search_assetsR Documentation

Searches for assets in Glue Data Catalog using full-text search, filters, sorting, and aggregations

Description

Searches for assets in Glue Data Catalog using full-text search, filters, sorting, and aggregations. Returns matching assets with relevance-ranked results.

See https://www.paws-r-sdk.com/docs/glue_search_assets/ for full documentation.

Usage

glue_search_assets(
  SearchText = NULL,
  MaxResults = NULL,
  NextToken = NULL,
  Sort = NULL,
  FilterClause = NULL
)

Arguments

SearchText

The text to search for. At least one of searchText or filterClause must be provided.

MaxResults

The maximum number of results to return in the response.

NextToken

A continuation token, if this is a continuation call.

Sort

The sort criteria for the search results.

FilterClause

The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.