glue_start_column_statistics_task_run_schedule: Starts a column statistics task run schedule

View source: R/glue_operations.R

glue_start_column_statistics_task_run_scheduleR Documentation

Starts a column statistics task run schedule

Description

Starts a column statistics task run schedule.

See https://www.paws-r-sdk.com/docs/glue_start_column_statistics_task_run_schedule/ for full documentation.

Usage

glue_start_column_statistics_task_run_schedule(DatabaseName, TableName)

Arguments

DatabaseName

[required] The name of the database where the table resides.

TableName

[required] The name of the table for which to start a column statistic task run schedule.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.