glue_start_materialized_view_refresh_task_run: Starts a materialized view refresh task run, for a specified...

View source: R/glue_operations.R

glue_start_materialized_view_refresh_task_runR Documentation

Starts a materialized view refresh task run, for a specified table and columns

Description

Starts a materialized view refresh task run, for a specified table and columns.

See https://www.paws-r-sdk.com/docs/glue_start_materialized_view_refresh_task_run/ for full documentation.

Usage

glue_start_materialized_view_refresh_task_run(
  CatalogId,
  DatabaseName,
  TableName,
  FullRefresh = NULL
)

Arguments

CatalogId

[required] The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.

DatabaseName

[required] The name of the database where the table resides.

TableName

[required] The name of the table to generate run the materialized view refresh task.

FullRefresh

Specifies whether this is a full refresh of the task run.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.