glue_update_asset: Updates the name and description of an existing asset in Glue...

View source: R/glue_operations.R

glue_update_assetR Documentation

Updates the name and description of an existing asset in Glue Data Catalog

Description

Updates the name and description of an existing asset in Glue Data Catalog. Only the fields that you provide are updated.

See https://www.paws-r-sdk.com/docs/glue_update_asset/ for full documentation.

Usage

glue_update_asset(
  Identifier,
  Name = NULL,
  Description = NULL,
  ClientToken = NULL
)

Arguments

Identifier

[required] The unique identifier of the asset to update.

Name

The new name of the asset.

Description

The new description of the asset.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.