View source: R/glue_operations.R
| glue_update_glossary_term | R Documentation |
Updates a glossary term in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_update_glossary_term/ for full documentation.
glue_update_glossary_term(
Identifier,
Name = NULL,
ShortDescription = NULL,
LongDescription = NULL,
ClientToken = NULL
)
Identifier |
[required] The unique identifier of the glossary term to update. |
Name |
The updated name of the glossary term. |
ShortDescription |
The updated short description of the glossary term. |
LongDescription |
The updated long description of the glossary term. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.