glue_update_glue_identity_center_configuration: Updates the existing Glue Identity Center configuration,...

View source: R/glue_operations.R

glue_update_glue_identity_center_configurationR Documentation

Updates the existing Glue Identity Center configuration, allowing modification of scopes and permissions for the integration

Description

Updates the existing Glue Identity Center configuration, allowing modification of scopes and permissions for the integration.

See https://www.paws-r-sdk.com/docs/glue_update_glue_identity_center_configuration/ for full documentation.

Usage

glue_update_glue_identity_center_configuration(
  Scopes = NULL,
  UserBackgroundSessionsEnabled = NULL
)

Arguments

Scopes

A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.

UserBackgroundSessionsEnabled

Specifies whether users can run background sessions when using Identity Center authentication with Glue services.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.