View source: R/glue_operations.R
| glue_update_table | R Documentation |
Updates a metadata table in the Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_update_table/ for full documentation.
glue_update_table(
CatalogId = NULL,
DatabaseName,
Name = NULL,
TableInput = NULL,
SkipArchive = NULL,
TransactionId = NULL,
VersionId = NULL,
ViewUpdateAction = NULL,
Force = NULL,
UpdateOpenTableFormatInput = NULL
)
CatalogId |
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default. |
DatabaseName |
[required] The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase. |
Name |
The unique identifier for the table within the specified database that will be created in the Glue Data Catalog. |
TableInput |
An updated |
SkipArchive |
By default, |
TransactionId |
The transaction ID at which to update the table contents. |
VersionId |
The version ID at which to update the table contents. |
ViewUpdateAction |
The operation to be performed when updating the view. |
Force |
A flag that can be set to true to ignore matching storage descriptor and subobject matching requirements. |
UpdateOpenTableFormatInput |
Input parameters for updating open table format tables in GlueData Catalog, serving as a wrapper for format-specific update operations such as Apache Iceberg. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.