gluedatabrew_send_project_session_action: Performs a recipe step within an interactive DataBrew session...

View source: R/gluedatabrew_operations.R

gluedatabrew_send_project_session_actionR Documentation

Performs a recipe step within an interactive DataBrew session that's currently open

Description

Performs a recipe step within an interactive DataBrew session that's currently open.

See https://www.paws-r-sdk.com/docs/gluedatabrew_send_project_session_action/ for full documentation.

Usage

gluedatabrew_send_project_session_action(
  Preview = NULL,
  Name,
  RecipeStep = NULL,
  StepIndex = NULL,
  ClientSessionId = NULL,
  ViewFrame = NULL
)

Arguments

Preview

If true, the result of the recipe step will be returned, but not applied.

Name

[required] The name of the project to apply the action to.

RecipeStep

Represents a single step from a DataBrew recipe to be performed.

StepIndex

The index from which to preview a step. This index is used to preview the result of steps that have already been applied, so that the resulting view frame is from earlier in the view frame stack.

ClientSessionId

A unique identifier for an interactive session that's currently open and ready for work. The action will be performed on this session.

ViewFrame

Represents the data being transformed during an action.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.