gluedatabrew_update_dataset: Modifies the definition of an existing DataBrew dataset

View source: R/gluedatabrew_operations.R

gluedatabrew_update_datasetR Documentation

Modifies the definition of an existing DataBrew dataset

Description

Modifies the definition of an existing DataBrew dataset.

See https://www.paws-r-sdk.com/docs/gluedatabrew_update_dataset/ for full documentation.

Usage

gluedatabrew_update_dataset(
  Name,
  Format = NULL,
  FormatOptions = NULL,
  Input,
  PathOptions = NULL
)

Arguments

Name

[required] The name of the dataset to be updated.

Format

The file format of a dataset that is created from an Amazon S3 file or folder.

FormatOptions

Represents a set of options that define the structure of either comma-separated value (CSV), Excel, or JSON input.

Input

[required] Represents information on how DataBrew can find data, in either the Glue Data Catalog or Amazon S3.

PathOptions

A set of options that defines how DataBrew interprets an Amazon S3 path of the dataset.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.