healthlake_create_data_transformation_profile: Creates a data transformation profile in DRAFT state

View source: R/healthlake_operations.R

healthlake_create_data_transformation_profileR Documentation

Creates a data transformation profile in DRAFT state

Description

Creates a data transformation profile in DRAFT state. Specify a built-in starter profile, an existing profile version, raw profile content, or a sample data file as the source.

See https://www.paws-r-sdk.com/docs/healthlake_create_data_transformation_profile/ for full documentation.

Usage

healthlake_create_data_transformation_profile(
  SourceFormat,
  Source,
  KmsKeyId = NULL,
  ProfileDescription = NULL,
  ProfileName,
  Tags = NULL,
  ClientToken = NULL
)

Arguments

SourceFormat

[required] The source data format that this profile converts from (Consolidated Clinical Document Architecture (C-CDA) or Comma-separated values (CSV)).

[required] The source for the initial profile content. Specify a built-in starter profile, an existing profile version to clone, raw profile content for CI/CD workflows, or a sample data file in Amazon S3.

KmsKeyId

The Amazon Web Services Key Management Service (Amazon Web Services KMS) key identifier used to encrypt the profile content at rest.

ProfileDescription

A human-readable description of the profile's purpose.

ProfileName

[required] A name for the data transformation profile.

Tags

The tags to associate with the profile at creation time.

ClientToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.