healthlake_create_fhir_datastore: Create a FHIR-enabled data store

View source: R/healthlake_operations.R

healthlake_create_fhir_datastoreR Documentation

Create a FHIR-enabled data store

Description

Create a FHIR-enabled data store.

See https://www.paws-r-sdk.com/docs/healthlake_create_fhir_datastore/ for full documentation.

Usage

healthlake_create_fhir_datastore(
  DatastoreName = NULL,
  DatastoreTypeVersion,
  SseConfiguration = NULL,
  PreloadDataConfig = NULL,
  ClientToken = NULL,
  Tags = NULL,
  IdentityProviderConfiguration = NULL
)

Arguments

DatastoreName

The data store name (user-generated).

DatastoreTypeVersion

[required] The FHIR release version supported by the data store. Current support is for version R4.

SseConfiguration

The server-side encryption key configuration for a customer-provided encryption key specified for creating a data store.

PreloadDataConfig

An optional parameter to preload (import) open source Synthea FHIR data upon creation of the data store.

ClientToken

An optional user-provided token to ensure API idempotency.

Tags

The resource tags applied to a data store when it is created.

IdentityProviderConfiguration

The identity provider configuration to use for the data store.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.