healthlake_delete_data_transformation_profile: Deletes a data transformation profile and all its versions,...

View source: R/healthlake_operations.R

healthlake_delete_data_transformation_profileR Documentation

Deletes a data transformation profile and all its versions, including the DRAFT and all published versions

Description

Deletes a data transformation profile and all its versions, including the DRAFT and all published versions.

See https://www.paws-r-sdk.com/docs/healthlake_delete_data_transformation_profile/ for full documentation.

Usage

healthlake_delete_data_transformation_profile(ProfileId)

Arguments

ProfileId

[required] The unique identifier of the profile to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.