View source: R/healthlake_operations.R
| healthlake_describe_data_transformation_job | R Documentation |
Describes a data transformation job, including its current status, configuration, and progress information.
See https://www.paws-r-sdk.com/docs/healthlake_describe_data_transformation_job/ for full documentation.
healthlake_describe_data_transformation_job(JobId)
JobId |
[required] The unique identifier of the data transformation job to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.