healthlake_describe_fhir_import_job: Get the import job properties to learn more about the job or...

View source: R/healthlake_operations.R

healthlake_describe_fhir_import_jobR Documentation

Get the import job properties to learn more about the job or job progress

Description

Get the import job properties to learn more about the job or job progress.

See https://www.paws-r-sdk.com/docs/healthlake_describe_fhir_import_job/ for full documentation.

Usage

healthlake_describe_fhir_import_job(DatastoreId, JobId)

Arguments

DatastoreId

[required] The data store identifier.

JobId

[required] The import job identifier.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.