View source: R/healthlake_operations.R
| healthlake_list_data_transformation_jobs | R Documentation |
Lists data transformation jobs for your Amazon Web Services account. Results can be filtered by status, job name, and submit time window. Results are paginated. Use the NextToken parameter to retrieve additional results.
See https://www.paws-r-sdk.com/docs/healthlake_list_data_transformation_jobs/ for full documentation.
healthlake_list_data_transformation_jobs(
MaxResults = NULL,
NextToken = NULL,
JobStatus = NULL,
JobName = NULL,
SubmittedAfter = NULL,
SubmittedBefore = NULL
)
MaxResults |
The maximum number of jobs to return per page. If you don't specify a value, the service returns up to 100 results. |
NextToken |
The pagination token from a previous response. Pass this value to retrieve the next page of results. |
JobStatus |
Filters the results to include only jobs with the specified status. |
JobName |
Filters the results to include only jobs with the specified name. |
SubmittedAfter |
Filters the results to include only jobs submitted at or after this timestamp. |
SubmittedBefore |
Filters the results to include only jobs submitted at or before this timestamp. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.