healthlake_list_data_transformation_profile_versions: Lists all versions of a specific data transformation profile...

View source: R/healthlake_operations.R

healthlake_list_data_transformation_profile_versionsR Documentation

Lists all versions of a specific data transformation profile (DRAFT and published), in reverse chronological order (newest first)

Description

Lists all versions of a specific data transformation profile (DRAFT and published), in reverse chronological order (newest first). Use get_data_transformation_profile to retrieve profile content. Results are paginated. Use the NextToken parameter to retrieve additional results.

See https://www.paws-r-sdk.com/docs/healthlake_list_data_transformation_profile_versions/ for full documentation.

Usage

healthlake_list_data_transformation_profile_versions(
  ProfileId,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

ProfileId

[required] The unique identifier of the profile whose versions to list.

MaxResults

The maximum number of profile versions to return per page. If you don't specify a value, the service returns up to 100 results.

NextToken

The pagination token from a previous response. Pass this value to retrieve the next page of results.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.