View source: R/healthlake_operations.R
| healthlake_list_data_transformation_profiles | R Documentation |
Lists all data transformation profiles in your account, returning the latest version summary for each. Use get_data_transformation_profile to retrieve profile content. Results are paginated. Use the NextToken parameter to retrieve additional results.
See https://www.paws-r-sdk.com/docs/healthlake_list_data_transformation_profiles/ for full documentation.
healthlake_list_data_transformation_profiles(
SourceFormat,
MaxResults = NULL,
NextToken = NULL
)
SourceFormat |
[required] Filters the results by source data format. |
MaxResults |
The maximum number of profiles to return per page. If you don't specify a value, the service returns up to 100 results. |
NextToken |
The pagination token from a previous response. Pass this value to retrieve the next page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.