healthlake_list_fhir_datastores: List all FHIR-enabled data stores in a user’s account,...

View source: R/healthlake_operations.R

healthlake_list_fhir_datastoresR Documentation

List all FHIR-enabled data stores in a user’s account, regardless of data store status

Description

List all FHIR-enabled data stores in a user’s account, regardless of data store status.

See https://www.paws-r-sdk.com/docs/healthlake_list_fhir_datastores/ for full documentation.

Usage

healthlake_list_fhir_datastores(
  Filter = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

Filter

List all filters associated with a FHIR data store request.

NextToken

The token used to retrieve the next page of data stores when results are paginated.

MaxResults

The maximum number of data stores returned on a page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.