View source: R/healthlake_operations.R
| healthlake_list_fhir_export_jobs | R Documentation |
Lists all FHIR export jobs associated with an account and their statuses.
See https://www.paws-r-sdk.com/docs/healthlake_list_fhir_export_jobs/ for full documentation.
healthlake_list_fhir_export_jobs(
DatastoreId,
NextToken = NULL,
MaxResults = NULL,
JobName = NULL,
JobStatus = NULL,
SubmittedBefore = NULL,
SubmittedAfter = NULL
)
DatastoreId |
[required] Limits the response to the export job with the specified data store ID. |
NextToken |
A pagination token used to identify the next page of results to return. |
MaxResults |
Limits the number of results returned for a ListFHIRExportJobs to a maximum quantity specified by the user. |
JobName |
Limits the response to the export job with the specified job name. |
JobStatus |
Limits the response to export jobs with the specified job status. |
SubmittedBefore |
Limits the response to FHIR export jobs submitted before a user- specified date. |
SubmittedAfter |
Limits the response to FHIR export jobs submitted after a user-specified date. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.