healthlake_list_fhir_import_jobs: List all FHIR import jobs associated with an account and...

View source: R/healthlake_operations.R

healthlake_list_fhir_import_jobsR Documentation

List all FHIR import jobs associated with an account and their statuses

Description

List all FHIR import jobs associated with an account and their statuses.

See https://www.paws-r-sdk.com/docs/healthlake_list_fhir_import_jobs/ for full documentation.

Usage

healthlake_list_fhir_import_jobs(
  DatastoreId,
  NextToken = NULL,
  MaxResults = NULL,
  JobName = NULL,
  JobStatus = NULL,
  SubmittedBefore = NULL,
  SubmittedAfter = NULL
)

Arguments

DatastoreId

[required] Limits the response to the import job with the specified data store ID.

NextToken

The pagination token used to identify the next page of results to return.

MaxResults

Limits the number of results returned for list_fhir_import_jobs to a maximum quantity specified by the user.

JobName

Limits the response to the import job with the specified job name.

JobStatus

Limits the response to the import job with the specified job status.

SubmittedBefore

Limits the response to FHIR import jobs submitted before a user- specified date.

SubmittedAfter

Limits the response to FHIR import jobs submitted after a user-specified date.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.