healthlake_publish_data_transformation_profile: Promotes the current DRAFT version of a data transformation...

View source: R/healthlake_operations.R

healthlake_publish_data_transformation_profileR Documentation

Promotes the current DRAFT version of a data transformation profile to a new immutable published version

Description

Promotes the current DRAFT version of a data transformation profile to a new immutable published version. Also supports rollback by publishing from a previously published version.

See https://www.paws-r-sdk.com/docs/healthlake_publish_data_transformation_profile/ for full documentation.

Usage

healthlake_publish_data_transformation_profile(
  ProfileId,
  SourceFormat,
  FromExistingVersion = NULL,
  ChangeDescription = NULL
)

Arguments

ProfileId

[required] The unique identifier of the profile to publish.

SourceFormat

[required] The source data format of the profile.

FromExistingVersion

The version number of a previously published version to republish as the new latest version. Use this parameter for rollback scenarios. If you omit this parameter, the service publishes the current DRAFT version.

ChangeDescription

A description of what changed or why this version is being published.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.