View source: R/healthlake_operations.R
| healthlake_start_data_transformation_job | R Documentation |
Starts an asynchronous data transformation job that converts source files from Amazon Simple Storage Service (Amazon S3) and writes the output to Amazon S3 or HealthLake.
See https://www.paws-r-sdk.com/docs/healthlake_start_data_transformation_job/ for full documentation.
healthlake_start_data_transformation_job(
InputDataConfig,
OutputDataConfig,
DataAccessRoleArn,
ClientToken,
JobName = NULL,
ProfileId,
DriftDetectionEnabled = NULL,
ProvenanceEnabled = NULL
)
InputDataConfig |
[required] The Amazon S3 location and format of the source files to transform. |
OutputDataConfig |
[required] The Amazon S3 output location and Amazon Web Services Key Management Service (Amazon Web Services KMS) encryption configuration. |
DataAccessRoleArn |
[required] The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that HealthLake assumes to read from and write to the specified Amazon S3 locations. |
ClientToken |
[required] A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error. |
JobName |
A descriptive name for the data transformation job. |
ProfileId |
[required] The unique identifier of the data transformation profile to use for conversion. |
DriftDetectionEnabled |
Specifies whether drift detection is enabled for this job. When enabled, HealthLake writes a drift report to the output Amazon S3 location alongside the converted files. |
ProvenanceEnabled |
Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job. When provenance is enabled, the service also generates related DocumentReference and Device resources. If you don't specify a value, the default is |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.