healthlake_start_fhir_export_job: Start a FHIR export job

View source: R/healthlake_operations.R

healthlake_start_fhir_export_jobR Documentation

Start a FHIR export job

Description

Start a FHIR export job.

See https://www.paws-r-sdk.com/docs/healthlake_start_fhir_export_job/ for full documentation.

Usage

healthlake_start_fhir_export_job(
  JobName = NULL,
  OutputDataConfig,
  DatastoreId,
  DataAccessRoleArn,
  ClientToken = NULL
)

Arguments

JobName

The export job name.

OutputDataConfig

[required] The output data configuration supplied when the export job was started.

DatastoreId

[required] The data store identifier from which files are being exported.

DataAccessRoleArn

[required] The Amazon Resource Name (ARN) used during initiation of the export job.

ClientToken

An optional user provided token used for ensuring API idempotency.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.