healthlake_tag_resource: Add a user-specifed key and value tag to a data store

View source: R/healthlake_operations.R

healthlake_tag_resourceR Documentation

Add a user-specifed key and value tag to a data store

Description

Add a user-specifed key and value tag to a data store.

See https://www.paws-r-sdk.com/docs/healthlake_tag_resource/ for full documentation.

Usage

healthlake_tag_resource(ResourceARN, Tags)

Arguments

ResourceARN

[required] The Amazon Resource Name (ARN) that grants access to the data store tags are being added to.

Tags

[required] The user-specified key and value pair tags being added to a data store.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.