healthlake_untag_resource: Remove a user-specifed key and value tag from a data store

View source: R/healthlake_operations.R

healthlake_untag_resourceR Documentation

Remove a user-specifed key and value tag from a data store

Description

Remove a user-specifed key and value tag from a data store.

See https://www.paws-r-sdk.com/docs/healthlake_untag_resource/ for full documentation.

Usage

healthlake_untag_resource(ResourceARN, TagKeys)

Arguments

ResourceARN

[required] The Amazon Resource Name (ARN) of the data store from which tags are being removed.

TagKeys

[required] The keys for the tags to be removed from the data store.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.