healthlake_update_data_transformation_profile: Updates the DRAFT version (version 0) of a data...

View source: R/healthlake_operations.R

healthlake_update_data_transformation_profileR Documentation

Updates the DRAFT version (version 0) of a data transformation profile with new profile content

Description

Updates the DRAFT version (version 0) of a data transformation profile with new profile content. The update replaces all existing DRAFT content.

See https://www.paws-r-sdk.com/docs/healthlake_update_data_transformation_profile/ for full documentation.

Usage

healthlake_update_data_transformation_profile(
  ProfileId,
  ProfileMapping,
  ChangeDescription = NULL
)

Arguments

ProfileId

[required] The unique identifier of the profile to update.

ProfileMapping

[required] The new profile content for the DRAFT version. This is a full replacement of all profile files.

ChangeDescription

A description of what changed in this update.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.