ivs_create_ad_configuration: Creates a new ad configuration to be used for server-side ad...

View source: R/ivs_operations.R

ivs_create_ad_configurationR Documentation

Creates a new ad configuration to be used for server-side ad insertion

Description

Creates a new ad configuration to be used for server-side ad insertion.

See https://www.paws-r-sdk.com/docs/ivs_create_ad_configuration/ for full documentation.

Usage

ivs_create_ad_configuration(
  name = NULL,
  mediaTailorPlaybackConfigurations,
  tags = NULL
)

Arguments

name

Ad configuration name. Defaults to “”.

mediaTailorPlaybackConfigurations

[required] List of integration configurations with media tailor resources.

tags

Array of 1-50 maps, each of the form string:string (key:value). See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.