ivs_create_stream_key: Creates a stream key, used to initiate a stream, for the...

View source: R/ivs_operations.R

ivs_create_stream_keyR Documentation

Creates a stream key, used to initiate a stream, for the specified channel ARN

Description

Creates a stream key, used to initiate a stream, for the specified channel ARN.

See https://www.paws-r-sdk.com/docs/ivs_create_stream_key/ for full documentation.

Usage

ivs_create_stream_key(channelArn, tags = NULL)

Arguments

channelArn

[required] ARN of the channel for which to create the stream key.

tags

Array of 1-50 maps, each of the form string:string (key:value). See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.