ivs_delete_channel: Deletes the specified channel and its associated stream keys

View source: R/ivs_operations.R

ivs_delete_channelR Documentation

Deletes the specified channel and its associated stream keys

Description

Deletes the specified channel and its associated stream keys.

See https://www.paws-r-sdk.com/docs/ivs_delete_channel/ for full documentation.

Usage

ivs_delete_channel(arn)

Arguments

arn

[required] ARN of the channel to be deleted.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.