ivs_get_ad_configuration: Gets the ad configuration represented by the specified ARN

View source: R/ivs_operations.R

ivs_get_ad_configurationR Documentation

Gets the ad configuration represented by the specified ARN

Description

Gets the ad configuration represented by the specified ARN.

See https://www.paws-r-sdk.com/docs/ivs_get_ad_configuration/ for full documentation.

Usage

ivs_get_ad_configuration(arn)

Arguments

arn

[required] ARN of the ad configuration to be retrieved.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.