ivs_get_channel: Gets the channel configuration for the specified channel ARN

View source: R/ivs_operations.R

ivs_get_channelR Documentation

Gets the channel configuration for the specified channel ARN

Description

Gets the channel configuration for the specified channel ARN. See also batch_get_channel.

See https://www.paws-r-sdk.com/docs/ivs_get_channel/ for full documentation.

Usage

ivs_get_channel(arn)

Arguments

arn

[required] ARN of the channel for which the configuration is to be retrieved.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.