ivs_insert_ad_break: Inserts an ad marker in the playlist for the specified...

View source: R/ivs_operations.R

ivs_insert_ad_breakR Documentation

Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel

Description

Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.

See https://www.paws-r-sdk.com/docs/ivs_insert_ad_break/ for full documentation.

Usage

ivs_insert_ad_break(channelArn, durationSeconds)

Arguments

channelArn

[required] ARN of the channel into which the ad break is inserted.

durationSeconds

[required] Maximum duration of the ad break, in seconds.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.