ivs_list_stream_sessions: Gets a summary of current and previous streams for a...

View source: R/ivs_operations.R

ivs_list_stream_sessionsR Documentation

Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed

Description

Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.

See https://www.paws-r-sdk.com/docs/ivs_list_stream_sessions/ for full documentation.

Usage

ivs_list_stream_sessions(channelArn, nextToken = NULL, maxResults = NULL)

Arguments

channelArn

[required] Channel ARN used to filter the list.

nextToken

The first stream to retrieve. This is used for pagination; see the nextToken response field.

maxResults

Maximum number of streams to return. Default: 100.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.