ivs_untag_resource: Removes tags from the resource with the specified ARN

View source: R/ivs_operations.R

ivs_untag_resourceR Documentation

Removes tags from the resource with the specified ARN

Description

Removes tags from the resource with the specified ARN.

See https://www.paws-r-sdk.com/docs/ivs_untag_resource/ for full documentation.

Usage

ivs_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] ARN of the resource for which tags are to be removed. The ARN must be URL-encoded.

tagKeys

[required] Array of tag keys (strings) for the tags to be removed. See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.