ivs_update_ad_configuration: Updates a specified ad configuration

View source: R/ivs_operations.R

ivs_update_ad_configurationR Documentation

Updates a specified ad configuration

Description

Updates a specified ad configuration.

See https://www.paws-r-sdk.com/docs/ivs_update_ad_configuration/ for full documentation.

Usage

ivs_update_ad_configuration(
  arn,
  name = NULL,
  mediaTailorPlaybackConfigurations = NULL,
  postRollConfiguration = NULL
)

Arguments

arn

[required] ARN of the ad configuration to be updated.

name

Ad configuration name. The value does not need to be unique.

mediaTailorPlaybackConfigurations

List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see Generate and Sign IVS Playback Tokens.

postRollConfiguration

Configuration for the post-roll ad break to use for this ad configuration.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.