Updates a channel's configuration. Live channels cannot be updated. You must stop the ongoing stream, update the channel, and restart the stream for the changes to take effect.
See https://www.paws-r-sdk.com/docs/ivs_update_channel/ for full documentation.
ivs_update_channel(
arn,
authorized = NULL,
insecureIngest = NULL,
latencyMode = NULL,
name = NULL,
preset = NULL,
recordingConfigurationArn = NULL,
type = NULL
)[required] ARN of the channel to be updated.
Whether the channel is private (enabled for playback authorization).
Whether the channel allows insecure RTMP ingest. Default: false.
Channel latency mode. Use NORMAL to broadcast and deliver live video
up to Full HD. Use LOW for near-real-time interaction with viewers.
(Note: In the Amazon IVS console, LOW and NORMAL correspond to
Ultra-low and Standard, respectively.)
Channel name.
Optional transcode preset for the channel. This is selectable only for
ADVANCED_HD and ADVANCED_SD channel types. For those channel types,
the default preset is HIGHER_BANDWIDTH_DELIVERY. For other channel
types (BASIC and STANDARD), preset is the empty string ("").
Recording-configuration ARN. If this is set to an empty string, recording is disabled. A value other than an empty string indicates that recording is enabled
Channel type, which determines the allowable resolution and bitrate. If
you exceed the allowable input resolution or bitrate, the stream
probably will disconnect immediately. Default: STANDARD. For details,
see Channel Types.