ivsrealtime_delete_ingest_configuration: Deletes a specified IngestConfiguration, so it can no longer...

View source: R/ivsrealtime_operations.R

ivsrealtime_delete_ingest_configurationR Documentation

Deletes a specified IngestConfiguration, so it can no longer be used to broadcast

Description

Deletes a specified IngestConfiguration, so it can no longer be used to broadcast. An IngestConfiguration cannot be deleted if the publisher is actively streaming to a stage, unless force is set to true.

See https://www.paws-r-sdk.com/docs/ivsrealtime_delete_ingest_configuration/ for full documentation.

Usage

ivsrealtime_delete_ingest_configuration(arn, force = NULL)

Arguments

arn

[required] ARN of the IngestConfiguration.

force

Optional field to force deletion of the IngestConfiguration. If this is set to true when a participant is actively publishing, the participant is disconnected from the stage, followed by deletion of the IngestConfiguration. Default: false.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.