Learn R Programming

paws.analytics (version 0.5.0)

ivsrealtime_disconnect_participant: Disconnects a specified participant and revokes the participant permanently from a specified stage

Description

Disconnects a specified participant and revokes the participant permanently from a specified stage.

See https://www.paws-r-sdk.com/docs/ivsrealtime_disconnect_participant/ for full documentation.

Usage

ivsrealtime_disconnect_participant(participantId, reason = NULL, stageArn)

Arguments

participantId

[required] Identifier of the participant to be disconnected. This is assigned by IVS and returned by create_participant_token.

reason

Description of why this participant is being disconnected.

stageArn

[required] ARN of the stage to which the participant is attached.