Import a public key to be used for signing stage participant tokens.
See https://www.paws-r-sdk.com/docs/ivsrealtime_import_public_key/ for full documentation.
ivsrealtime_import_public_key(publicKeyMaterial, name = NULL, tags = NULL)[required] The content of the public key to be imported.
Name of the public key to be imported.
Tags attached to the resource. Array of maps, each of the form
string:string (key:value). See Best practices and strategies
in Tagging AWS Resources and Tag Editor for details, including
restrictions that apply to tags and "Tag naming limits and
requirements"; Amazon IVS has no constraints on tags beyond what is
documented there.