Gets summary information about all Compositions in your account, in the AWS region where the API request is processed.
See https://www.paws-r-sdk.com/docs/ivsrealtime_list_compositions/ for full documentation.
ivsrealtime_list_compositions(
filterByEncoderConfigurationArn = NULL,
filterByStageArn = NULL,
maxResults = NULL,
nextToken = NULL
)Filters the Composition list to match the specified EncoderConfiguration attached to at least one of its output.
Filters the Composition list to match the specified Stage ARN.
Maximum number of results to return. Default: 100.
The first Composition to retrieve. This is used for pagination; see the
nextToken response field.