Learn R Programming

paws.analytics (version 0.6.0)

ivsrealtime_list_participant_events: Lists events for a specified participant that occurred during a specified stage session

Description

Lists events for a specified participant that occurred during a specified stage session.

See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participant_events/ for full documentation.

Usage

ivsrealtime_list_participant_events(
  maxResults = NULL,
  nextToken = NULL,
  participantId,
  sessionId,
  stageArn
)

Arguments

maxResults

Maximum number of results to return. Default: 50.

nextToken

The first participant event to retrieve. This is used for pagination; see the nextToken response field.

participantId

[required] Unique identifier for this participant. This is assigned by IVS and returned by create_participant_token.

sessionId

[required] ID of a session within the stage.

stageArn

[required] Stage ARN.