ivsrealtime_list_participant_replicas: Lists all the replicas for a participant from a source stage

View source: R/ivsrealtime_operations.R

ivsrealtime_list_participant_replicasR Documentation

Lists all the replicas for a participant from a source stage

Description

Lists all the replicas for a participant from a source stage.

See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participant_replicas/ for full documentation.

Usage

ivsrealtime_list_participant_replicas(
  sourceStageArn,
  participantId,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

sourceStageArn

[required] ARN of the stage where the participant is publishing.

participantId

[required] Participant ID of the publisher that has been replicated. This is assigned by IVS and returned by create_participant_token or the jti (JWT ID) used to create a self signed token.

nextToken

The first participant to retrieve. This is used for pagination; see the nextToken response field.

maxResults

Maximum number of results to return. Default: 50.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.