Lists all participants in a specified stage session.
See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participants/ for full documentation.
ivsrealtime_list_participants(
stageArn,
sessionId,
filterByUserId = NULL,
filterByPublished = NULL,
filterByState = NULL,
nextToken = NULL,
maxResults = NULL,
filterByRecordingState = NULL
)[required] Stage ARN.
[required] ID of the session within the stage.
Filters the response list to match the specified user ID. Only one of
filterByUserId, filterByPublished, filterByState, or
filterByRecordingState can be provided per request. A userId is a
customer-assigned name to help identify the token; this can be used to
link a participant to a user in the customer’s own systems.
Filters the response list to only show participants who published during
the stage session. Only one of filterByUserId, filterByPublished,
filterByState, or filterByRecordingState can be provided per
request.
Filters the response list to only show participants in the specified
state. Only one of filterByUserId, filterByPublished,
filterByState, or filterByRecordingState can be provided per
request.
The first participant to retrieve. This is used for pagination; see the
nextToken response field.
Maximum number of results to return. Default: 50.
Filters the response list to only show participants with the specified
recording state. Only one of filterByUserId, filterByPublished,
filterByState, or filterByRecordingState can be provided per
request.