ivsrealtime_stop_participant_replication: Stops a replicated participant session

View source: R/ivsrealtime_operations.R

ivsrealtime_stop_participant_replicationR Documentation

Stops a replicated participant session

Description

Stops a replicated participant session.

See https://www.paws-r-sdk.com/docs/ivsrealtime_stop_participant_replication/ for full documentation.

Usage

ivsrealtime_stop_participant_replication(
  sourceStageArn,
  destinationStageArn,
  participantId
)

Arguments

sourceStageArn

[required] ARN of the stage where the participant is publishing.

destinationStageArn

[required] ARN of the stage where the participant has been replicated.

participantId

[required] Participant ID of the publisher that has been replicated. This is assigned by IVS and returned by create_participant_token or the jti (JWT ID) used to create a self signed token.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.