ivsrealtime_untag_resource: Removes tags from the resource with the specified ARN

View source: R/ivsrealtime_operations.R

ivsrealtime_untag_resourceR Documentation

Removes tags from the resource with the specified ARN

Description

Removes tags from the resource with the specified ARN.

See https://www.paws-r-sdk.com/docs/ivsrealtime_untag_resource/ for full documentation.

Usage

ivsrealtime_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] The ARN of the resource to be untagged. The ARN must be URL-encoded.

tagKeys

[required] Array of tag keys (strings) for the tags to be removed. See Best practices and strategies in Tagging AWS Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no constraints on tags beyond what is documented there.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.