kafka_create_channel: Creates a Channel that streams records from an Amazon MSK...

View source: R/kafka_operations.R

kafka_create_channelR Documentation

Creates a Channel that streams records from an Amazon MSK Express cluster topic to Amazon S3 or Apache Iceberg

Description

Creates a Channel that streams records from an Amazon MSK Express cluster topic to Amazon S3 or Apache Iceberg.

See https://www.paws-r-sdk.com/docs/kafka_create_channel/ for full documentation.

Usage

kafka_create_channel(
  ChannelName,
  ClusterArn,
  EncryptionConfiguration = NULL,
  IcebergDestinationConfiguration = NULL,
  S3DestinationConfiguration = NULL,
  Tags = NULL,
  TopicConfigurationList,
  LoggingInfo = NULL
)

Arguments

ChannelName

[required] The name of the channel. Must be unique within the cluster.

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

EncryptionConfiguration

The encryption configuration applied to the channel.

IcebergDestinationConfiguration

The Apache Iceberg destination for the channel. Mutually exclusive with s3DestinationConfiguration.

S3DestinationConfiguration

The Amazon S3 destination for the channel. Mutually exclusive with icebergDestinationConfiguration.

Tags

The tags attached to the channel.

TopicConfigurationList

[required] The list of topic configurations for the channel. Currently exactly one topic must be specified.

LoggingInfo

The destinations to which the channel publishes operational logs.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.