kafka_describe_channel: Returns the current configuration and state of a channel

View source: R/kafka_operations.R

kafka_describe_channelR Documentation

Returns the current configuration and state of a channel

Description

Returns the current configuration and state of a channel.

See https://www.paws-r-sdk.com/docs/kafka_describe_channel/ for full documentation.

Usage

kafka_describe_channel(ChannelArn, ClusterArn)

Arguments

ChannelArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the channel.

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.