kafka_describe_topic: Returns topic details of this topic on a MSK cluster

View source: R/kafka_operations.R

kafka_describe_topicR Documentation

Returns topic details of this topic on a MSK cluster

Description

Returns topic details of this topic on a MSK cluster.

See https://www.paws-r-sdk.com/docs/kafka_describe_topic/ for full documentation.

Usage

kafka_describe_topic(ClusterArn, TopicName)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

TopicName

[required] The Kafka topic name that uniquely identifies the topic.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.