kafka_describe_topic_partitions: Returns partition details of this topic on a MSK cluster

View source: R/kafka_operations.R

kafka_describe_topic_partitionsR Documentation

Returns partition details of this topic on a MSK cluster

Description

Returns partition details of this topic on a MSK cluster.

See https://www.paws-r-sdk.com/docs/kafka_describe_topic_partitions/ for full documentation.

Usage

kafka_describe_topic_partitions(
  ClusterArn,
  TopicName,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

TopicName

[required] The Kafka topic name that uniquely identifies the topic.

MaxResults

The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.

NextToken

The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.