kafka_list_channels: Returns the list of channels in a cluster

View source: R/kafka_operations.R

kafka_list_channelsR Documentation

Returns the list of channels in a cluster

Description

Returns the list of channels in a cluster.

See https://www.paws-r-sdk.com/docs/kafka_list_channels/ for full documentation.

Usage

kafka_list_channels(
  ClusterArn,
  MaxResults = NULL,
  NextToken = NULL,
  TopicNameFilter = NULL
)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

MaxResults

Maximum number of channels to return in a single response.

NextToken

If the response of ListChannels is truncated, it returns a nextToken in the response. This nextToken should be sent in the subsequent request to ListChannels.

TopicNameFilter

Filters results to channels whose topic name matches the specified value.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.