kafka_list_topics: List topics in a MSK cluster

View source: R/kafka_operations.R

kafka_list_topicsR Documentation

List topics in a MSK cluster

Description

List topics in a MSK cluster.

See https://www.paws-r-sdk.com/docs/kafka_list_topics/ for full documentation.

Usage

kafka_list_topics(
  ClusterArn,
  MaxResults = NULL,
  NextToken = NULL,
  TopicNameFilter = NULL
)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

MaxResults

The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.

NextToken

The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request.

TopicNameFilter

Returns topics starting with given name.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.