kafka_update_channel: Updates the destination configuration of an existing channel

View source: R/kafka_operations.R

kafka_update_channelR Documentation

Updates the destination configuration of an existing channel

Description

Updates the destination configuration of an existing channel. Exactly one of icebergDestinationUpdate or s3DestinationUpdate must be supplied.

See https://www.paws-r-sdk.com/docs/kafka_update_channel/ for full documentation.

Usage

kafka_update_channel(
  ChannelArn,
  ClusterArn,
  IcebergDestinationUpdate = NULL,
  S3DestinationUpdate = NULL
)

Arguments

ChannelArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the channel.

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

IcebergDestinationUpdate

Updates fields on an Apache Iceberg destination. Use only when the channel was created with an Iceberg destination.

S3DestinationUpdate

Updates fields on an Amazon S3 destination. Use only when the channel was created with an Amazon S3 destination.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.