kafka_update_rebalancing: Use this resource to update the intelligent rebalancing...

View source: R/kafka_operations.R

kafka_update_rebalancingR Documentation

Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers

Description

Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.

See https://www.paws-r-sdk.com/docs/kafka_update_rebalancing/ for full documentation.

Usage

kafka_update_rebalancing(ClusterArn, CurrentVersion, Rebalancing)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) of the cluster.

CurrentVersion

[required] The current version of the cluster.

Rebalancing

[required] Specifies if intelligent rebalancing should be turned on for your cluster. The default intelligent rebalancing status is ACTIVE for all new MSK Provisioned clusters that you create with Express brokers.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.