kafka_update_topic: Updates the configuration of the specified topic

View source: R/kafka_operations.R

kafka_update_topicR Documentation

Updates the configuration of the specified topic

Description

Updates the configuration of the specified topic.

See https://www.paws-r-sdk.com/docs/kafka_update_topic/ for full documentation.

Usage

kafka_update_topic(
  ClusterArn,
  TopicName,
  Configs = NULL,
  PartitionCount = NULL
)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster.

TopicName

[required] The name of the topic to update configuration for.

Configs

The new topic configurations encoded as a Base64 string.

PartitionCount

The new total number of partitions for the topic.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.