kafkaconnect_list_tags_for_resource: Lists all the tags attached to the specified resource

View source: R/kafkaconnect_operations.R

kafkaconnect_list_tags_for_resourceR Documentation

Lists all the tags attached to the specified resource

Description

Lists all the tags attached to the specified resource.

See https://www.paws-r-sdk.com/docs/kafkaconnect_list_tags_for_resource/ for full documentation.

Usage

kafkaconnect_list_tags_for_resource(resourceArn)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) of the resource for which you want to list all attached tags.


paws.analytics documentation built on April 3, 2025, 11:10 p.m.