kafkaconnect_restart_connector: Restarts the specified connector

View source: R/kafkaconnect_operations.R

kafkaconnect_restart_connectorR Documentation

Restarts the specified connector

Description

Restarts the specified connector. By default, this operation restarts the connector and all of its tasks. This operation is asynchronous and returns a connector operation ARN that you can pass to describe_connector_operation to track the state of the restart.

See https://www.paws-r-sdk.com/docs/kafkaconnect_restart_connector/ for full documentation.

Usage

kafkaconnect_restart_connector(connectorArn, onlyFailedTasks = NULL)

Arguments

connectorArn

[required] The Amazon Resource Name (ARN) of the connector that you want to restart.

onlyFailedTasks

Specifies whether to restart only the connector's failed tasks. If true, the operation restarts only the tasks that are currently in a failed state, and healthy tasks continue running. If false or not specified, the operation restarts the connector and all of its tasks.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.