kafkaconnect_tag_resource: Attaches tags to the specified resource

View source: R/kafkaconnect_operations.R

kafkaconnect_tag_resourceR Documentation

Attaches tags to the specified resource

Description

Attaches tags to the specified resource.

See https://www.paws-r-sdk.com/docs/kafkaconnect_tag_resource/ for full documentation.

Usage

kafkaconnect_tag_resource(resourceArn, tags)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) of the resource to which you want to attach tags.

tags

[required] The tags that you want to attach to the resource.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.