kafkaconnect_update_connector: Updates the specified connector

View source: R/kafkaconnect_operations.R

kafkaconnect_update_connectorR Documentation

Updates the specified connector

Description

Updates the specified connector. For request body, specify only one parameter: either capacity or connectorConfiguration.

See https://www.paws-r-sdk.com/docs/kafkaconnect_update_connector/ for full documentation.

Usage

kafkaconnect_update_connector(
  capacity = NULL,
  connectorConfiguration = NULL,
  connectorArn,
  currentVersion
)

Arguments

capacity

The target capacity.

connectorConfiguration

A map of keys to values that represent the configuration for the connector.

connectorArn

[required] The Amazon Resource Name (ARN) of the connector that you want to update.

currentVersion

[required] The current version of the connector that you want to update.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.