kendra_describe_data_source: Gets information about an Amazon Kendra data source connector

View source: R/kendra_operations.R

kendra_describe_data_sourceR Documentation

Gets information about an Amazon Kendra data source connector

Description

Gets information about an Amazon Kendra data source connector.

See https://www.paws-r-sdk.com/docs/kendra_describe_data_source/ for full documentation.

Usage

kendra_describe_data_source(Id, IndexId)

Arguments

Id

[required] The identifier of the data source connector.

IndexId

[required] The identifier of the index used with the data source connector.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.