kendraranking_delete_rescore_execution_plan: Deletes a rescore execution plan

View source: R/kendraranking_operations.R

kendraranking_delete_rescore_execution_planR Documentation

Deletes a rescore execution plan

Description

Deletes a rescore execution plan. A rescore execution plan is an Amazon Kendra Intelligent Ranking resource used for provisioning the rescore API.

See https://www.paws-r-sdk.com/docs/kendraranking_delete_rescore_execution_plan/ for full documentation.

Usage

kendraranking_delete_rescore_execution_plan(Id)

Arguments

Id

[required] The identifier of the rescore execution plan that you want to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.