kinesis_delete_channel: Deletes the specified channel

View source: R/kinesis_operations.R

kinesis_delete_channelR Documentation

Deletes the specified channel

Description

Deletes the specified channel. Deleting a channel stops delivery from the source stream to the destination. Data already delivered to the destination is not deleted.

See https://www.paws-r-sdk.com/docs/kinesis_delete_channel/ for full documentation.

Usage

kinesis_delete_channel(ChannelARN)

Arguments

ChannelARN

[required] The Amazon Resource Name (ARN) of the channel to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.