To deregister a consumer, provide its ARN. Alternatively, you can
provide the ARN of the data stream and the name you gave the consumer
when you registered it. You may also provide all three parameters, as
long as they don't conflict with each other. If you don't know the name
or ARN of the consumer that you want to deregister, you can use the
list_stream_consumers operation to
get a list of the descriptions of all the consumers that are currently
registered with a given data stream. The description of a consumer
contains its name and ARN.
This operation has a limit of five transactions per second per stream.
kinesis_deregister_stream_consumer(StreamARN, ConsumerName, ConsumerARN)An empty list.
The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
The name that you gave to the consumer.
The ARN returned by Kinesis Data Streams when you registered the consumer. If you don't know the ARN of the consumer that you want to deregister, you can use the ListStreamConsumers operation to get a list of the descriptions of all the consumers that are currently registered with a given data stream. The description of a consumer contains its ARN.
svc$deregister_stream_consumer(
StreamARN = "string",
ConsumerName = "string",
ConsumerARN = "string"
)