kinesis_describe_channel: Describes the specified channel, including its configuration...

View source: R/kinesis_operations.R

kinesis_describe_channelR Documentation

Describes the specified channel, including its configuration and current status

Description

Describes the specified channel, including its configuration and current status.

See https://www.paws-r-sdk.com/docs/kinesis_describe_channel/ for full documentation.

Usage

kinesis_describe_channel(ChannelARN)

Arguments

ChannelARN

[required] The Amazon Resource Name (ARN) of the channel to describe.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.