kinesis_describe_limits: Describes the shard limits and usage for the account

View source: R/kinesis_operations.R

kinesis_describe_limitsR Documentation

Describes the shard limits and usage for the account

Description

Describes the shard limits and usage for the account.

See https://www.paws-r-sdk.com/docs/kinesis_describe_limits/ for full documentation.

Usage

kinesis_describe_limits()

paws.analytics documentation built on May 30, 2026, 9:16 a.m.