To get the description of a registered consumer, provide the ARN of the
consumer. Alternatively, you can provide the ARN of the data stream and
the name you gave the consumer when you registered it. You may also
provide all three parameters, as long as they don't conflict with each
other. If you don't know the name or ARN of the consumer that you want
to describe, you can use the
list_stream_consumers operation to
get a list of the descriptions of all the consumers that are currently
registered with a given data stream.
This operation has a limit of 20 transactions per second per stream.
kinesis_describe_stream_consumer(StreamARN, ConsumerName, ConsumerARN)A list with the following syntax:
list(
ConsumerDescription = list(
ConsumerName = "string",
ConsumerARN = "string",
ConsumerStatus = "CREATING"|"DELETING"|"ACTIVE",
ConsumerCreationTimestamp = as.POSIXct(
"2015-01-01"
),
StreamARN = "string"
)
)
The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
The name that you gave to the consumer.
The ARN returned by Kinesis Data Streams when you registered the consumer.
svc$describe_stream_consumer(
StreamARN = "string",
ConsumerName = "string",
ConsumerARN = "string"
)