kinesis_describe_stream_summary: Provides a summarized description of the specified Kinesis...

View source: R/kinesis_operations.R

kinesis_describe_stream_summaryR Documentation

Provides a summarized description of the specified Kinesis data stream without the shard list

Description

Provides a summarized description of the specified Kinesis data stream without the shard list.

See https://www.paws-r-sdk.com/docs/kinesis_describe_stream_summary/ for full documentation.

Usage

kinesis_describe_stream_summary(
  StreamName = NULL,
  StreamARN = NULL,
  StreamId = NULL
)

Arguments

StreamName

The name of the stream to describe.

StreamARN

The ARN of the stream.

StreamId

Not Implemented. Reserved for future use.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.