kinesis_put_records: Writes multiple data records into a Kinesis data stream in a...

View source: R/kinesis_operations.R

kinesis_put_recordsR Documentation

Writes multiple data records into a Kinesis data stream in a single call (also referred to as a PutRecords request)

Description

Writes multiple data records into a Kinesis data stream in a single call (also referred to as a put_records request). Use this operation to send data into the stream for data ingestion and processing.

See https://www.paws-r-sdk.com/docs/kinesis_put_records/ for full documentation.

Usage

kinesis_put_records(
  Records,
  StreamName = NULL,
  StreamARN = NULL,
  StreamId = NULL
)

Arguments

Records

[required] The records associated with the request.

StreamName

The stream name associated with the request.

StreamARN

The ARN of the stream.

StreamId

Not Implemented. Reserved for future use.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.