kinesis_register_stream_consumer: Registers a consumer with a Kinesis data stream

View source: R/kinesis_operations.R

kinesis_register_stream_consumerR Documentation

Registers a consumer with a Kinesis data stream

Description

Registers a consumer with a Kinesis data stream. When you use this operation, the consumer you register can then call subscribe_to_shard to receive data from the stream using enhanced fan-out, at a rate of up to 2 MiB per second for every shard you subscribe to. This rate is unaffected by the total number of consumers that read from the same stream.

See https://www.paws-r-sdk.com/docs/kinesis_register_stream_consumer/ for full documentation.

Usage

kinesis_register_stream_consumer(
  StreamARN,
  ConsumerName,
  StreamId = NULL,
  Tags = NULL
)

Arguments

StreamARN

[required] The ARN of the Kinesis data stream that you want to register the consumer with. For more info, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces.

ConsumerName

[required] For a given Kinesis data stream, each consumer must have a unique name. However, consumer names don't have to be unique across data streams.

StreamId

Not Implemented. Reserved for future use.

Tags

A set of up to 50 key-value pairs. A tag consists of a required key and an optional value.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.