Removes tags from the specified Kinesis data stream. Removed tags are deleted and cannot be recovered after this operation successfully completes.
kinesis_remove_tags_from_stream(StreamName, TagKeys)[required] The name of the stream.
[required] A list of tag keys. Each corresponding tag is removed from the stream.
svc$remove_tags_from_stream(
StreamName = "string",
TagKeys = list(
"string"
)
)
If you specify a tag that does not exist, it is ignored.
RemoveTagsFromStream has a limit of five transactions per second per account.