kinesis_untag_resource: Removes tags from the specified Kinesis resource

View source: R/kinesis_operations.R

kinesis_untag_resourceR Documentation

Removes tags from the specified Kinesis resource

Description

Removes tags from the specified Kinesis resource. Removed tags are deleted and can't be recovered after this operation completes successfully.

See https://www.paws-r-sdk.com/docs/kinesis_untag_resource/ for full documentation.

Usage

kinesis_untag_resource(TagKeys, ResourceARN, StreamId = NULL)

Arguments

TagKeys

[required] A list of tag key-value pairs. Existing tags of the resource whose keys are members of this list will be removed from the Kinesis resource.

ResourceARN

[required] The Amazon Resource Name (ARN) of the Kinesis resource from which to remove tags.

StreamId

Not Implemented. Reserved for future use.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.