kinesis_update_channel: Updates the data freshness interval or the Amazon CloudWatch...

View source: R/kinesis_operations.R

kinesis_update_channelR Documentation

Updates the data freshness interval or the Amazon CloudWatch Logs configuration of an existing channel

Description

Updates the data freshness interval or the Amazon CloudWatch Logs configuration of an existing channel. You cannot change the destination, source stream, record format, schema, encryption configuration, or service execution role of an existing channel. To change any other setting, delete the channel and create a new one.

See https://www.paws-r-sdk.com/docs/kinesis_update_channel/ for full documentation.

Usage

kinesis_update_channel(
  ChannelARN,
  S3DestinationConfiguration = NULL,
  S3TablesDestinationConfiguration = NULL,
  LoggingConfiguration = NULL
)

Arguments

ChannelARN

[required] The Amazon Resource Name (ARN) of the channel to update.

S3DestinationConfiguration

The updated configuration for a general purpose Amazon S3 destination. Specify this parameter when the channel delivers to a general purpose Amazon S3 bucket. Only DataFreshnessInSeconds can be updated.

S3TablesDestinationConfiguration

The updated configuration for a streaming table destination. Specify this parameter when the channel delivers to streaming tables on Apache Iceberg in Amazon S3 Tables. Only DataFreshnessInSeconds can be updated.

LoggingConfiguration

The updated Amazon CloudWatch Logs configuration for the channel.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.