kinesis_update_max_record_size: This allows you to update the MaxRecordSize of a single...

View source: R/kinesis_operations.R

kinesis_update_max_record_sizeR Documentation

This allows you to update the MaxRecordSize of a single record that you can write to, and read from a stream

Description

This allows you to update the MaxRecordSize of a single record that you can write to, and read from a stream. You can ingest and digest single records up to 10240 KiB.

See https://www.paws-r-sdk.com/docs/kinesis_update_max_record_size/ for full documentation.

Usage

kinesis_update_max_record_size(
  StreamARN = NULL,
  StreamId = NULL,
  MaxRecordSizeInKiB
)

Arguments

StreamARN

The Amazon Resource Name (ARN) of the stream for the MaxRecordSize update.

StreamId

Not Implemented. Reserved for future use.

MaxRecordSizeInKiB

[required] The maximum record size of a single record in KiB that you can write to, and read from a stream. Specify a value between 1024 and 10240 KiB (1 to 10 MiB). If you specify a value that is out of this range, update_max_record_size sends back an ValidationException message.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.