View source: R/kinesis_operations.R
| kinesis_update_stream_mode | R Documentation |
Updates the capacity mode of the data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand capacity mode and a provisioned capacity mode for your data stream.
See https://www.paws-r-sdk.com/docs/kinesis_update_stream_mode/ for full documentation.
kinesis_update_stream_mode(
StreamARN,
StreamId = NULL,
StreamModeDetails,
WarmThroughputMiBps = NULL
)
StreamARN |
[required] Specifies the ARN of the data stream whose capacity mode you want to update. |
StreamId |
Not Implemented. Reserved for future use. |
StreamModeDetails |
[required] Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand capacity mode and a provisioned capacity mode for your data streams. |
WarmThroughputMiBps |
The target warm throughput in MB/s that the stream should be scaled to handle. This represents the throughput capacity that will be immediately available for write operations. This field is only valid when the stream mode is being updated to on-demand. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.