kinesis_update_stream_record_distribution_strategy: Updates the record distribution strategy for the specified...

View source: R/kinesis_operations.R

kinesis_update_stream_record_distribution_strategyR Documentation

Updates the record distribution strategy for the specified Amazon Kinesis Data Streams on-demand data stream

Description

Updates the record distribution strategy for the specified Amazon Kinesis Data Streams on-demand data stream. The record distribution strategy determines how Amazon Kinesis Data Streams distributes records across the shards in a stream.

See https://www.paws-r-sdk.com/docs/kinesis_update_stream_record_distribution_strategy/ for full documentation.

Usage

kinesis_update_stream_record_distribution_strategy(
  StreamARN,
  StreamId = NULL,
  RecordDistributionStrategy
)

Arguments

StreamARN

[required] The Amazon Resource Name (ARN) of the stream to update.

StreamId

Not Implemented. Reserved for future use.

RecordDistributionStrategy

[required] The record distribution strategy to apply to the stream. Specify one of the following values:

  • AUTO – Amazon Kinesis Data Streams distributes records evenly across shards and ignores any partition key and ExplicitHashKey that producers supply.

  • USER_PARTITION_KEY – Producers must supply a partition key, which Amazon Kinesis Data Streams uses to determine shard placement. This is the default.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.