| kinesisanalyticsv2_delete_application_input_processing_configuration | R Documentation |
Deletes an InputProcessingConfiguration from an input.
See https://www.paws-r-sdk.com/docs/kinesisanalyticsv2_delete_application_input_processing_configuration/ for full documentation.
kinesisanalyticsv2_delete_application_input_processing_configuration(
ApplicationName,
CurrentApplicationVersionId,
InputId
)
ApplicationName |
[required] The name of the application. |
CurrentApplicationVersionId |
[required] The application version. You can use the |
InputId |
[required] The ID of the input configuration from which to delete the input processing configuration. You can get a list of the input IDs for an application by using the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.