View source: R/kinesisanalyticsv2_operations.R
| kinesisanalyticsv2_describe_application_operation | R Documentation |
Provides a detailed description of a specified application operation. To see a list of all the operations of an application, invoke the list_application_operations operation.
See https://www.paws-r-sdk.com/docs/kinesisanalyticsv2_describe_application_operation/ for full documentation.
kinesisanalyticsv2_describe_application_operation(ApplicationName, OperationId)
ApplicationName |
[required] The name of the application. |
OperationId |
[required] The operation ID of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.