kinesisanalyticsv2_list_application_operations: Lists all the operations performed for the specified...

View source: R/kinesisanalyticsv2_operations.R

kinesisanalyticsv2_list_application_operationsR Documentation

Lists all the operations performed for the specified application such as UpdateApplication, StartApplication etc

Description

Lists all the operations performed for the specified application such as UpdateApplication, StartApplication etc. The response also includes a summary of the operation.

See https://www.paws-r-sdk.com/docs/kinesisanalyticsv2_list_application_operations/ for full documentation.

Usage

kinesisanalyticsv2_list_application_operations(
  ApplicationName,
  Limit = NULL,
  NextToken = NULL,
  Operation = NULL,
  OperationStatus = NULL
)

Arguments

ApplicationName

[required] The name of the application.

Limit

The limit on the number of records to be returned in the response.

NextToken

A pagination token that can be used in a subsequent request.

Operation

The type of operation that is performed on an application.

OperationStatus

The status of the operation.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.