mturk_get_assignment: The GetAssignment operation retrieves the details of the...

View source: R/mturk_operations.R

mturk_get_assignmentR Documentation

The GetAssignment operation retrieves the details of the specified Assignment

Description

The get_assignment operation retrieves the details of the specified Assignment.

See https://www.paws-r-sdk.com/docs/mturk_get_assignment/ for full documentation.

Usage

mturk_get_assignment(AssignmentId)

Arguments

AssignmentId

[required] The ID of the Assignment to be retrieved.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.