mturk_list_qualification_requests: The ListQualificationRequests operation retrieves requests...

View source: R/mturk_operations.R

mturk_list_qualification_requestsR Documentation

The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type

Description

The list_qualification_requests operation retrieves requests for Qualifications of a particular Qualification type. The owner of the Qualification type calls this operation to poll for pending requests, and accepts them using the AcceptQualification operation.

See https://www.paws-r-sdk.com/docs/mturk_list_qualification_requests/ for full documentation.

Usage

mturk_list_qualification_requests(
  QualificationTypeId = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

QualificationTypeId

The ID of the QualificationType.

NextToken

If the previous response was incomplete (because there is more data to retrieve), Amazon Mechanical Turk returns a pagination token in the response. You can use this pagination token to retrieve the next set of results.

MaxResults

The maximum number of results to return in a single call.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.