The ListReviewPolicyResultsForHIT operation retrieves the computed
results and the actions taken in the course of executing your Review
Policies for a given HIT. For information about how to specify Review
Policies when you call CreateHIT, see Review Policies. The
ListReviewPolicyResultsForHIT operation can return results for both
Assignment-level and HIT-level review results.
mturk_list_review_policy_results_for_hit(HITId, PolicyLevels,
RetrieveActions, RetrieveResults, NextToken, MaxResults)[required] The unique identifier of the HIT to retrieve review results for.
The Policy Level(s) to retrieve review results for - HIT or Assignment. If omitted, the default behavior is to retrieve all data for both policy levels. For a list of all the described policies, see Review Policies.
Specify if the operation should retrieve a list of the actions taken executing the Review Policies and their outcomes.
Specify if the operation should retrieve a list of the results computed by the Review Policies.
Pagination token
Limit the number of results returned.
svc$list_review_policy_results_for_hit(
HITId = "string",
PolicyLevels = list(
"Assignment"|"HIT"
),
RetrieveActions = TRUE|FALSE,
RetrieveResults = TRUE|FALSE,
NextToken = "string",
MaxResults = 123
)