mturk_list_worker_blocks: The ListWorkersBlocks operation retrieves a list of Workers...

View source: R/mturk_operations.R

mturk_list_worker_blocksR Documentation

The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs

Description

The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs.

See https://www.paws-r-sdk.com/docs/mturk_list_worker_blocks/ for full documentation.

Usage

mturk_list_worker_blocks(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

Pagination token


paws.analytics documentation built on May 30, 2026, 9:16 a.m.