The list_workers_with_qualification_type operation returns all of the Workers that have been associated with a given Qualification type.
See https://www.paws-r-sdk.com/docs/mturk_list_workers_with_qualification_type/ for full documentation.
mturk_list_workers_with_qualification_type(
QualificationTypeId,
Status = NULL,
NextToken = NULL,
MaxResults = NULL
)[required] The ID of the Qualification type of the Qualifications to return.
The status of the Qualifications to return. Can be Granted | Revoked.
Pagination Token
Limit the number of results returned.