opensearchingestion_create_pipeline_endpoint: Creates a VPC endpoint for an OpenSearch Ingestion pipeline

View source: R/opensearchingestion_operations.R

opensearchingestion_create_pipeline_endpointR Documentation

Creates a VPC endpoint for an OpenSearch Ingestion pipeline

Description

Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.

See https://www.paws-r-sdk.com/docs/opensearchingestion_create_pipeline_endpoint/ for full documentation.

Usage

opensearchingestion_create_pipeline_endpoint(PipelineArn, VpcOptions)

Arguments

PipelineArn

[required] The Amazon Resource Name (ARN) of the pipeline to create the endpoint for.

VpcOptions

[required] Container for the VPC configuration for the pipeline endpoint, including subnet IDs and security group IDs.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.