opensearchingestion_list_pipeline_blueprints: Retrieves a list of all available blueprints for Data Prepper

View source: R/opensearchingestion_operations.R

opensearchingestion_list_pipeline_blueprintsR Documentation

Retrieves a list of all available blueprints for Data Prepper

Description

Retrieves a list of all available blueprints for Data Prepper. For more information, see Using blueprints to create a pipeline.

See https://www.paws-r-sdk.com/docs/opensearchingestion_list_pipeline_blueprints/ for full documentation.

Usage

opensearchingestion_list_pipeline_blueprints()

paws.analytics documentation built on May 30, 2026, 9:16 a.m.