opensearchingestion_list_pipeline_endpoint_connections: Lists the pipeline endpoints connected to pipelines in your...

View source: R/opensearchingestion_operations.R

opensearchingestion_list_pipeline_endpoint_connectionsR Documentation

Lists the pipeline endpoints connected to pipelines in your account

Description

Lists the pipeline endpoints connected to pipelines in your account.

See https://www.paws-r-sdk.com/docs/opensearchingestion_list_pipeline_endpoint_connections/ for full documentation.

Usage

opensearchingestion_list_pipeline_endpoint_connections(
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MaxResults

The maximum number of pipeline endpoint connections to return in the response.

NextToken

If your initial list_pipeline_endpoint_connections operation returns a nextToken, you can include the returned nextToken in subsequent list_pipeline_endpoint_connections operations, which returns results in the next page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.