opensearchingestion_list_pipeline_endpoints: Lists all pipeline endpoints in your account

View source: R/opensearchingestion_operations.R

opensearchingestion_list_pipeline_endpointsR Documentation

Lists all pipeline endpoints in your account

Description

Lists all pipeline endpoints in your account.

See https://www.paws-r-sdk.com/docs/opensearchingestion_list_pipeline_endpoints/ for full documentation.

Usage

opensearchingestion_list_pipeline_endpoints(
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MaxResults

The maximum number of pipeline endpoints to return in the response.

NextToken

If your initial list_pipeline_endpoints operation returns a NextToken, you can include the returned NextToken in subsequent list_pipeline_endpoints operations, which returns results in the next page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.