opensearchingestion_revoke_pipeline_endpoint_connections: Revokes pipeline endpoints from specified endpoint IDs

View source: R/opensearchingestion_operations.R

opensearchingestion_revoke_pipeline_endpoint_connectionsR Documentation

Revokes pipeline endpoints from specified endpoint IDs

Description

Revokes pipeline endpoints from specified endpoint IDs.

See https://www.paws-r-sdk.com/docs/opensearchingestion_revoke_pipeline_endpoint_connections/ for full documentation.

Usage

opensearchingestion_revoke_pipeline_endpoint_connections(
  PipelineArn,
  EndpointIds
)

Arguments

PipelineArn

[required] The Amazon Resource Name (ARN) of the pipeline from which to revoke endpoint connections.

EndpointIds

[required] A list of endpoint IDs for which to revoke access to the pipeline.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.