opensearchservice_add_direct_query_data_source: Adds a new data source in Amazon OpenSearch Service so that...

View source: R/opensearchservice_operations.R

opensearchservice_add_direct_query_data_sourceR Documentation

Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data

Description

Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data.

See https://www.paws-r-sdk.com/docs/opensearchservice_add_direct_query_data_source/ for full documentation.

Usage

opensearchservice_add_direct_query_data_source(
  DataSourceName,
  DataSourceType,
  Description = NULL,
  OpenSearchArns = NULL,
  DataSourceAccessPolicy = NULL,
  TagList = NULL
)

Arguments

DataSourceName

[required] A unique, user-defined label to identify the data source within your OpenSearch Service environment.

DataSourceType

[required] The supported Amazon Web Services service that you want to use as the source for direct queries in OpenSearch Service.

Description

An optional text field for providing additional context and details about the data source.

OpenSearchArns

An optional list of Amazon Resource Names (ARNs) for the OpenSearch collections that are associated with the direct query data source. This field is required for CloudWatchLogs and SecurityLake datasource types.

DataSourceAccessPolicy

An optional IAM access policy document that defines the permissions for accessing the data source. The policy document must be in valid JSON format and follow IAM policy syntax.

TagList

A list of tags attached to a domain.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.