opensearchservice_associate_packages: Operation in the Amazon OpenSearch Service API for...

View source: R/opensearchservice_operations.R

opensearchservice_associate_packagesR Documentation

Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously

Description

Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously.

See https://www.paws-r-sdk.com/docs/opensearchservice_associate_packages/ for full documentation.

Usage

opensearchservice_associate_packages(PackageList, DomainName)

Arguments

PackageList

[required] A list of packages and their prerequisites to be associated with a domain.

DomainName

[required] The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.