View source: R/opensearchservice_operations.R
| opensearchservice_create_application | R Documentation |
Creates an OpenSearch UI application. For more information, see Using the OpenSearch user interface in Amazon OpenSearch Service.
See https://www.paws-r-sdk.com/docs/opensearchservice_create_application/ for full documentation.
opensearchservice_create_application(
clientToken = NULL,
name,
dataSources = NULL,
iamIdentityCenterOptions = NULL,
appConfigs = NULL,
tagList = NULL,
kmsKeyArn = NULL
)
clientToken |
Unique, case-sensitive identifier to ensure idempotency of the request. |
name |
[required] The unique name of the OpenSearch application. Names must be unique within an Amazon Web Services Region for each account. |
dataSources |
The data sources to link to the OpenSearch application. |
iamIdentityCenterOptions |
Configuration settings for integrating Amazon Web Services IAM Identity Center with the OpenSearch application. |
appConfigs |
Configuration settings for the OpenSearch application, including administrative options. |
tagList |
A list of tags attached to a domain. |
kmsKeyArn |
The Amazon Resource Name (ARN) of the KMS key used to encrypt the application's data at rest. If provided, the application uses your customer-managed key for encryption. If omitted, the application uses an AWS-managed key. The KMS key must be in the same region as the application. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.