opensearchservice_delete_index: Deletes an OpenSearch index

View source: R/opensearchservice_operations.R

opensearchservice_delete_indexR Documentation

Deletes an OpenSearch index

Description

Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.

See https://www.paws-r-sdk.com/docs/opensearchservice_delete_index/ for full documentation.

Usage

opensearchservice_delete_index(DomainName, IndexName)

Arguments

DomainName

[required] The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.

IndexName

[required] The name of the index to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.