opensearchservice_describe_data_source_attachment: Returns the current status and details of a specific data...

View source: R/opensearchservice_operations.R

opensearchservice_describe_data_source_attachmentR Documentation

Returns the current status and details of a specific data source attachment for an OpenSearch application

Description

Returns the current status and details of a specific data source attachment for an OpenSearch application. Throws a ResourceNotFoundException if no attachment record exists for the specified application and data source combination.

See https://www.paws-r-sdk.com/docs/opensearchservice_describe_data_source_attachment/ for full documentation.

Usage

opensearchservice_describe_data_source_attachment(id, dataSourceArn)

Arguments

id

[required] The unique identifier or name of the OpenSearch application.

dataSourceArn

[required] The Amazon Resource Name (ARN) of the domain. See Identifiers for IAM Entities in Using Amazon Web Services Identity and Access Management for more information.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.