opensearchservice_describe_insight_details: Describes the details of an existing insight for an Amazon...

View source: R/opensearchservice_operations.R

opensearchservice_describe_insight_detailsR Documentation

Describes the details of an existing insight for an Amazon OpenSearch Service domain

Description

Describes the details of an existing insight for an Amazon OpenSearch Service domain. Returns detailed fields associated with the specified insight, such as text descriptions and metric data.

See https://www.paws-r-sdk.com/docs/opensearchservice_describe_insight_details/ for full documentation.

Usage

opensearchservice_describe_insight_details(
  Entity,
  InsightId,
  ShowHtmlContent = NULL
)

Arguments

Entity

[required] The entity for which to retrieve insight details. Specifies the type and value of the entity, such as a domain name or Amazon Web Services account ID.

InsightId

[required] The unique identifier of the insight to describe.

ShowHtmlContent

Specifies whether to show response with HTML content in response or not.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.