Describes all packages available to OpenSearch Service. For more information, see Custom packages for Amazon OpenSearch Service.
See https://www.paws-r-sdk.com/docs/opensearchservice_describe_packages/ for full documentation.
opensearchservice_describe_packages(
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)Only returns packages that match the DescribePackagesFilterList
values.
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to get the next page of results.
If your initial DescribePackageFilters operation returns a
nextToken, you can include the returned nextToken in subsequent
DescribePackageFilters operations, which returns results in the next
page.