opensearchservice_detach_data_source: Removes a data source from an OpenSearch application

View source: R/opensearchservice_operations.R

opensearchservice_detach_data_sourceR Documentation

Removes a data source from an OpenSearch application

Description

Removes a data source from an OpenSearch application. The application must be in the ACTIVE state. This operation removes the data source saved object from the application and deletes the attachment record. Throws a ConflictException if the specified data source has a PENDING attachment, and a ResourceNotFoundException if the data source is not currently attached to the application.

See https://www.paws-r-sdk.com/docs/opensearchservice_detach_data_source/ for full documentation.

Usage

opensearchservice_detach_data_source(id, dataSourceArn)

Arguments

id

[required] The unique identifier or name of the OpenSearch application to detach the data source from.

dataSourceArn

[required] The Amazon Resource Name (ARN) of the domain. See Identifiers for IAM Entities in Using Amazon Web Services Identity and Access Management for more information.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.