View source: R/opensearchservice_operations.R
| opensearchservice_get_index | R Documentation |
Retrieves information about an OpenSearch index including its schema and semantic enrichment configuration. Use this operation to view the current index structure and semantic search settings.
See https://www.paws-r-sdk.com/docs/opensearchservice_get_index/ for full documentation.
opensearchservice_get_index(DomainName, IndexName)
DomainName |
[required] The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region. |
IndexName |
[required] The name of the index to retrieve information about. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.