View source: R/opensearchservice_operations.R
| opensearchservice_get_capability | R Documentation |
Retrieves information about a registered capability for an OpenSearch UI application, including its configuration and current status.
See https://www.paws-r-sdk.com/docs/opensearchservice_get_capability/ for full documentation.
opensearchservice_get_capability(applicationId, capabilityName)
applicationId |
[required] The unique identifier of the OpenSearch UI application. |
capabilityName |
[required] The name of the capability to retrieve information about. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.