opensearchservice_get_migration: Retrieves the current status and progress of a migration job,...

View source: R/opensearchservice_operations.R

opensearchservice_get_migrationR Documentation

Retrieves the current status and progress of a migration job, including the number of exported and imported objects and error details if the migration failed

Description

Retrieves the current status and progress of a migration job, including the number of exported and imported objects and error details if the migration failed.

See https://www.paws-r-sdk.com/docs/opensearchservice_get_migration/ for full documentation.

Usage

opensearchservice_get_migration(migrationId)

Arguments

migrationId

[required] The unique identifier of the migration job to retrieve.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.