opensearchservice_insight_feedback: Submits feedback for an existing insight in an Amazon...

View source: R/opensearchservice_operations.R

opensearchservice_insight_feedbackR Documentation

Submits feedback for an existing insight in an Amazon OpenSearch Service domain

Description

Submits feedback for an existing insight in an Amazon OpenSearch Service domain. Allows users to provide a thumbs up or thumbs down rating and optional text feedback for a specific insight.

See https://www.paws-r-sdk.com/docs/opensearchservice_insight_feedback/ for full documentation.

Usage

opensearchservice_insight_feedback(
  Entity,
  InsightId,
  Thumbs,
  FeedbackText = NULL
)

Arguments

Entity

[required] The entity for which to submit insight feedback. Specifies the type and value of the entity, such as a domain name.

InsightId

[required] The unique identifier of the insight for which to submit feedback.

Thumbs

[required] The thumbs up or thumbs down feedback for the insight. Possible values are Up and Down.

FeedbackText

Optional text feedback providing additional details about the insight. Maximum length is 1000 characters.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.