opensearchservice_list_applications: Lists all OpenSearch applications under your account

View source: R/opensearchservice_operations.R

opensearchservice_list_applicationsR Documentation

Lists all OpenSearch applications under your account

Description

Lists all OpenSearch applications under your account.

See https://www.paws-r-sdk.com/docs/opensearchservice_list_applications/ for full documentation.

Usage

opensearchservice_list_applications(
  nextToken = NULL,
  statuses = NULL,
  maxResults = NULL
)

Arguments

nextToken

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.

statuses

Filters the list of OpenSearch applications by status. Possible values: CREATING, UPDATING, DELETING, FAILED, ACTIVE, and DELETED.

maxResults

An optional parameter that specifies the maximum number of results to return for a given request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.