View source: R/opensearchservice_operations.R
| opensearchservice_list_data_source_attachments | R Documentation |
Returns a paginated list of all data source attachments for an OpenSearch application, including attachments in all states (PENDING, ATTACHED, and FAILED).
See https://www.paws-r-sdk.com/docs/opensearchservice_list_data_source_attachments/ for full documentation.
opensearchservice_list_data_source_attachments(
id,
nextToken = NULL,
maxResults = NULL
)
id |
[required] The unique identifier or name of the OpenSearch application to list attachments for. |
nextToken |
The pagination token from a previous call to retrieve the next set of results. |
maxResults |
The maximum number of results to return per page. The default is 50. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.