opensearchservice_list_direct_query_data_sources: Lists an inventory of all the direct query data sources that...

View source: R/opensearchservice_operations.R

opensearchservice_list_direct_query_data_sourcesR Documentation

Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service

Description

Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service.

See https://www.paws-r-sdk.com/docs/opensearchservice_list_direct_query_data_sources/ for full documentation.

Usage

opensearchservice_list_direct_query_data_sources(NextToken = NULL)

Arguments

NextToken

When nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Send the request again using the returned token to retrieve the next page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.