View source: R/opensearchservice_operations.R
| opensearchservice_list_insights | R Documentation |
Lists insights for an Amazon OpenSearch Service domain or Amazon Web Services account. Returns a paginated list of insights based on the specified entity, filters, time range, and sort order.
See https://www.paws-r-sdk.com/docs/opensearchservice_list_insights/ for full documentation.
opensearchservice_list_insights(
Entity,
TimeRange = NULL,
SortOrder = NULL,
MaxResults = NULL,
NextToken = NULL
)
Entity |
[required] The entity for which to list insights. Specifies the type and value of the entity, such as a domain name or Amazon Web Services account ID. |
TimeRange |
The time range for filtering insights, specified as epoch millisecond timestamps. |
SortOrder |
The sort order for the results. Possible values are |
MaxResults |
An optional parameter that specifies the maximum number of results to return. You can use |
NextToken |
If your initial |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.