View source: R/opensearchservice_operations.R
| opensearchservice_list_migrations | R Documentation |
Lists migration jobs for an Amazon OpenSearch Service application. You can filter results by migration status. Use pagination to ensure that the operation returns quickly and successfully.
See https://www.paws-r-sdk.com/docs/opensearchservice_list_migrations/ for full documentation.
opensearchservice_list_migrations(
applicationId,
status = NULL,
maxResults = NULL,
nextToken = NULL
)
applicationId |
[required] The unique identifier of the OpenSearch application to list migrations for. |
status |
Filters the results by migration status. Valid values are |
maxResults |
The maximum number of results to return in a single call. |
nextToken |
The pagination token from a previous call to retrieve the next set of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.