opensearchservice_list_vpc_endpoints: Retrieves all Amazon OpenSearch Service-managed VPC endpoints...

View source: R/opensearchservice_operations.R

opensearchservice_list_vpc_endpointsR Documentation

Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region

Description

Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region.

See https://www.paws-r-sdk.com/docs/opensearchservice_list_vpc_endpoints/ for full documentation.

Usage

opensearchservice_list_vpc_endpoints(NextToken = NULL)

Arguments

NextToken

If your initial list_vpc_endpoints operation returns a nextToken, you can include the returned nextToken in subsequent list_vpc_endpoints operations, which returns results in the next page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.