opensearchservice_list_vpc_endpoints_for_domain: Retrieves all Amazon OpenSearch Service-managed VPC endpoints...

View source: R/opensearchservice_operations.R

opensearchservice_list_vpc_endpoints_for_domainR Documentation

Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain

Description

Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.

See https://www.paws-r-sdk.com/docs/opensearchservice_list_vpc_endpoints_for_domain/ for full documentation.

Usage

opensearchservice_list_vpc_endpoints_for_domain(DomainName, NextToken = NULL)

Arguments

DomainName

[required] The name of the domain to list associated VPC endpoints for.

NextToken

If your initial ListEndpointsForDomain operation returns a nextToken, you can include the returned nextToken in subsequent ListEndpointsForDomain operations, which returns results in the next page.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.