opensearchservice_put_default_application_setting: Sets the default application to the application with the...

View source: R/opensearchservice_operations.R

opensearchservice_put_default_application_settingR Documentation

Sets the default application to the application with the specified ARN

Description

Sets the default application to the application with the specified ARN.

See https://www.paws-r-sdk.com/docs/opensearchservice_put_default_application_setting/ for full documentation.

Usage

opensearchservice_put_default_application_setting(applicationArn, setAsDefault)

Arguments

applicationArn

[required] The Amazon Resource Name (ARN) of the domain. See Identifiers for IAM Entities in Using Amazon Web Services Identity and Access Management for more information.

setAsDefault

[required] Set to true to set the specified ARN as the default application. Set to false to clear the default application.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.