View source: R/opensearchservice_operations.R
| opensearchservice_register_capability | R Documentation |
Registers a capability for an OpenSearch UI application. Use this operation to enable specific capabilities, such as AI features, for a given application. The capability configuration defines the type and settings of the capability to register. For more information about the AI features, see Agentic AI for OpenSearch UI.
See https://www.paws-r-sdk.com/docs/opensearchservice_register_capability/ for full documentation.
opensearchservice_register_capability(
applicationId,
capabilityName,
capabilityConfig
)
applicationId |
[required] The unique identifier of the OpenSearch UI application to register the capability for. |
capabilityName |
[required] The name of the capability to register. Must be between 3 and 30 characters and contain only alphanumeric characters and hyphens. This identifies the type of capability being enabled for the application. For registering AI Assistant capability, use |
capabilityConfig |
[required] The configuration settings for the capability being registered. This includes capability-specific settings such as AI configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.