opensearchservice_rollback_service_software_update: Rolls back a service software update for a domain to the...

View source: R/opensearchservice_operations.R

opensearchservice_rollback_service_software_updateR Documentation

Rolls back a service software update for a domain to the previous version

Description

Rolls back a service software update for a domain to the previous version. For more information, see Service software updates in Amazon OpenSearch Service.

See https://www.paws-r-sdk.com/docs/opensearchservice_rollback_service_software_update/ for full documentation.

Usage

opensearchservice_rollback_service_software_update(DomainName)

Arguments

DomainName

[required] The name of the domain to roll back the service software update on.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.