opensearchservice_start_domain_maintenance: Starts the node maintenance process on the data node

View source: R/opensearchservice_operations.R

opensearchservice_start_domain_maintenanceR Documentation

Starts the node maintenance process on the data node

Description

Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart, or a Dashboard or Kibana restart.

See https://www.paws-r-sdk.com/docs/opensearchservice_start_domain_maintenance/ for full documentation.

Usage

opensearchservice_start_domain_maintenance(DomainName, Action, NodeId = NULL)

Arguments

DomainName

[required] The name of the domain.

Action

[required] The name of the action.

NodeId

The ID of the data node.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.