View source: R/opensearchservice_operations.R
| opensearchservice_start_migration | R Documentation |
Initiates a migration job to migrate saved objects from a data source to an Amazon OpenSearch Service application workspace. Saved objects include dashboards, visualizations, index patterns, and searches. You can specify export filters to control the scope of the migration and a conflict resolution strategy for handling existing objects in the target workspace.
See https://www.paws-r-sdk.com/docs/opensearchservice_start_migration/ for full documentation.
opensearchservice_start_migration(
applicationId,
migrationOptions,
clientToken = NULL
)
applicationId |
[required] The unique identifier of the OpenSearch application to migrate saved objects into. |
migrationOptions |
[required] The configuration options for the migration, including the source data source, target workspace, export filters, and conflict resolution strategy. |
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon OpenSearch Service ignores the request but does not return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.