opensearchservice_update_index: Updates an existing OpenSearch index schema and semantic...

View source: R/opensearchservice_operations.R

opensearchservice_update_indexR Documentation

Updates an existing OpenSearch index schema and semantic enrichment configuration

Description

Updates an existing OpenSearch index schema and semantic enrichment configuration. This operation allows modification of field mappings and semantic search settings for text fields. Changes to semantic enrichment configuration will apply to newly ingested documents.

See https://www.paws-r-sdk.com/docs/opensearchservice_update_index/ for full documentation.

Usage

opensearchservice_update_index(DomainName, IndexName, IndexSchema)

Arguments

DomainName

[required] The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region.

IndexName

[required] The name of the index to update.

IndexSchema

[required] The updated JSON schema for the index including any changes to mappings, settings, and semantic enrichment configuration.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.