opensearchserviceserverless_batch_get_collection: Returns attributes for one or more collections, including the...

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_batch_get_collectionR Documentation

Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints

Description

Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints. For more information, see Creating and managing Amazon OpenSearch Serverless collections.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_batch_get_collection/ for full documentation.

Usage

opensearchserviceserverless_batch_get_collection(ids = NULL, names = NULL)

Arguments

ids

A list of collection IDs. You can't provide names and IDs in the same request. The ID is part of the collection endpoint. You can also retrieve it using the list_collections API.

names

A list of collection names. You can't provide names and IDs in the same request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.