opensearchserviceserverless_create_index: Creates an index within an OpenSearch Serverless collection

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_create_indexR Documentation

Creates an index within an OpenSearch Serverless collection

Description

Creates an index within an OpenSearch Serverless collection. Unlike other OpenSearch indexes, indexes created by this API are automatically configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment in the OpenSearch User Guide.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_create_index/ for full documentation.

Usage

opensearchserviceserverless_create_index(id, indexName, indexSchema = NULL)

Arguments

id

[required] The unique identifier of the collection in which to create the index.

indexName

[required] The name of the index to create. Index names must be lowercase and can't begin with underscores (_) or hyphens (-).

indexSchema

The JSON schema definition for the index, including field mappings and settings.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.