opensearchserviceserverless_delete_index: Deletes an index from an OpenSearch Serverless collection

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_delete_indexR Documentation

Deletes an index from an OpenSearch Serverless collection

Description

Deletes an index from an OpenSearch Serverless collection. Be aware that the index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_delete_index/ for full documentation.

Usage

opensearchserviceserverless_delete_index(id, indexName)

Arguments

id

[required] The unique identifier of the collection containing the index to delete.

indexName

[required] The name of the index to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.