View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_delete_collection_group | R Documentation |
Deletes a collection group. You can only delete empty collection groups that contain no collections. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_delete_collection_group/ for full documentation.
opensearchserviceserverless_delete_collection_group(id, clientToken = NULL)
id |
[required] The unique identifier of the collection group to delete. |
clientToken |
Unique, case-sensitive identifier to ensure idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.