opensearchserviceserverless_get_index: Retrieves information about an index in an OpenSearch...

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_get_indexR Documentation

Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition

Description

Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition. The index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_get_index/ for full documentation.

Usage

opensearchserviceserverless_get_index(id, indexName)

Arguments

id

[required] The unique identifier of the collection containing the index.

indexName

[required] The name of the index to retrieve information about.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.