opensearchserviceserverless_update_index: Updates an existing index in an OpenSearch Serverless...

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_update_indexR Documentation

Updates an existing index in an OpenSearch Serverless collection

Description

Updates an existing index in an OpenSearch Serverless collection. This operation allows you to modify the index schema, including adding new fields or changing field mappings. You can also enable automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_update_index/ for full documentation.

Usage

opensearchserviceserverless_update_index(id, indexName, indexSchema = NULL)

Arguments

id

[required] The unique identifier of the collection containing the index to update.

indexName

[required] The name of the index to update.

indexSchema

The updated JSON schema definition for the index, including field mappings and settings.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.