opensearchserviceserverless_update_account_settings: Update the OpenSearch Serverless settings for the current...

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_update_account_settingsR Documentation

Update the OpenSearch Serverless settings for the current Amazon Web Services account

Description

Update the OpenSearch Serverless settings for the current Amazon Web Services account. For more information, see Managing capacity limits for Amazon OpenSearch Serverless.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_update_account_settings/ for full documentation.

Usage

opensearchserviceserverless_update_account_settings(capacityLimits = NULL)

Arguments

capacityLimits

The maximum capacity limits for all OpenSearch Serverless collections, in OpenSearch Compute Units (OCUs). These limits are used to scale your collections based on the current workload. For more information, see Managing capacity limits for Amazon OpenSearch Serverless.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.