opensearchserviceserverless_update_collection_group: Updates the description and capacity limits of a collection...

View source: R/opensearchserviceserverless_operations.R

opensearchserviceserverless_update_collection_groupR Documentation

Updates the description and capacity limits of a collection group

Description

Updates the description and capacity limits of a collection group.

See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_update_collection_group/ for full documentation.

Usage

opensearchserviceserverless_update_collection_group(
  id,
  description = NULL,
  capacityLimits = NULL,
  clientToken = NULL
)

Arguments

id

[required] The unique identifier of the collection group to update.

description

A new description for the collection group.

capacityLimits

Updated capacity limits for the collection group, in OpenSearch Compute Units (OCUs).

clientToken

Unique, case-sensitive identifier to ensure idempotency of the request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.