quicksight: Amazon QuickSight

View source: R/quicksight_service.R

quicksightR Documentation

Amazon QuickSight

Description

Amazon Quick API Reference

Amazon Quick Sight is a fully managed, serverless business intelligence service for the Amazon Web Services Cloud that makes it easy to extend data and insights to every user in your organization. This API reference contains documentation for a programming interface that you can use to manage Amazon Quick Sight.

Usage

quicksight(
  config = list(),
  credentials = list(),
  endpoint = NULL,
  region = NULL
)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- quicksight(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

batch_create_topic_reviewed_answer Creates new reviewed answers for a Q Topic
batch_delete_topic_reviewed_answer Deletes reviewed answers for Q Topic
cancel_ingestion Cancels an ongoing ingestion of data into SPICE
create_account_customization Creates Amazon Quick Sight customizations
create_account_subscription Creates an Amazon Quick Sight account, or subscribes to Amazon Quick Sight Q
create_action_connector Creates an action connector that enables Amazon Quick Sight to connect to external services and perform actions
create_analysis Creates an analysis in Amazon Quick Sight
create_brand Creates an Quick Sight brand
create_custom_permissions Creates a custom permissions profile
create_dashboard Creates a dashboard from either a template or directly with a DashboardDefinition
create_data_set Creates a dataset
create_data_source Creates a data source
create_folder Creates an empty shared folder
create_folder_membership Adds an asset, such as a dashboard, analysis, or dataset into a folder
create_group Use the CreateGroup operation to create a group in Quick Sight
create_group_membership Adds an Amazon Quick Sight user to an Amazon Quick Sight group
create_iam_policy_assignment Creates an assignment with one specified IAM policy, identified by its Amazon Resource Name (ARN)
create_ingestion Creates and starts a new SPICE ingestion for a dataset
create_namespace (Enterprise edition only) Creates a new namespace for you to use with Amazon Quick Sight
create_refresh_schedule Creates a refresh schedule for a dataset
create_role_membership Use CreateRoleMembership to add an existing Quick Sight group to an existing role
create_template Creates a template either from a TemplateDefinition or from an existing Quick Sight analysis or template
create_template_alias Creates a template alias for a template
create_theme Creates a theme
create_theme_alias Creates a theme alias for a theme
create_topic Creates a new Q topic
create_topic_refresh_schedule Creates a topic refresh schedule
create_vpc_connection Creates a new VPC connection
delete_account_customization This API permanently deletes all Quick Sight customizations for the specified Amazon Web Services account and namespace
delete_account_custom_permission Unapplies a custom permissions profile from an account
delete_account_subscription Deleting your Quick Sight account subscription has permanent, irreversible consequences across all Amazon Web Services regions:
delete_action_connector Hard deletes an action connector, making it unrecoverable
delete_analysis Deletes an analysis from Amazon Quick Sight
delete_brand This API permanently deletes the specified Quick Sight brand
delete_brand_assignment Deletes a brand assignment
delete_custom_permissions Deletes a custom permissions profile
delete_dashboard Deletes a dashboard
delete_data_set Deletes a dataset
delete_data_set_refresh_properties Deletes the dataset refresh properties of the dataset
delete_data_source Deletes the data source permanently
delete_default_q_business_application Deletes a linked Amazon Q Business application from an Quick Sight account
delete_folder Deletes an empty folder
delete_folder_membership Removes an asset, such as a dashboard, analysis, or dataset, from a folder
delete_group Removes a user group from Amazon Quick Sight
delete_group_membership Removes a user from a group so that the user is no longer a member of the group
delete_iam_policy_assignment Deletes an existing IAM policy assignment
delete_identity_propagation_config Deletes all access scopes and authorized targets that are associated with a service from the Quick Sight IAM Identity Center application
delete_namespace Deletes a namespace and the users and groups that are associated with the namespace
delete_refresh_schedule Deletes a refresh schedule from a dataset
delete_role_custom_permission Removes custom permissions from the role
delete_role_membership Removes a group from a role
delete_template Deletes a template
delete_template_alias Deletes the item that the specified template alias points to
delete_theme Deletes a theme
delete_theme_alias Deletes the version of the theme that the specified theme alias points to
delete_topic Deletes a topic
delete_topic_refresh_schedule Deletes a topic refresh schedule
delete_user Deletes the Amazon Quick Sight user that is associated with the identity of the IAM user or role that's making the call
delete_user_by_principal_id Deletes a user identified by its principal ID
delete_user_custom_permission Deletes a custom permissions profile from a user
delete_vpc_connection Deletes a VPC connection
describe_account_customization Describes the customizations associated with the provided Amazon Web Services account and Amazon Quick Sight namespace
describe_account_custom_permission Describes the custom permissions profile that is applied to an account
describe_account_settings Describes the settings that were used when your Quick Sight subscription was first created in this Amazon Web Services account
describe_account_subscription Use the DescribeAccountSubscription operation to receive a description of an Quick Sight account's subscription
describe_action_connector Retrieves detailed information about an action connector, including its configuration, authentication settings, enabled actions, and current status
describe_action_connector_permissions Retrieves the permissions configuration for an action connector, showing which users, groups, and namespaces have access and what operations they can perform
describe_analysis Provides a summary of the metadata for an analysis
describe_analysis_definition Provides a detailed description of the definition of an analysis
describe_analysis_permissions Provides the read and write permissions for an analysis
describe_asset_bundle_export_job Describes an existing export job
describe_asset_bundle_import_job Describes an existing import job
describe_automation_job Retrieves the status and details of a specified automation job, including its status and outputs
describe_brand Describes a brand
describe_brand_assignment Describes a brand assignment
describe_brand_published_version Describes the published version of the brand
describe_custom_permissions Describes a custom permissions profile
describe_dashboard Provides a summary for a dashboard
describe_dashboard_definition Provides a detailed description of the definition of a dashboard
describe_dashboard_permissions Describes read and write permissions for a dashboard
describe_dashboard_snapshot_job Describes an existing snapshot job
describe_dashboard_snapshot_job_result Describes the result of an existing snapshot job that has finished running
describe_dashboards_qa_configuration Describes an existing dashboard QA configuration
describe_data_set Describes a dataset
describe_data_set_permissions Describes the permissions on a dataset
describe_data_set_refresh_properties Describes the refresh properties of a dataset
describe_data_source Describes a data source
describe_data_source_permissions Describes the resource permissions for a data source
describe_default_q_business_application Describes a Amazon Q Business application that is linked to an Quick Sight account
describe_folder Describes a folder
describe_folder_permissions Describes permissions for a folder
describe_folder_resolved_permissions Describes the folder resolved permissions
describe_group Returns an Amazon Quick Sight group's description and Amazon Resource Name (ARN)
describe_group_membership Use the DescribeGroupMembership operation to determine if a user is a member of the specified group
describe_iam_policy_assignment Describes an existing IAM policy assignment, as specified by the assignment name
describe_ingestion Describes a SPICE ingestion
describe_ip_restriction Provides a summary and status of IP rules
describe_key_registration Describes all customer managed key registrations in a Quick Sight account
describe_namespace Describes the current namespace
describe_q_personalization_configuration Describes a personalization configuration
describe_quick_sight_q_search_configuration Describes the state of a Quick Sight Q Search configuration
describe_refresh_schedule Provides a summary of a refresh schedule
describe_role_custom_permission Describes all custom permissions that are mapped to a role
describe_self_upgrade_configuration Describes the self-upgrade configuration for a Quick account
describe_template Describes a template's metadata
describe_template_alias Describes the template alias for a template
describe_template_definition Provides a detailed description of the definition of a template
describe_template_permissions Describes read and write permissions on a template
describe_theme Describes a theme
describe_theme_alias Describes the alias for a theme
describe_theme_permissions Describes the read and write permissions for a theme
describe_topic Describes a topic
describe_topic_permissions Describes the permissions of a topic
describe_topic_refresh Describes the status of a topic refresh
describe_topic_refresh_schedule Deletes a topic refresh schedule
describe_user Returns information about a user, given the user name
describe_vpc_connection Describes a VPC connection
generate_embed_url_for_anonymous_user Generates an embed URL that you can use to embed an Amazon Quick dashboard or visual in your website, without having to register any reader users
generate_embed_url_for_registered_user Generates an embed URL that you can use to embed an Amazon Quick experience in your website
generate_embed_url_for_registered_user_with_identity Generates an embed URL that you can use to embed an Amazon Quick Sight experience in your website
get_dashboard_embed_url Generates a temporary session URL and authorization code(bearer token) that you can use to embed an Amazon Quick Sight read-only dashboard in your website or application
get_flow_metadata Retrieves the metadata of a flow, not including its definition specifying the steps
get_flow_permissions Get permissions for a flow
get_identity_context Retrieves the identity context for a Quick Sight user in a specified namespace, allowing you to obtain identity tokens that can be used with identity-enhanced IAM role sessions to call identity-aware APIs
get_session_embed_url Generates a session URL and authorization code that you can use to embed the Amazon Amazon Quick Sight console in your web server code
list_action_connectors Lists all action connectors in the specified Amazon Web Services account
list_analyses Lists Amazon Quick Sight analyses that exist in the specified Amazon Web Services account
list_asset_bundle_export_jobs Lists all asset bundle export jobs that have been taken place in the last 14 days
list_asset_bundle_import_jobs Lists all asset bundle import jobs that have taken place in the last 14 days
list_brands Lists all brands in an Quick Sight account
list_custom_permissions Returns a list of all the custom permissions profiles
list_dashboards Lists dashboards in an Amazon Web Services account
list_dashboard_versions Lists all the versions of the dashboards in the Amazon Quick Sight subscription
list_data_sets Lists all of the datasets belonging to the current Amazon Web Services account in an Amazon Web Services Region
list_data_sources Lists data sources in current Amazon Web Services Region that belong to this Amazon Web Services account
list_flows Lists flows in an Amazon Web Services account
list_folder_members List all assets (DASHBOARD, ANALYSIS, and DATASET) in a folder
list_folders Lists all folders in an account
list_folders_for_resource List all folders that a resource is a member of
list_group_memberships Lists member users in a group
list_groups Lists all user groups in Amazon Quick Sight
list_iam_policy_assignments Lists the IAM policy assignments in the current Amazon Quick Sight account
list_iam_policy_assignments_for_user Lists all of the IAM policy assignments, including the Amazon Resource Names (ARNs), for the IAM policies assigned to the specified user and group, or groups that the user belongs to
list_identity_propagation_configs Lists all services and authorized targets that the Quick Sight IAM Identity Center application can access
list_ingestions Lists the history of SPICE ingestions for a dataset
list_namespaces Lists the namespaces for the specified Amazon Web Services account
list_refresh_schedules Lists the refresh schedules of a dataset
list_role_memberships Lists all groups that are associated with a role
list_self_upgrades Lists all self-upgrade requests for a Quick account
list_tags_for_resource Lists the tags assigned to a resource
list_template_aliases Lists all the aliases of a template
list_templates Lists all the templates in the current Amazon Quick Sight account
list_template_versions Lists all the versions of the templates in the current Amazon Quick Sight account
list_theme_aliases Lists all the aliases of a theme
list_themes Lists all the themes in the current Amazon Web Services account
list_theme_versions Lists all the versions of the themes in the current Amazon Web Services account
list_topic_refresh_schedules Lists all of the refresh schedules for a topic
list_topic_reviewed_answers Lists all reviewed answers for a Q Topic
list_topics Lists all of the topics within an account
list_user_groups Lists the Amazon Quick Sight groups that an Amazon Quick Sight user is a member of
list_users Returns a list of all of the Amazon Quick Sight users belonging to this account
list_vpc_connections Lists all of the VPC connections in the current set Amazon Web Services Region of an Amazon Web Services account
predict_qa_results Predicts existing visuals or generates new visuals to answer a given query
put_data_set_refresh_properties Creates or updates the dataset refresh properties for the dataset
register_user Creates an Amazon Quick Sight user whose identity is associated with the Identity and Access Management (IAM) identity or role specified in the request
restore_analysis Restores an analysis
search_action_connectors Searches for action connectors in the specified Amazon Web Services account using filters
search_analyses Searches for analyses that belong to the user specified in the filter
search_dashboards Searches for dashboards that belong to a user
search_data_sets Use the SearchDataSets operation to search for datasets that belong to an account
search_data_sources Use the SearchDataSources operation to search for data sources that belong to an account
search_flows Search for the flows in an Amazon Web Services account
search_folders Searches the subfolders in a folder
search_groups Use the SearchGroups operation to search groups in a specified Quick Sight namespace using the supplied filters
search_topics Searches for any Q topic that exists in an Quick account
start_asset_bundle_export_job Starts an Asset Bundle export job
start_asset_bundle_import_job Starts an Asset Bundle import job
start_automation_job Starts a new job for a specified automation
start_dashboard_snapshot_job Starts an asynchronous job that generates a snapshot of a dashboard's output
start_dashboard_snapshot_job_schedule Starts an asynchronous job that runs an existing dashboard schedule and sends the dashboard snapshot through email
tag_resource Assigns one or more tags (key-value pairs) to the specified Amazon Quick Sight resource
untag_resource Removes a tag or tags from a resource
update_account_customization Updates Amazon Quick Sight customizations
update_account_custom_permission Applies a custom permissions profile to an account
update_account_settings Updates the Amazon Quick Sight settings in your Amazon Web Services account
update_action_connector Updates an existing action connector with new configuration details, authentication settings, or enabled actions
update_action_connector_permissions Updates the permissions for an action connector by granting or revoking access for specific users and groups
update_analysis Updates an analysis in Amazon Quick Sight
update_analysis_permissions Updates the read and write permissions for an analysis
update_application_with_token_exchange_grant Updates an Quick application with a token exchange grant
update_brand Updates a brand
update_brand_assignment Updates a brand assignment
update_brand_published_version Updates the published version of a brand
update_custom_permissions Updates a custom permissions profile
update_dashboard Updates a dashboard in an Amazon Web Services account
update_dashboard_links Updates the linked analyses on a dashboard
update_dashboard_permissions Updates read and write permissions on a dashboard
update_dashboard_published_version Updates the published version of a dashboard
update_dashboards_qa_configuration Updates a Dashboard QA configuration
update_data_set Updates a dataset
update_data_set_permissions Updates the permissions on a dataset
update_data_source Updates a data source
update_data_source_permissions Updates the permissions to a data source
update_default_q_business_application Updates a Amazon Q Business application that is linked to a Quick Sight account
update_flow_permissions Updates permissions against principals on a flow
update_folder Updates the name of a folder
update_folder_permissions Updates permissions of a folder
update_group Changes a group description
update_iam_policy_assignment Updates an existing IAM policy assignment
update_identity_propagation_config Adds or updates services and authorized targets to configure what the Quick Sight IAM Identity Center application can access
update_ip_restriction Updates the content and status of IP rules
update_key_registration Updates a customer managed key in a Quick Sight account
update_public_sharing_settings This API controls public sharing settings for your entire Quick Sight account, affecting data security and access
update_q_personalization_configuration Updates a personalization configuration
update_quick_sight_q_search_configuration Updates the state of a Quick Sight Q Search configuration
update_refresh_schedule Updates a refresh schedule for a dataset
update_role_custom_permission Updates the custom permissions that are associated with a role
update_self_upgrade Updates a self-upgrade request for a Quick user by approving, denying, or verifying the request
update_self_upgrade_configuration Updates the self-upgrade configuration for a Quick account
update_spice_capacity_configuration Updates the SPICE capacity configuration for a Quick Sight account
update_template Updates a template from an existing Amazon Quick Sight analysis or another template
update_template_alias Updates the template alias of a template
update_template_permissions Updates the resource permissions for a template
update_theme Updates a theme
update_theme_alias Updates an alias of a theme
update_theme_permissions Updates the resource permissions for a theme
update_topic Updates a topic
update_topic_permissions Updates the permissions of a topic
update_topic_refresh_schedule Updates a topic refresh schedule
update_user Updates an Amazon Quick Sight user
update_user_custom_permission Updates a custom permissions profile for a user
update_vpc_connection Updates a VPC connection

Examples

## Not run: 
svc <- quicksight()
svc$batch_create_topic_reviewed_answer(
  Foo = 123
)

## End(Not run)


paws.analytics documentation built on May 30, 2026, 9:16 a.m.