quicksight_batch_describe_user_limits: Describes the effective resource limits for one or more...

View source: R/quicksight_operations.R

quicksight_batch_describe_user_limitsR Documentation

Describes the effective resource limits for one or more Amazon Quick Sight users, including the limits that apply to each user based on their profile assignments

Description

Describes the effective resource limits for one or more Amazon Quick Sight users, including the limits that apply to each user based on their profile assignments.

See https://www.paws-r-sdk.com/docs/quicksight_batch_describe_user_limits/ for full documentation.

Usage

quicksight_batch_describe_user_limits(
  accountId,
  users = NULL,
  resourceTypes = NULL
)

Arguments

accountId

[required] The ID of the Amazon Web Services account that contains the users.

users

A list of users to describe limits for. Each entry contains a user name and namespace.

resourceTypes

An optional filter that limits the results to specific resource types. If you don't specify a value, the operation returns limits for all resource types.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.