quicksight_create_account_customization: Creates Amazon Quick Sight customizations

View source: R/quicksight_operations.R

quicksight_create_account_customizationR Documentation

Creates Amazon Quick Sight customizations

Description

Creates Amazon Quick Sight customizations. Currently, you can add a custom default theme by using the create_account_customization or update_account_customization API operation. To further customize Amazon Quick Sight by removing Amazon Quick Sight sample assets and videos for all new users, see Customizing Quick Sight in the Amazon Quick Sight User Guide.

See https://www.paws-r-sdk.com/docs/quicksight_create_account_customization/ for full documentation.

Usage

quicksight_create_account_customization(
  AwsAccountId,
  Namespace = NULL,
  AccountCustomization,
  Tags = NULL
)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that you want to customize Quick Sight for.

Namespace

The Quick Sight namespace that you want to add customizations to.

AccountCustomization

[required] The Quick Sight customizations you're adding. You can add these to an Amazon Web Services account and a QuickSight namespace.

For example, you can add a default theme by setting AccountCustomization to the midnight theme: "AccountCustomization": { "DefaultTheme": "arn:aws:quicksight::aws:theme/MIDNIGHT" }. Or, you can add a custom theme by specifying "AccountCustomization": { "DefaultTheme": "arn:aws:quicksight:us-west-2:111122223333:theme/bdb844d0-0fe9-4d9d-b520-0fe602d93639" }.

Tags

A list of the tags that you want to attach to this resource.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.