View source: R/quicksight_operations.R
| quicksight_create_account_subscription | R Documentation |
Creates an Amazon Quick Sight account, or subscribes to Amazon Quick Sight Q.
See https://www.paws-r-sdk.com/docs/quicksight_create_account_subscription/ for full documentation.
quicksight_create_account_subscription(
Edition = NULL,
AuthenticationMethod,
AwsAccountId,
AccountName,
NotificationEmail,
ActiveDirectoryName = NULL,
Realm = NULL,
DirectoryId = NULL,
AdminGroup = NULL,
AuthorGroup = NULL,
ReaderGroup = NULL,
AdminProGroup = NULL,
AuthorProGroup = NULL,
ReaderProGroup = NULL,
FirstName = NULL,
LastName = NULL,
EmailAddress = NULL,
ContactNumber = NULL,
IAMIdentityCenterInstanceArn = NULL
)
Edition |
The edition of Amazon Quick Sight that you want your account to have. Currently, you can choose from If you choose
|
AuthenticationMethod |
[required] The method that you want to use to authenticate your Quick Sight account. If you choose If you choose |
AwsAccountId |
[required] The Amazon Web Services account ID of the account that you're using to create your Quick Sight account. |
AccountName |
[required] The name of your Amazon Quick Sight account. This name is unique over all of Amazon Web Services, and it appears only when users sign in. You can't change |
NotificationEmail |
[required] The email address that you want Quick Sight to send notifications to regarding your Quick Sight account or Quick Sight subscription. |
ActiveDirectoryName |
The name of your Active Directory. This field is required if |
Realm |
The realm of the Active Directory that is associated with your Quick Sight account. This field is required if |
DirectoryId |
The ID of the Active Directory that is associated with your Quick Sight account. |
AdminGroup |
The admin group associated with your Active Directory or IAM Identity Center account. Either this field or the For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
AuthorGroup |
The author group associated with your Active Directory or IAM Identity Center account. For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
ReaderGroup |
The reader group associated with your Active Directory or IAM Identity Center account. For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
AdminProGroup |
The admin pro group associated with your Active Directory or IAM Identity Center account. Either this field or the For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
AuthorProGroup |
The author pro group associated with your Active Directory or IAM Identity Center account. For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
ReaderProGroup |
The reader pro group associated with your Active Directory or IAM Identity Center account. For more information about using IAM Identity Center in Amazon Quick Sight, see Using IAM Identity Center with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see Using Active Directory with Amazon Quick Sight Enterprise Edition in the Amazon Quick Sight User Guide. |
FirstName |
The first name of the author of the Amazon Quick Sight account to use for future communications. This field is required if |
LastName |
The last name of the author of the Amazon Quick Sight account to use for future communications. This field is required if |
EmailAddress |
The email address of the author of the Amazon Quick Sight account to use for future communications. This field is required if |
ContactNumber |
A 10-digit phone number for the author of the Amazon Quick Sight account to use for future communications. This field is required if |
IAMIdentityCenterInstanceArn |
The Amazon Resource Name (ARN) for the IAM Identity Center instance. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.