View source: R/quicksight_operations.R
| quicksight_create_action_connector | R Documentation |
Creates an action connector that enables Amazon Quick Sight to connect to external services and perform actions. Action connectors support various authentication methods and can be configured with specific actions from supported connector types like Amazon S3, Salesforce, JIRA.
See https://www.paws-r-sdk.com/docs/quicksight_create_action_connector/ for full documentation.
quicksight_create_action_connector(
AwsAccountId,
ActionConnectorId,
Name,
Type,
AuthenticationConfig,
Description = NULL,
Permissions = NULL,
VpcConnectionArn = NULL,
Tags = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID associated with the action connector. |
ActionConnectorId |
[required] A unique identifier for the action connector. This ID must be unique within the Amazon Web Services account. The |
Name |
[required] A descriptive name for the action connector. |
Type |
[required] The type of action connector. |
AuthenticationConfig |
[required] The authentication configuration for connecting to the external service. This includes the authentication type, base URL, and authentication metadata such as client credentials or API keys. |
Description |
An optional description of the action connector. |
Permissions |
The permissions configuration that defines which users, groups, or namespaces can access this action connector and what operations they can perform. |
VpcConnectionArn |
The ARN of the VPC connection to use for secure connectivity to the external service. |
Tags |
A list of tags to apply to the action connector for resource management and organization. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.