quicksight_create_agent: Creates an agent in Amazon QuickSight

View source: R/quicksight_operations.R

quicksight_create_agentR Documentation

Creates an agent in Amazon QuickSight

Description

Creates an agent in Amazon QuickSight.

See https://www.paws-r-sdk.com/docs/quicksight_create_agent/ for full documentation.

Usage

quicksight_create_agent(
  Spaces = NULL,
  ActionConnectors = NULL,
  AwsAccountId,
  AgentId,
  Name,
  Description = NULL,
  IconId = NULL,
  StarterPrompts = NULL,
  WelcomeMessage = NULL,
  AgentLifecycle = NULL,
  CustomPromptInput = NULL
)

Arguments

Spaces

The Amazon Resource Names (ARNs) of the spaces to attach to the agent.

ActionConnectors

The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the agent.

AgentId

[required] A unique identifier for the agent.

Name

[required] The name of the agent.

Description

A description of the agent.

IconId

The icon identifier for the agent.

StarterPrompts

A list of starter prompts that are displayed to users when they begin interacting with the agent.

WelcomeMessage

The welcome message that is displayed when a user starts a conversation with the agent.

AgentLifecycle

The lifecycle state of the agent. Valid values are PREVIEW and PUBLISHED.

CustomPromptInput

The custom prompt configuration for the agent.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.