View source: R/quicksight_operations.R
| quicksight_create_analysis | R Documentation |
Creates an analysis in Amazon Quick Sight. Analyses can be created either from a template or from an AnalysisDefinition.
See https://www.paws-r-sdk.com/docs/quicksight_create_analysis/ for full documentation.
quicksight_create_analysis(
AwsAccountId,
AnalysisId,
Name,
Parameters = NULL,
Permissions = NULL,
SourceEntity = NULL,
ThemeArn = NULL,
Tags = NULL,
Definition = NULL,
ValidationStrategy = NULL,
FolderArns = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account where you are creating an analysis. |
AnalysisId |
[required] The ID for the analysis that you're creating. This ID displays in the URL of the analysis. |
Name |
[required] A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon Quick Sight console. |
Parameters |
The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values. |
Permissions |
A structure that describes the principals and the resource-level permissions on an analysis. You can use the To specify no permissions, omit |
SourceEntity |
A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a |
ThemeArn |
The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon Quick Sight console, make sure that you have access to it. |
Tags |
Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis. |
Definition |
The definition of an analysis. A definition is the data model of all features in a Dashboard, Template, or Analysis. Either a |
ValidationStrategy |
The option to relax the validation needed to create an analysis with definition objects. This skips the validation step for specific errors. |
FolderArns |
When you create the analysis, Amazon Quick Sight adds the analysis to these folders. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.