quicksight_create_approval_policy: Creates an approval policy in Quick Sight

View source: R/quicksight_operations.R

quicksight_create_approval_policyR Documentation

Creates an approval policy in Quick Sight

Description

Creates an approval policy in Quick Sight.

See https://www.paws-r-sdk.com/docs/quicksight_create_approval_policy/ for full documentation.

Usage

quicksight_create_approval_policy(
  PolicyId,
  Name,
  Description = NULL,
  Actions,
  AssetTypes,
  ApplicableTo,
  ApprovalGroups
)

Arguments

PolicyId

[required] The unique identifier to assign to the approval policy. You cannot change this value after you create the policy.

Name

[required] The name of the approval policy.

Description

A description of the approval policy.

Actions

[required] The list of governed actions that trigger the approval workflow.

AssetTypes

[required] The list of asset types that the approval policy applies to.

ApplicableTo

[required] The scoping configuration that determines who the approval policy applies to.

ApprovalGroups

[required] The list of group ARNs whose members can approve requests.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.