quicksight_create_dlp_setting: Creates a data loss prevention (DLP) setting configuration...

View source: R/quicksight_operations.R

quicksight_create_dlp_settingR Documentation

Creates a data loss prevention (DLP) setting configuration for an Amazon Web Services account

Description

Creates a data loss prevention (DLP) setting configuration for an Amazon Web Services account. A DLP setting defines the DLP provider, the enforcement behavior, and the Quick capabilities that the setting applies to.

See https://www.paws-r-sdk.com/docs/quicksight_create_dlp_setting/ for full documentation.

Usage

quicksight_create_dlp_setting(
  AwsAccountId,
  DlpSettingId,
  Name,
  ProviderType,
  ProviderConfig,
  ProviderOutageAction,
  Enabled,
  Tags = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account in which to create the DLP setting.

DlpSettingId

[required] A unique identifier for the DLP setting.

Name

[required] A human-readable display name for the DLP setting.

ProviderType

[required] The type of external DLP provider to use for sensitivity label classification. Currently, the only supported value is MICROSOFT_PURVIEW.

ProviderConfig

[required] The provider-specific configuration for the DLP integration. This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

ProviderOutageAction

[required] The behavior to apply when the DLP provider is unreachable. Valid values are ALLOW, WARN, and BLOCK.

Enabled

[required] Specifies whether DLP enforcement is active for this setting. Set to true to enable enforcement, or false to disable it at time of setting creation.

Tags

A list of resource tags to apply to the DLP setting. You can use tags to manage access to your Amazon Web Services resources.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.