quicksight_create_flow: Creates a new flow in the specified Amazon Web Services...

View source: R/quicksight_operations.R

quicksight_create_flowR Documentation

Creates a new flow in the specified Amazon Web Services account

Description

Creates a new flow in the specified Amazon Web Services account. Creates both a DRAFT and PUBLISHED (auto-published) version.

See https://www.paws-r-sdk.com/docs/quicksight_create_flow/ for full documentation.

Usage

quicksight_create_flow(
  AwsAccountId,
  Name,
  Description = NULL,
  FlowDefinition,
  Permissions = NULL,
  ClientToken = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account where you want to create the flow.

Name

[required] The display name for the flow.

Description

The description for the flow.

FlowDefinition

[required] The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow's internal format. The format is subject to change.

Always derive or depend on the flow definition from the describe_flow operation to ensure you are working with the latest format.

Permissions

Initial permissions for the flow. If omitted, the flow is created without any permissions.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.