View source: R/quicksight_operations.R
| quicksight_create_group | R Documentation |
Use the create_group operation to create a group in Quick Sight. You can create up to 10,000 groups in a namespace. If you want to create more than 10,000 groups in a namespace, contact Amazon Web Services Support.
See https://www.paws-r-sdk.com/docs/quicksight_create_group/ for full documentation.
quicksight_create_group(GroupName, Description = NULL, AwsAccountId, Namespace)
GroupName |
[required] A name for the group that you want to create. |
Description |
A description for the group that you want to create. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace that you want the group to be a part of. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.