View source: R/quicksight_operations.R
| quicksight_create_knowledge_base | R Documentation |
Creates a knowledge base from a specified data source. Supported data source connector types include:
See https://www.paws-r-sdk.com/docs/quicksight_create_knowledge_base/ for full documentation.
quicksight_create_knowledge_base(
AwsAccountId,
KnowledgeBaseId,
Name,
DataSourceArn,
KnowledgeBaseConfiguration,
Description = NULL,
Permissions = NULL,
MediaExtractionConfiguration = NULL,
AccessControlConfiguration = NULL,
PrimaryOwnerArn = NULL,
Tags = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the knowledge base. |
KnowledgeBaseId |
[required] The unique identifier for the knowledge base. |
Name |
[required] The name of the knowledge base. |
DataSourceArn |
[required] The Amazon Resource Name (ARN) of the data source for the knowledge base. |
KnowledgeBaseConfiguration |
[required] The configuration settings for a knowledge base. |
Description |
A description for the knowledge base. If you don't specify a description, the knowledge base is created without one. |
Permissions |
A list of resource permissions on the knowledge base. Each entry grants a specified Amazon QuickSight principal either owner or viewer access. If you don't specify permissions, only the primary owner (if provided) receives owner access. |
MediaExtractionConfiguration |
The configuration for media extraction from knowledge base documents. |
AccessControlConfiguration |
The access control configuration for the knowledge base. If you don't specify this parameter, document-level ACLs are disabled. |
PrimaryOwnerArn |
The Amazon Resource Name (ARN) of the Amazon QuickSight user or group to set as the primary owner of the knowledge base. The specified principal is always granted owner access, regardless of what is specified in the This must be an Amazon QuickSight principal ARN, not an IAM user or role ARN. The API caller is never assigned as the owner automatically. If you don't specify a primary owner and don't grant owner access in When you call |
Tags |
The tags to assign to the knowledge base. If you don't specify tags, the knowledge base is created without tags. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.