quicksight_create_limits_profile: Creates a limits profile that defines resource usage limits...

View source: R/quicksight_operations.R

quicksight_create_limits_profileR Documentation

Creates a limits profile that defines resource usage limits for Amazon Quick Sight users

Description

Creates a limits profile that defines resource usage limits for Amazon Quick Sight users.

See https://www.paws-r-sdk.com/docs/quicksight_create_limits_profile/ for full documentation.

Usage

quicksight_create_limits_profile(
  accountId,
  profileName,
  description = NULL,
  resourceLimits,
  clientToken
)

Arguments

accountId

[required] The ID of the Amazon Web Services account that contains the limits profile.

profileName

[required] A display name for the limits profile.

description

A description for the limits profile.

resourceLimits

[required] A map of resource types to their limit values for this profile.

clientToken

[required] A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.