quicksight_create_space: Creates a new Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_create_spaceR Documentation

Creates a new Amazon QuickSight space

Description

Creates a new Amazon QuickSight space. A space is a collection of resources that can be used to organize and manage QuickSight assets.

See https://www.paws-r-sdk.com/docs/quicksight_create_space/ for full documentation.

Usage

quicksight_create_space(AwsAccountId, SpaceId, Name, Description = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Name

[required] A display name for the space.

Description

A description of the space.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.