quicksight_create_topic_v2: Creates a new Q topic

View source: R/quicksight_operations.R

quicksight_create_topic_v2R Documentation

Creates a new Q topic

Description

Creates a new Q topic.

See https://www.paws-r-sdk.com/docs/quicksight_create_topic_v2/ for full documentation.

Usage

quicksight_create_topic_v2(
  AwsAccountId,
  TopicId,
  Topic,
  Tags = NULL,
  FolderArns = NULL,
  CustomInstructions = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that you want to create a topic in.

TopicId

[required] The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Topic

[required] The definition of a topic to create.

Tags

Contains a map of the key-value pairs for the resource tag or tags that are assigned to the topic.

FolderArns

The Amazon Resource Names (ARNs) of the folders that you want the topic to reside in.

CustomInstructions

Instructions that provide additional guidance and context for response generation.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.