quicksight_delete_account_custom_permission: Unapplies a custom permissions profile from an account

View source: R/quicksight_operations.R

quicksight_delete_account_custom_permissionR Documentation

Unapplies a custom permissions profile from an account

Description

Unapplies a custom permissions profile from an account.

See https://www.paws-r-sdk.com/docs/quicksight_delete_account_custom_permission/ for full documentation.

Usage

quicksight_delete_account_custom_permission(AwsAccountId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account from which you want to unapply the custom permissions profile.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.