quicksight_delete_account_customization: This API permanently deletes all Quick Sight customizations...

View source: R/quicksight_operations.R

quicksight_delete_account_customizationR Documentation

This API permanently deletes all Quick Sight customizations for the specified Amazon Web Services account and namespace

Description

This API permanently deletes all Quick Sight customizations for the specified Amazon Web Services account and namespace. When you delete account customizations:

See https://www.paws-r-sdk.com/docs/quicksight_delete_account_customization/ for full documentation.

Usage

quicksight_delete_account_customization(AwsAccountId, Namespace = NULL)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that you want to delete Quick Sight customizations from.

Namespace

The Quick Sight namespace that you're deleting the customizations from.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.