View source: R/quicksight_operations.R
| quicksight_delete_account_subscription | R Documentation |
Deleting your Quick Sight account subscription has permanent, irreversible consequences across all Amazon Web Services regions:
See https://www.paws-r-sdk.com/docs/quicksight_delete_account_subscription/ for full documentation.
quicksight_delete_account_subscription(AwsAccountId)
AwsAccountId |
[required] The Amazon Web Services account ID of the account that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.