quicksight_delete_action_connector: Hard deletes an action connector, making it unrecoverable

View source: R/quicksight_operations.R

quicksight_delete_action_connectorR Documentation

Hard deletes an action connector, making it unrecoverable

Description

Hard deletes an action connector, making it unrecoverable. This operation removes the connector and all its associated configurations. Any resources currently using this action connector will no longer be able to perform actions through it.

See https://www.paws-r-sdk.com/docs/quicksight_delete_action_connector/ for full documentation.

Usage

quicksight_delete_action_connector(AwsAccountId, ActionConnectorId)

Arguments

AwsAccountId

[required] The Amazon Web Services account ID that contains the action connector to delete.

ActionConnectorId

[required] The unique identifier of the action connector to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.