quicksight_delete_app: Deletes an app

View source: R/quicksight_operations.R

quicksight_delete_appR Documentation

Deletes an app

Description

Deletes an app.

See https://www.paws-r-sdk.com/docs/quicksight_delete_app/ for full documentation.

Usage

quicksight_delete_app(AwsAccountId, AppId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the app.

AppId

[required] The ID of the app that you want to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.