quicksight_delete_dlp_setting: Deletes a DLP setting configuration from an Amazon Web...

View source: R/quicksight_operations.R

quicksight_delete_dlp_settingR Documentation

Deletes a DLP setting configuration from an Amazon Web Services account

Description

Deletes a DLP setting configuration from an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_delete_dlp_setting/ for full documentation.

Usage

quicksight_delete_dlp_setting(AwsAccountId, DlpSettingId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the DLP setting that you want to delete.

DlpSettingId

[required] The ID of the DLP setting that you want to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.