quicksight_delete_flow: Permanently deletes a flow from the specified Amazon Web...

View source: R/quicksight_operations.R

quicksight_delete_flowR Documentation

Permanently deletes a flow from the specified Amazon Web Services account

Description

Permanently deletes a flow from the specified Amazon Web Services account. This operation cannot be undone.

See https://www.paws-r-sdk.com/docs/quicksight_delete_flow/ for full documentation.

Usage

quicksight_delete_flow(AwsAccountId, FlowId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow that you are deleting.

FlowId

[required] The unique identifier of the flow to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.