quicksight_delete_group: Removes a user group from Amazon Quick Sight

View source: R/quicksight_operations.R

quicksight_delete_groupR Documentation

Removes a user group from Amazon Quick Sight

Description

Removes a user group from Amazon Quick Sight.

See https://www.paws-r-sdk.com/docs/quicksight_delete_group/ for full documentation.

Usage

quicksight_delete_group(GroupName, AwsAccountId, Namespace)

Arguments

GroupName

[required] The name of the group that you want to delete.

AwsAccountId

[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Namespace

[required] The namespace of the group that you want to delete.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.