View source: R/quicksight_operations.R
| quicksight_delete_group_membership | R Documentation |
Removes a user from a group so that the user is no longer a member of the group.
See https://www.paws-r-sdk.com/docs/quicksight_delete_group_membership/ for full documentation.
quicksight_delete_group_membership(
MemberName,
GroupName,
AwsAccountId,
Namespace
)
MemberName |
[required] The name of the user that you want to delete from the group membership. |
GroupName |
[required] The name of the group that you want to delete the user from. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace of the group that you want to remove a user from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.