quicksight_delete_limits_profile: Deletes a limits profile

View source: R/quicksight_operations.R

quicksight_delete_limits_profileR Documentation

Deletes a limits profile

Description

Deletes a limits profile.

See https://www.paws-r-sdk.com/docs/quicksight_delete_limits_profile/ for full documentation.

Usage

quicksight_delete_limits_profile(profileId, accountId)

Arguments

profileId

[required] The unique identifier for the limits profile to delete.

accountId

[required] The ID of the Amazon Web Services account that contains the limits profile.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.