View source: R/quicksight_operations.R
| quicksight_delete_role_custom_permission | R Documentation |
Removes custom permissions from the role.
See https://www.paws-r-sdk.com/docs/quicksight_delete_role_custom_permission/ for full documentation.
quicksight_delete_role_custom_permission(Role, AwsAccountId, Namespace)
Role |
[required] The role that you want to remove permissions from. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace that includes the role. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.