quicksight_delete_space: Deletes an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_delete_spaceR Documentation

Deletes an Amazon QuickSight space

Description

Deletes an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_delete_space/ for full documentation.

Usage

quicksight_delete_space(AwsAccountId, SpaceId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to delete.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.