quicksight_delete_topic_v2: Deletes a Q topic

View source: R/quicksight_operations.R

quicksight_delete_topic_v2R Documentation

Deletes a Q topic

Description

Deletes a Q topic.

See https://www.paws-r-sdk.com/docs/quicksight_delete_topic_v2/ for full documentation.

Usage

quicksight_delete_topic_v2(AwsAccountId, TopicId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the topic that you want to delete.

TopicId

[required] The ID of the topic that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.