quicksight_delete_user: Deletes the Amazon Quick Sight user that is associated with...

View source: R/quicksight_operations.R

quicksight_delete_userR Documentation

Deletes the Amazon Quick Sight user that is associated with the identity of the IAM user or role that's making the call

Description

Deletes the Amazon Quick Sight user that is associated with the identity of the IAM user or role that's making the call. The IAM user isn't deleted as a result of this call.

See https://www.paws-r-sdk.com/docs/quicksight_delete_user/ for full documentation.

Usage

quicksight_delete_user(UserName, AwsAccountId, Namespace)

Arguments

UserName

[required] The name of the user that you want to delete.

AwsAccountId

[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Namespace

[required] The namespace. Currently, you should set this to default.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.