View source: R/quicksight_operations.R
| quicksight_delete_user_by_principal_id | R Documentation |
Deletes a user identified by its principal ID.
See https://www.paws-r-sdk.com/docs/quicksight_delete_user_by_principal_id/ for full documentation.
quicksight_delete_user_by_principal_id(PrincipalId, AwsAccountId, Namespace)
PrincipalId |
[required] The principal ID of the user. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace. Currently, you should set this to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.