quicksight_describe_account_custom_permission: Describes the custom permissions profile that is applied to...

View source: R/quicksight_operations.R

quicksight_describe_account_custom_permissionR Documentation

Describes the custom permissions profile that is applied to an account

Description

Describes the custom permissions profile that is applied to an account.

See https://www.paws-r-sdk.com/docs/quicksight_describe_account_custom_permission/ for full documentation.

Usage

quicksight_describe_account_custom_permission(AwsAccountId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account for which you want to describe the applied custom permissions profile.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.