quicksight_describe_account_customization: Describes the customizations associated with the provided...

View source: R/quicksight_operations.R

quicksight_describe_account_customizationR Documentation

Describes the customizations associated with the provided Amazon Web Services account and Amazon Quick Sight namespace

Description

Describes the customizations associated with the provided Amazon Web Services account and Amazon Quick Sight namespace. The Quick Sight console evaluates which customizations to apply by running this API operation with the Resolved flag included.

See https://www.paws-r-sdk.com/docs/quicksight_describe_account_customization/ for full documentation.

Usage

quicksight_describe_account_customization(
  AwsAccountId,
  Namespace = NULL,
  Resolved = NULL
)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that you want to describe Quick Sight customizations for.

Namespace

The Quick Sight namespace that you want to describe Quick Sight customizations for.

Resolved

The Resolved flag works with the other parameters to determine which view of Quick Sight customizations is returned. You can add this flag to your command to use the same view that Quick Sight uses to identify which customizations to apply to the console. Omit this flag, or set it to no-resolved, to reveal customizations that are configured at different levels.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.