View source: R/quicksight_operations.R
| quicksight_describe_action_connector | R Documentation |
Retrieves detailed information about an action connector, including its configuration, authentication settings, enabled actions, and current status.
See https://www.paws-r-sdk.com/docs/quicksight_describe_action_connector/ for full documentation.
quicksight_describe_action_connector(AwsAccountId, ActionConnectorId)
AwsAccountId |
[required] The Amazon Web Services account ID that contains the action connector. |
ActionConnectorId |
[required] The unique identifier of the action connector to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.