View source: R/quicksight_operations.R
| quicksight_describe_action_connector_permissions | R Documentation |
Retrieves the permissions configuration for an action connector, showing which users, groups, and namespaces have access and what operations they can perform.
See https://www.paws-r-sdk.com/docs/quicksight_describe_action_connector_permissions/ for full documentation.
quicksight_describe_action_connector_permissions(
AwsAccountId,
ActionConnectorId
)
AwsAccountId |
[required] The Amazon Web Services account ID that contains the action connector. |
ActionConnectorId |
[required] The unique identifier of the action connector whose permissions you want to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.