View source: R/quicksight_operations.R
| quicksight_describe_app | R Documentation |
Describes an app.
See https://www.paws-r-sdk.com/docs/quicksight_describe_app/ for full documentation.
quicksight_describe_app(AwsAccountId, AppId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the app. |
AppId |
[required] The ID of the app that you want to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.