View source: R/quicksight_operations.R
| quicksight_describe_automation_job | R Documentation |
Retrieves the status and details of a specified automation job, including its status and outputs.
See https://www.paws-r-sdk.com/docs/quicksight_describe_automation_job/ for full documentation.
quicksight_describe_automation_job(
AwsAccountId,
AutomationGroupId,
AutomationId,
IncludeInputPayload = NULL,
IncludeOutputPayload = NULL,
JobId
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the automation job. |
AutomationGroupId |
[required] The ID of the automation group that contains the automation. |
AutomationId |
[required] The ID of the automation that the job belongs to. |
IncludeInputPayload |
A Boolean value that indicates whether to include the input payload in the response. If set to |
IncludeOutputPayload |
A Boolean value that indicates whether to include the output payload in the response. If set to |
JobId |
[required] The ID of the automation job to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.