quicksight_describe_default_q_business_application: Describes a Amazon Q Business application that is linked to...

View source: R/quicksight_operations.R

quicksight_describe_default_q_business_applicationR Documentation

Describes a Amazon Q Business application that is linked to an Quick Sight account

Description

Describes a Amazon Q Business application that is linked to an Quick Sight account.

See https://www.paws-r-sdk.com/docs/quicksight_describe_default_q_business_application/ for full documentation.

Usage

quicksight_describe_default_q_business_application(
  AwsAccountId,
  Namespace = NULL
)

Arguments

AwsAccountId

[required] The ID of the Quick Sight account that is linked to the Amazon Q Business application that you want described.

Namespace

The Quick Sight namespace that contains the linked Amazon Q Business application. If this field is left blank, the default namespace is used. Currently, the default namespace is the only valid value for this parameter.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.