quicksight_describe_flow: Returns the full details of a flow for the latest version of...

View source: R/quicksight_operations.R

quicksight_describe_flowR Documentation

Returns the full details of a flow for the latest version of the requested publish state

Description

Returns the full details of a flow for the latest version of the requested publish state.

See https://www.paws-r-sdk.com/docs/quicksight_describe_flow/ for full documentation.

Usage

quicksight_describe_flow(AwsAccountId, FlowId, PublishState)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow that you are describing.

FlowId

[required] The unique identifier of the flow.

PublishState

[required] The publish state of the flow version to describe. Valid values are DRAFT, PUBLISHED, or PENDING_APPROVAL.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.