View source: R/quicksight_operations.R
| quicksight_describe_group | R Documentation |
Returns an Amazon Quick Sight group's description and Amazon Resource Name (ARN).
See https://www.paws-r-sdk.com/docs/quicksight_describe_group/ for full documentation.
quicksight_describe_group(GroupName, AwsAccountId, Namespace)
GroupName |
[required] The name of the group that you want to describe. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace of the group that you want described. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.