View source: R/quicksight_operations.R
| quicksight_describe_group_membership | R Documentation |
Use the describe_group_membership operation to determine if a user is a member of the specified group. If the user exists and is a member of the specified group, an associated GroupMember object is returned.
See https://www.paws-r-sdk.com/docs/quicksight_describe_group_membership/ for full documentation.
quicksight_describe_group_membership(
MemberName,
GroupName,
AwsAccountId,
Namespace
)
MemberName |
[required] The user name of the user that you want to search for. |
GroupName |
[required] The name of the group that you want to search. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace that includes the group you are searching within. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.