Describes an existing IAM policy assignment, as specified by the assignment name.
quicksight_describe_iam_policy_assignment(AwsAccountId, AssignmentName,
Namespace)[required] The ID of the AWS account that contains the assignment that you want to describe.
[required] The name of the assignment, also called a rule.
[required] The namespace that contains the assignment.
A list with the following syntax:
list(
IAMPolicyAssignment = list(
AwsAccountId = "string",
AssignmentId = "string",
AssignmentName = "string",
PolicyArn = "string",
Identities = list(
list(
"string"
)
),
AssignmentStatus = "ENABLED"|"DRAFT"|"DISABLED"
),
RequestId = "string",
Status = 123
)
svc$describe_iam_policy_assignment( AwsAccountId = "string", AssignmentName = "string", Namespace = "string" )