quicksight_describe_namespace: Describes the current namespace

View source: R/quicksight_operations.R

quicksight_describe_namespaceR Documentation

Describes the current namespace

Description

Describes the current namespace.

See https://www.paws-r-sdk.com/docs/quicksight_describe_namespace/ for full documentation.

Usage

quicksight_describe_namespace(AwsAccountId, Namespace)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that contains the Quick Sight namespace that you want to describe.

Namespace

[required] The namespace that you want to describe.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.