quicksight_describe_self_upgrade_configuration: Describes the self-upgrade configuration for a Quick account

View source: R/quicksight_operations.R

quicksight_describe_self_upgrade_configurationR Documentation

Describes the self-upgrade configuration for a Quick account

Description

Describes the self-upgrade configuration for a Quick account.

See https://www.paws-r-sdk.com/docs/quicksight_describe_self_upgrade_configuration/ for full documentation.

Usage

quicksight_describe_self_upgrade_configuration(AwsAccountId, Namespace)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration.

Namespace

[required] The Quick namespace that you want to describe the Quick self-upgrade configuration for.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.