quicksight_describe_space: Describes an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_describe_spaceR Documentation

Describes an Amazon QuickSight space

Description

Describes an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_describe_space/ for full documentation.

Usage

quicksight_describe_space(AwsAccountId, SpaceId, MaxContributors = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to describe.

MaxContributors

The maximum number of contributors to include in the response.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.