quicksight_describe_space_permissions: Describes the permissions for an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_describe_space_permissionsR Documentation

Describes the permissions for an Amazon QuickSight space

Description

Describes the permissions for an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_describe_space_permissions/ for full documentation.

Usage

quicksight_describe_space_permissions(AwsAccountId, SpaceId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to describe permissions for.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.