Describes the template alias for a template.
quicksight_describe_template_alias(AwsAccountId, TemplateId, AliasName)[required] The ID of the AWS account that contains the template alias that you're describing.
[required] The ID for the template.
[required] The name of the template alias that you want to describe. If you name a
specific alias, you describe the version that the alias points to. You
can specify the latest version of the template by providing the keyword
$LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't
apply to templates.
A list with the following syntax:
list(
TemplateAlias = list(
AliasName = "string",
Arn = "string",
TemplateVersionNumber = 123
),
Status = 123,
RequestId = "string"
)
svc$describe_template_alias( AwsAccountId = "string", TemplateId = "string", AliasName = "string" )