Describes the read and write permissions for a theme.
quicksight_describe_theme_permissions(AwsAccountId, ThemeId)[required] The ID of the AWS account that contains the theme that you're describing.
[required] The ID for the theme that you want to describe permissions for.
A list with the following syntax:
list(
ThemeId = "string",
ThemeArn = "string",
Permissions = list(
list(
Principal = "string",
Actions = list(
"string"
)
)
),
RequestId = "string",
Status = 123
)
svc$describe_theme_permissions( AwsAccountId = "string", ThemeId = "string" )