quicksight_gener_embed_url_for_regis_user_with_ident: Generates an embed URL that you can use to embed an Amazon...

quicksight_generate_embed_url_for_registered_user_with_identityR Documentation

Generates an embed URL that you can use to embed an Amazon Quick Sight experience in your website

Description

Generates an embed URL that you can use to embed an Amazon Quick Sight experience in your website. This action can be used for any type of user that is registered in an Amazon Quick Sight account that uses IAM Identity Center for authentication. This API requires identity-enhanced IAM Role sessions for the authenticated user that the API call is being made for.

See https://www.paws-r-sdk.com/docs/quicksight_generate_embed_url_for_registered_user_with_identity/ for full documentation.

Usage

quicksight_generate_embed_url_for_registered_user_with_identity(
  AwsAccountId,
  SessionLifetimeInMinutes = NULL,
  ExperienceConfiguration,
  AllowedDomains = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services registered user.

SessionLifetimeInMinutes

The validity of the session in minutes.

ExperienceConfiguration

[required] The type of experience you want to embed. For registered users, you can embed Quick dashboards or the Amazon Quick Sight console.

Exactly one of the experience configurations is required. You can choose Dashboard or QuickSightConsole. You cannot choose more than one experience configuration.

AllowedDomains

A list of domains to be allowed to generate the embed URL.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.