quicksight_get_flow_metadata: Retrieves the metadata of a flow, not including its...

View source: R/quicksight_operations.R

quicksight_get_flow_metadataR Documentation

Retrieves the metadata of a flow, not including its definition specifying the steps

Description

Retrieves the metadata of a flow, not including its definition specifying the steps.

See https://www.paws-r-sdk.com/docs/quicksight_get_flow_metadata/ for full documentation.

Usage

quicksight_get_flow_metadata(AwsAccountId, FlowId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow that you are getting metadata for.

FlowId

[required] The unique identifier of the flow.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.