quicksight_get_flow_permissions: Get permissions for a flow

View source: R/quicksight_operations.R

quicksight_get_flow_permissionsR Documentation

Get permissions for a flow

Description

Get permissions for a flow.

See https://www.paws-r-sdk.com/docs/quicksight_get_flow_permissions/ for full documentation.

Usage

quicksight_get_flow_permissions(AwsAccountId, FlowId)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow that you are getting permissions for.

FlowId

[required] The unique identifier of the flow to get permissions from.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.