quicksight_list_agents: Lists all agents in an Amazon QuickSight account

View source: R/quicksight_operations.R

quicksight_list_agentsR Documentation

Lists all agents in an Amazon QuickSight account

Description

Lists all agents in an Amazon QuickSight account.

See https://www.paws-r-sdk.com/docs/quicksight_list_agents/ for full documentation.

Usage

quicksight_list_agents(AwsAccountId, MaxResults = NULL, NextToken = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the agents.

MaxResults

The maximum number of results to return.

NextToken

The token for the next set of results, or null if there are no more results.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.