quicksight_list_approval_policies: Lists all approval policies in the specified Quick Sight...

View source: R/quicksight_operations.R

quicksight_list_approval_policiesR Documentation

Lists all approval policies in the specified Quick Sight account

Description

Lists all approval policies in the specified Quick Sight account. The results are paginated. If the response includes a NextToken value, pass it in a subsequent call to retrieve the next set of results.

See https://www.paws-r-sdk.com/docs/quicksight_list_approval_policies/ for full documentation.

Usage

quicksight_list_approval_policies(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to return in a single call. If you don't specify a value, the service returns a default number of results. Use the NextToken value in the response to retrieve additional results.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.