quicksight_list_brands: Lists all brands in an Quick Sight account

View source: R/quicksight_operations.R

quicksight_list_brandsR Documentation

Lists all brands in an Quick Sight account

Description

Lists all brands in an Quick Sight account.

See https://www.paws-r-sdk.com/docs/quicksight_list_brands/ for full documentation.

Usage

quicksight_list_brands(AwsAccountId, MaxResults = NULL, NextToken = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that owns the brands that you want to list.

MaxResults

The maximum number of results to be returned in a single request.

NextToken

The token for the next set of results, or null if there are no more results.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.