quicksight_list_dlp_settings: Lists all DLP settings in an Amazon Web Services account

View source: R/quicksight_operations.R

quicksight_list_dlp_settingsR Documentation

Lists all DLP settings in an Amazon Web Services account

Description

Lists all DLP settings in an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_list_dlp_settings/ for full documentation.

Usage

quicksight_list_dlp_settings(AwsAccountId, NextToken = NULL, MaxResults = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the DLP settings that you want to list.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to return per request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.