quicksight_list_flows: Lists flows in an Amazon Web Services account

View source: R/quicksight_operations.R

quicksight_list_flowsR Documentation

Lists flows in an Amazon Web Services account

Description

Lists flows in an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_list_flows/ for full documentation.

Usage

quicksight_list_flows(AwsAccountId, NextToken = NULL, MaxResults = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow list that you are getting.

NextToken

The token to request the next set of results, or null if you want to retrieve the first set.

MaxResults

The maximum number of results to be returned per request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.