View source: R/quicksight_operations.R
| quicksight_list_group_memberships | R Documentation |
Lists member users in a group.
See https://www.paws-r-sdk.com/docs/quicksight_list_group_memberships/ for full documentation.
quicksight_list_group_memberships(
GroupName,
NextToken = NULL,
MaxResults = NULL,
AwsAccountId,
Namespace
)
GroupName |
[required] The name of the group that you want to see a membership list of. |
NextToken |
A pagination token that can be used in a subsequent request. |
MaxResults |
The maximum number of results to return from this request. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace of the group that you want a list of users from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.