View source: R/quicksight_operations.R
| quicksight_list_groups | R Documentation |
Lists all user groups in Amazon Quick Sight.
See https://www.paws-r-sdk.com/docs/quicksight_list_groups/ for full documentation.
quicksight_list_groups(
AwsAccountId,
NextToken = NULL,
MaxResults = NULL,
Namespace
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
NextToken |
A pagination token that can be used in a subsequent request. |
MaxResults |
The maximum number of results to return. |
Namespace |
[required] The namespace that you want a list of groups from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.