quicksight_list_identity_propagation_configs: Lists all services and authorized targets that the Quick...

View source: R/quicksight_operations.R

quicksight_list_identity_propagation_configsR Documentation

Lists all services and authorized targets that the Quick Sight IAM Identity Center application can access

Description

Lists all services and authorized targets that the Quick Sight IAM Identity Center application can access.

See https://www.paws-r-sdk.com/docs/quicksight_list_identity_propagation_configs/ for full documentation.

Usage

quicksight_list_identity_propagation_configs(
  AwsAccountId,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contain the identity propagation configurations of.

MaxResults

The maximum number of results to be returned.

NextToken

The token for the next set of results, or null if there are no more results.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.