quicksight_list_o_auth_client_applications: Lists all OAuthClientApplications in the current Amazon Web...

View source: R/quicksight_operations.R

quicksight_list_o_auth_client_applicationsR Documentation

Lists all OAuthClientApplications in the current Amazon Web Services Region that belong to this Amazon Web Services account

Description

Lists all OAuthClientApplications in the current Amazon Web Services Region that belong to this Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_list_o_auth_client_applications/ for full documentation.

Usage

quicksight_list_o_auth_client_applications(
  AwsAccountId,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AwsAccountId

[required] The Amazon Web Services account ID.

NextToken

A pagination token that can be used in a subsequent request.

MaxResults

The maximum number of results to return.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.