quicksight_list_self_upgrades: Lists all self-upgrade requests for a Quick account

View source: R/quicksight_operations.R

quicksight_list_self_upgradesR Documentation

Lists all self-upgrade requests for a Quick account

Description

Lists all self-upgrade requests for a Quick account.

See https://www.paws-r-sdk.com/docs/quicksight_list_self_upgrades/ for full documentation.

Usage

quicksight_list_self_upgrades(
  AwsAccountId,
  Namespace,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the self-upgrade requests.

Namespace

[required] The Quick namespace for the self-upgrade requests.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to return.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.