quicksight_list_spaces: Lists all Amazon QuickSight spaces in an Amazon Web Services...

View source: R/quicksight_operations.R

quicksight_list_spacesR Documentation

Lists all Amazon QuickSight spaces in an Amazon Web Services account

Description

Lists all Amazon QuickSight spaces in an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_list_spaces/ for full documentation.

Usage

quicksight_list_spaces(AwsAccountId, NextToken = NULL, MaxResults = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the spaces.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to return.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.