quicksight_list_user_groups: Lists the Amazon Quick Sight groups that an Amazon Quick...

View source: R/quicksight_operations.R

quicksight_list_user_groupsR Documentation

Lists the Amazon Quick Sight groups that an Amazon Quick Sight user is a member of

Description

Lists the Amazon Quick Sight groups that an Amazon Quick Sight user is a member of.

See https://www.paws-r-sdk.com/docs/quicksight_list_user_groups/ for full documentation.

Usage

quicksight_list_user_groups(
  UserName,
  AwsAccountId,
  Namespace,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

UserName

[required] The Amazon Quick Sight user name that you want to list group memberships for.

AwsAccountId

[required] The Amazon Web Services account ID that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Namespace

[required] The namespace. Currently, you should set this to default.

NextToken

A pagination token that can be used in a subsequent request.

MaxResults

The maximum number of results to return from this request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.