quicksight_list_users: Returns a list of all of the Amazon Quick Sight users...

View source: R/quicksight_operations.R

quicksight_list_usersR Documentation

Returns a list of all of the Amazon Quick Sight users belonging to this account

Description

Returns a list of all of the Amazon Quick Sight users belonging to this account.

See https://www.paws-r-sdk.com/docs/quicksight_list_users/ for full documentation.

Usage

quicksight_list_users(
  AwsAccountId,
  NextToken = NULL,
  MaxResults = NULL,
  Namespace
)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

NextToken

A pagination token that can be used in a subsequent request.

MaxResults

The maximum number of results to return from this request.

Namespace

[required] The namespace. Currently, you should set this to default.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.