quicksight_list_users_index_capacity: Lists per-user index capacity consumption for an account

View source: R/quicksight_operations.R

quicksight_list_users_index_capacityR Documentation

Lists per-user index capacity consumption for an account

Description

Lists per-user index capacity consumption for an account.

See https://www.paws-r-sdk.com/docs/quicksight_list_users_index_capacity/ for full documentation.

Usage

quicksight_list_users_index_capacity(
  awsAccountId,
  namespace = NULL,
  filters = NULL,
  sortBy = NULL,
  sortOrder = NULL,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

awsAccountId

[required] The ID of the Amazon Web Services account that contains the index capacity data.

namespace

The namespace to scope the user search to. Required when the userNameOrEmail filter is present.

filters

Filters to apply. Only one filter is supported per request. The userNameOrEmail and totalCapacityBytes filters are mutually exclusive.

sortBy

The field to sort results by.

sortOrder

The sort order for results. Defaults to DESC if not specified.

maxResults

The maximum number of results to return per page.

nextToken

The token for the next set of results, received from a previous call.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.