View source: R/quicksight_operations.R
| quicksight_register_user | R Documentation |
Creates an Amazon Quick Sight user whose identity is associated with the Identity and Access Management (IAM) identity or role specified in the request. When you register a new user from the Quick Sight API, Quick Sight generates a registration URL. The user accesses this registration URL to create their account. Quick Sight doesn't send a registration email to users who are registered from the Quick Sight API. If you want new users to receive a registration email, then add those users in the Quick Sight console. For more information on registering a new user in the Quick Sight console, see Inviting users to access Quick Sight.
See https://www.paws-r-sdk.com/docs/quicksight_register_user/ for full documentation.
quicksight_register_user(
IdentityType,
Email,
UserRole,
IamArn = NULL,
SessionName = NULL,
AwsAccountId,
Namespace,
UserName = NULL,
CustomPermissionsName = NULL,
ExternalLoginFederationProviderType = NULL,
CustomFederationProviderUrl = NULL,
ExternalLoginId = NULL,
Tags = NULL
)
IdentityType |
[required] The identity type that your Quick Sight account uses to manage the identity of users. |
Email |
[required] The email address of the user that you want to register. |
UserRole |
[required] The Amazon Quick Sight role for the user. The user role can be one of the following:
|
IamArn |
The ARN of the IAM user or role that you are registering with Amazon Quick Sight. |
SessionName |
You need to use this parameter only when you register one or more users using an assumed IAM role. You don't need to provide the session name for other scenarios, for example when you are registering an IAM user or an Amazon Quick Sight user. You can register multiple users using the same IAM role if each user has a different session name. For more information on assuming IAM roles, see |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace. Currently, you should set this to |
UserName |
The Amazon Quick Sight user name that you want to create for the user you are registering. |
CustomPermissionsName |
(Enterprise edition only) The name of the custom permissions profile that you want to assign to this user. Customized permissions allows you to control a user's access by restricting access the following operations:
To add custom permissions to an existing user, use A set of custom permissions includes any combination of these restrictions. Currently, you need to create the profile names for custom permission sets by using the Quick Sight console. Then, you use the Quick Sight custom permissions are applied through IAM policies. Therefore, they override the permissions typically granted by assigning Quick Sight users to one of the default security cohorts in Quick Sight (admin, author, reader, admin pro, author pro, reader pro). This feature is available only to Quick Sight Enterprise edition subscriptions. |
ExternalLoginFederationProviderType |
The type of supported external login provider that provides identity to let a user federate into Amazon Quick Sight with an associated Identity and Access Management(IAM) role. The type of supported external login provider can be one of the following.
|
CustomFederationProviderUrl |
The URL of the custom OpenID Connect (OIDC) provider that provides identity to let a user federate into Quick Sight with an associated Identity and Access Management(IAM) role. This parameter should only be used when |
ExternalLoginId |
The identity ID for a user in the external login provider. |
Tags |
The tags to associate with the user. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.