View source: R/quicksight_operations.R
| quicksight_search_action_connectors | R Documentation |
Searches for action connectors in the specified Amazon Web Services account using filters. You can search by connector name, type, or user permissions.
See https://www.paws-r-sdk.com/docs/quicksight_search_action_connectors/ for full documentation.
quicksight_search_action_connectors(
AwsAccountId,
MaxResults = NULL,
NextToken = NULL,
Filters
)
AwsAccountId |
[required] The Amazon Web Services account ID in which to search for action connectors. |
MaxResults |
The maximum number of action connectors to return in a single response. Valid range is 1 to 100. |
NextToken |
A pagination token to retrieve the next set of results. Use the token returned from a previous call to continue searching. |
Filters |
[required] The search filters to apply. You can filter by connector name, type, or user permissions. Maximum of one filter is supported. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.