quicksight_search_agents: Searches for agents based on specified filters

View source: R/quicksight_operations.R

quicksight_search_agentsR Documentation

Searches for agents based on specified filters

Description

Searches for agents based on specified filters.

See https://www.paws-r-sdk.com/docs/quicksight_search_agents/ for full documentation.

Usage

quicksight_search_agents(
  AwsAccountId,
  Filters,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the agents.

Filters

[required] The filters to apply when searching agents.

MaxResults

The maximum number of results to return.

NextToken

The token for the next set of results, or null if there are no more results.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.