quicksight_search_flows: Search for the flows in an Amazon Web Services account

View source: R/quicksight_operations.R

quicksight_search_flowsR Documentation

Search for the flows in an Amazon Web Services account

Description

Search for the flows in an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_search_flows/ for full documentation.

Usage

quicksight_search_flows(
  AwsAccountId,
  Filters,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account where you are searching for flows from.

Filters

[required] The filters applied to the search when searching for flows in the Amazon Web Services account.

NextToken

The token to request the next set of results, or null if you want to retrieve the first set.

MaxResults

The maximum number of results to be returned per request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.