View source: R/quicksight_operations.R
| quicksight_search_groups | R Documentation |
Use the search_groups operation to search groups in a specified Quick Sight namespace using the supplied filters.
See https://www.paws-r-sdk.com/docs/quicksight_search_groups/ for full documentation.
quicksight_search_groups(
AwsAccountId,
NextToken = NULL,
MaxResults = NULL,
Namespace,
Filters
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
NextToken |
A pagination token that can be used in a subsequent request. |
MaxResults |
The maximum number of results to return from this request. |
Namespace |
[required] The namespace that you want to search. |
Filters |
[required] The structure for the search filters that you want to apply to your search. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.