quicksight_search_spaces: Searches for Amazon QuickSight spaces that match the...

View source: R/quicksight_operations.R

quicksight_search_spacesR Documentation

Searches for Amazon QuickSight spaces that match the specified filters

Description

Searches for Amazon QuickSight spaces that match the specified filters.

See https://www.paws-r-sdk.com/docs/quicksight_search_spaces/ for full documentation.

Usage

quicksight_search_spaces(
  AwsAccountId,
  NextToken = NULL,
  MaxResults = NULL,
  Filters
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the spaces.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to return.

Filters

[required] The filters to apply to the search.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.