quicksight_search_topics: Searches for any Q topic that exists in an Quick account

View source: R/quicksight_operations.R

quicksight_search_topicsR Documentation

Searches for any Q topic that exists in an Quick account

Description

Searches for any Q topic that exists in an Quick account.

See https://www.paws-r-sdk.com/docs/quicksight_search_topics/ for full documentation.

Usage

quicksight_search_topics(
  AwsAccountId,
  Filters,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the topic that you want to find.

Filters

[required] The filters that you want to use to search for the topic.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to be returned per request.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.