quicksight_search_topics_v2: Searches for any Q topic that exists in an Amazon Web...

View source: R/quicksight_operations.R

quicksight_search_topics_v2R Documentation

Searches for any Q topic that exists in an Amazon Web Services account

Description

Searches for any Q topic that exists in an Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/quicksight_search_topics_v2/ for full documentation.

Usage

quicksight_search_topics_v2(
  AwsAccountId,
  Filters,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the topic that you want to search.

Filters

[required] The filters that you want to use to search for the topic.

NextToken

The token for the next set of results, or null if there are no more results.

MaxResults

The maximum number of results to be returned per request.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.