quicksight_start_automation_job: Starts a new job for a specified automation

View source: R/quicksight_operations.R

quicksight_start_automation_jobR Documentation

Starts a new job for a specified automation

Description

Starts a new job for a specified automation. The job runs the automation with the provided input payload.

See https://www.paws-r-sdk.com/docs/quicksight_start_automation_job/ for full documentation.

Usage

quicksight_start_automation_job(
  AwsAccountId,
  AutomationGroupId,
  AutomationId,
  InputPayload = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the automation.

AutomationGroupId

[required] The ID of the automation group that contains the automation to run.

AutomationId

[required] The ID of the automation to run.

InputPayload

The input payload for the automation job, provided as a JSON string.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.