quicksight_update_account_custom_permission: Applies a custom permissions profile to an account

View source: R/quicksight_operations.R

quicksight_update_account_custom_permissionR Documentation

Applies a custom permissions profile to an account

Description

Applies a custom permissions profile to an account.

See https://www.paws-r-sdk.com/docs/quicksight_update_account_custom_permission/ for full documentation.

Usage

quicksight_update_account_custom_permission(
  CustomPermissionsName,
  AwsAccountId
)

Arguments

CustomPermissionsName

[required] The name of the custom permissions profile that you want to apply to an account.

AwsAccountId

[required] The ID of the Amazon Web Services account for which you want to apply a custom permissions profile.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.