quicksight_update_account_customization: Updates Amazon Quick Sight customizations

View source: R/quicksight_operations.R

quicksight_update_account_customizationR Documentation

Updates Amazon Quick Sight customizations

Description

Updates Amazon Quick Sight customizations. Currently, the only customization that you can use is a theme.

See https://www.paws-r-sdk.com/docs/quicksight_update_account_customization/ for full documentation.

Usage

quicksight_update_account_customization(
  AwsAccountId,
  Namespace = NULL,
  AccountCustomization
)

Arguments

AwsAccountId

[required] The ID for the Amazon Web Services account that you want to update Quick Sight customizations for.

Namespace

The namespace that you want to update Quick Sight customizations for.

AccountCustomization

[required] The Quick Sight customizations you're updating.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.