quicksight_update_action_connector: Updates an existing action connector with new configuration...

View source: R/quicksight_operations.R

quicksight_update_action_connectorR Documentation

Updates an existing action connector with new configuration details, authentication settings, or enabled actions

Description

Updates an existing action connector with new configuration details, authentication settings, or enabled actions. You can modify the connector's name, description, authentication configuration, and which actions are enabled. For more information, https://docs.aws.amazon.com/quicksuite/latest/userguide/quick-action-auth.html.

See https://www.paws-r-sdk.com/docs/quicksight_update_action_connector/ for full documentation.

Usage

quicksight_update_action_connector(
  AwsAccountId,
  ActionConnectorId,
  Name,
  AuthenticationConfig,
  Description = NULL,
  VpcConnectionArn = NULL
)

Arguments

AwsAccountId

[required] The Amazon Web Services account ID that contains the action connector to update.

ActionConnectorId

[required] The unique identifier of the action connector to update.

Name

[required] The new name for the action connector.

AuthenticationConfig

[required] The updated authentication configuration for connecting to the external service.

Description

The updated description of the action connector.

VpcConnectionArn

The updated ARN of the VPC connection to use for secure connectivity.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.