quicksight_update_action_connector_permissions: Updates the permissions for an action connector by granting...

View source: R/quicksight_operations.R

quicksight_update_action_connector_permissionsR Documentation

Updates the permissions for an action connector by granting or revoking access for specific users and groups

Description

Updates the permissions for an action connector by granting or revoking access for specific users and groups. You can control who can view, use, or manage the action connector.

See https://www.paws-r-sdk.com/docs/quicksight_update_action_connector_permissions/ for full documentation.

Usage

quicksight_update_action_connector_permissions(
  AwsAccountId,
  ActionConnectorId,
  GrantPermissions = NULL,
  RevokePermissions = NULL
)

Arguments

AwsAccountId

[required] The Amazon Web Services account ID that contains the action connector.

ActionConnectorId

[required] The unique identifier of the action connector whose permissions you want to update.

GrantPermissions

The permissions to grant to users and groups for this action connector.

RevokePermissions

The permissions to revoke from users and groups for this action connector.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.