quicksight_update_agent: Updates an existing agent

View source: R/quicksight_operations.R

quicksight_update_agentR Documentation

Updates an existing agent

Description

Updates an existing agent.

See https://www.paws-r-sdk.com/docs/quicksight_update_agent/ for full documentation.

Usage

quicksight_update_agent(
  AgentId,
  AwsAccountId,
  Name,
  Description = NULL,
  IconId = NULL,
  StarterPrompts = NULL,
  WelcomeMessage = NULL,
  CustomPromptInput = NULL,
  SpacesToAdd = NULL,
  SpacesToRemove = NULL,
  ActionConnectorsToAdd = NULL,
  ActionConnectorsToRemove = NULL
)

Arguments

AgentId

[required] The unique identifier for the agent to update.

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the agent.

Name

[required] The name of the agent.

Description

A description of the agent.

IconId

The icon identifier for the agent.

StarterPrompts

A list of starter prompts that are displayed to users when they begin interacting with the agent.

WelcomeMessage

The welcome message that is displayed when a user starts a conversation with the agent.

CustomPromptInput

The custom prompt configuration for the agent.

SpacesToAdd

The Amazon Resource Names (ARNs) of the spaces to attach to the agent.

SpacesToRemove

The Amazon Resource Names (ARNs) of the spaces to detach from the agent.

ActionConnectorsToAdd

The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.

ActionConnectorsToRemove

The Amazon Resource Names (ARNs) of the action connectors to detach from the agent.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.