quicksight_update_agent_permissions: Updates the resource permissions for an agent

View source: R/quicksight_operations.R

quicksight_update_agent_permissionsR Documentation

Updates the resource permissions for an agent

Description

Updates the resource permissions for an agent.

See https://www.paws-r-sdk.com/docs/quicksight_update_agent_permissions/ for full documentation.

Usage

quicksight_update_agent_permissions(
  AgentId,
  AwsAccountId,
  GrantPermissions = NULL,
  RevokePermissions = NULL
)

Arguments

AgentId

[required] The unique identifier for the agent.

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the agent.

GrantPermissions

The resource permissions that you want to grant on the agent.

RevokePermissions

The resource permissions that you want to revoke from the agent.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.