quicksight_update_app_permissions: Updates the resource permissions for an app

View source: R/quicksight_operations.R

quicksight_update_app_permissionsR Documentation

Updates the resource permissions for an app

Description

Updates the resource permissions for an app. You can grant or revoke permissions and, optionally, change the app's visibility.

See https://www.paws-r-sdk.com/docs/quicksight_update_app_permissions/ for full documentation.

Usage

quicksight_update_app_permissions(
  AwsAccountId,
  AppId,
  GrantPermissions = NULL,
  RevokePermissions = NULL,
  Visibility = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the app.

AppId

[required] The ID of the app.

GrantPermissions

The permissions that you want to grant on the app.

RevokePermissions

The permissions that you want to revoke from the app.

Visibility

The visibility to set for the app. Currently, only PRIVATE is accepted, which removes public (anonymous) access from the app. If you don't specify a value, the app's visibility is unchanged. Setting an app to PUBLIC through this operation is not supported.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.