quicksight_update_application_with_token_exchange_grant: Updates an Quick application with a token exchange grant

View source: R/quicksight_operations.R

quicksight_update_application_with_token_exchange_grantR Documentation

Updates an Quick application with a token exchange grant

Description

Updates an Quick application with a token exchange grant. This operation only supports Quick applications that are registered with IAM Identity Center.

See https://www.paws-r-sdk.com/docs/quicksight_update_application_with_token_exchange_grant/ for full documentation.

Usage

quicksight_update_application_with_token_exchange_grant(
  AwsAccountId,
  Namespace
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account to be updated with a token exchange grant.

Namespace

[required] The namespace of the Quick application.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.