quicksight_update_approval_policy: Updates an approval policy in Quick Sight

View source: R/quicksight_operations.R

quicksight_update_approval_policyR Documentation

Updates an approval policy in Quick Sight

Description

Updates an approval policy in Quick Sight.

See https://www.paws-r-sdk.com/docs/quicksight_update_approval_policy/ for full documentation.

Usage

quicksight_update_approval_policy(
  PolicyId,
  Name = NULL,
  Description = NULL,
  Actions = NULL,
  AssetTypes = NULL,
  ApplicableTo = NULL,
  ApprovalGroups = NULL
)

Arguments

PolicyId

[required] The unique identifier of the approval policy to update.

Name

The name of the approval policy.

Description

A description of the approval policy.

Actions

The list of governed actions that trigger the approval workflow.

AssetTypes

The list of asset types that the approval policy applies to.

ApplicableTo

The scoping configuration that determines who the approval policy applies to.

ApprovalGroups

The list of group ARNs whose members can approve requests.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.