quicksight_update_data_set: Updates a dataset

View source: R/quicksight_operations.R

quicksight_update_data_setR Documentation

Updates a dataset

Description

Updates a dataset. This operation doesn't support datasets that include uploaded files as a source. Partial updates are not supported by this operation.

See https://www.paws-r-sdk.com/docs/quicksight_update_data_set/ for full documentation.

Usage

quicksight_update_data_set(
  AwsAccountId,
  DataSetId,
  Name,
  PhysicalTableMap,
  LogicalTableMap = NULL,
  ImportMode,
  ColumnGroups = NULL,
  FieldFolders = NULL,
  RowLevelPermissionDataSet = NULL,
  RowLevelPermissionTagConfiguration = NULL,
  ColumnLevelPermissionRules = NULL,
  DataSetUsageConfiguration = NULL,
  DatasetParameters = NULL,
  PerformanceConfiguration = NULL,
  DataPrepConfiguration = NULL,
  SemanticModelConfiguration = NULL
)

Arguments

AwsAccountId

[required] The Amazon Web Services account ID.

DataSetId

[required] The ID for the dataset that you want to update. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Name

[required] The display name for the dataset.

PhysicalTableMap

[required] Declares the physical tables that are available in the underlying data sources.

LogicalTableMap

Configures the combination and transformation of the data from the physical tables. This parameter is used with the legacy data preparation experience.

ImportMode

[required] Indicates whether you want to import the data into SPICE.

ColumnGroups

Groupings of columns that work together in certain Amazon Quick Sight features. Currently, only geospatial hierarchy is supported.

FieldFolders

The folder that contains fields and nested subfolders for your dataset.

RowLevelPermissionDataSet

The row-level security configuration for the data you want to create. This parameter is used with the legacy data preparation experience.

RowLevelPermissionTagConfiguration

The configuration of tags on a dataset to set row-level security. Row-level security tags are currently supported for anonymous embedding only. This parameter is used with the legacy data preparation experience.

ColumnLevelPermissionRules

A set of one or more definitions of a ColumnLevelPermissionRule.

DataSetUsageConfiguration

The usage configuration to apply to child datasets that reference this dataset as a source.

DatasetParameters

The parameter declarations of the dataset.

PerformanceConfiguration

The configuration for the performance optimization of the dataset that contains a UniqueKey configuration.

DataPrepConfiguration

The data preparation configuration for the dataset. This configuration defines the source tables, transformation steps, and destination tables used to prepare the data. Required when using the new data preparation experience.

SemanticModelConfiguration

The semantic model configuration for the dataset. This configuration defines how the prepared data is structured for an analysis, including table mappings and row-level security configurations. Required when using the new data preparation experience.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.