quicksight_update_default_q_business_application: Updates a Amazon Q Business application that is linked to a...

View source: R/quicksight_operations.R

quicksight_update_default_q_business_applicationR Documentation

Updates a Amazon Q Business application that is linked to a Quick Sight account

Description

Updates a Amazon Q Business application that is linked to a Quick Sight account.

See https://www.paws-r-sdk.com/docs/quicksight_update_default_q_business_application/ for full documentation.

Usage

quicksight_update_default_q_business_application(
  AwsAccountId,
  Namespace = NULL,
  ApplicationId
)

Arguments

AwsAccountId

[required] The ID of the Quick Sight account that is connected to the Amazon Q Business application that you want to update.

Namespace

The Quick Sight namespace that contains the linked Amazon Q Business application. If this field is left blank, the default namespace is used. Currently, the default namespace is the only valid value for this parameter.

ApplicationId

[required] The ID of the Amazon Q Business application that you want to update.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.