View source: R/quicksight_operations.R
| quicksight_update_flow | R Documentation |
Updates an existing flow. Supply only the fields you want to change. Updates both DRAFT and PUBLISHED versions. When FlowDefinition is provided, all existing steps are replaced with the new definition.
See https://www.paws-r-sdk.com/docs/quicksight_update_flow/ for full documentation.
quicksight_update_flow(
AwsAccountId,
FlowId,
Name = NULL,
Description = NULL,
FlowDefinition = NULL,
ClientToken = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow that you are updating. |
FlowId |
[required] The unique identifier of the flow to update. |
Name |
Updated display name for the flow. Omit to preserve the existing name. |
Description |
Updated description for the flow. Omit to preserve the existing description. |
FlowDefinition |
The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow's internal format. The format is subject to change. When provided, all existing steps are replaced. Omit to preserve the existing definition. Always derive or depend on the flow definition from the |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.