quicksight_update_flow_permissions: Updates permissions against principals on a flow

View source: R/quicksight_operations.R

quicksight_update_flow_permissionsR Documentation

Updates permissions against principals on a flow

Description

Updates permissions against principals on a flow.

See https://www.paws-r-sdk.com/docs/quicksight_update_flow_permissions/ for full documentation.

Usage

quicksight_update_flow_permissions(
  AwsAccountId,
  FlowId,
  GrantPermissions = NULL,
  RevokePermissions = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the flow you are updating permissions against.

FlowId

[required] The unique identifier of the flow to update permissions for.

GrantPermissions

The permissions that you want to grant on this flow.

RevokePermissions

The permissions that you want to revoke from this flow.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.