View source: R/quicksight_operations.R
| quicksight_update_group | R Documentation |
Changes a group description.
See https://www.paws-r-sdk.com/docs/quicksight_update_group/ for full documentation.
quicksight_update_group(GroupName, Description = NULL, AwsAccountId, Namespace)
GroupName |
[required] The name of the group that you want to update. |
Description |
The description for the group that you want to update. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace of the group that you want to update. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.