quicksight_update_knowledge_base: Updates the properties of an existing knowledge base

View source: R/quicksight_operations.R

quicksight_update_knowledge_baseR Documentation

Updates the properties of an existing knowledge base

Description

Updates the properties of an existing knowledge base.

See https://www.paws-r-sdk.com/docs/quicksight_update_knowledge_base/ for full documentation.

Usage

quicksight_update_knowledge_base(
  AwsAccountId,
  KnowledgeBaseId,
  Name = NULL,
  Description = NULL,
  KnowledgeBaseConfiguration = NULL,
  MediaExtractionConfiguration = NULL,
  IsEmailNotificationOptedForIngestionFailures = NULL,
  AccessControlConfiguration = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the knowledge base.

KnowledgeBaseId

[required] The unique identifier for the knowledge base.

Name

The name of the knowledge base. If you don't specify a name, the existing name is retained.

Description

A description for the knowledge base. If you don't specify a description, the existing description is retained.

KnowledgeBaseConfiguration

The configuration settings for a knowledge base.

MediaExtractionConfiguration

The configuration for media extraction from knowledge base documents.

IsEmailNotificationOptedForIngestionFailures

Specifies whether email notifications are enabled for ingestion failures.

AccessControlConfiguration

The access control configuration for the knowledge base. If you don't specify this parameter, the existing setting is retained.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.