quicksight_update_limits_profile: Updates the properties of an existing limits profile

View source: R/quicksight_operations.R

quicksight_update_limits_profileR Documentation

Updates the properties of an existing limits profile

Description

Updates the properties of an existing limits profile.

See https://www.paws-r-sdk.com/docs/quicksight_update_limits_profile/ for full documentation.

Usage

quicksight_update_limits_profile(
  profileId,
  accountId,
  profileName = NULL,
  description = NULL,
  resourceLimits = NULL
)

Arguments

profileId

[required] The unique identifier for the limits profile to update.

accountId

[required] The ID of the Amazon Web Services account that contains the limits profile.

profileName

A new display name for the limits profile.

description

A new description for the limits profile.

resourceLimits

A map of resource types to their updated limit values.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.