View source: R/quicksight_operations.R
| quicksight_update_public_sharing_settings | R Documentation |
This API controls public sharing settings for your entire Quick Sight account, affecting data security and access. When you enable public sharing:
See https://www.paws-r-sdk.com/docs/quicksight_update_public_sharing_settings/ for full documentation.
quicksight_update_public_sharing_settings(
AwsAccountId,
PublicSharingEnabled = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID associated with your Amazon Quick Sight subscription. |
PublicSharingEnabled |
A Boolean value that indicates whether public sharing is turned on for an Quick account. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.