quicksight_update_quick_sight_q_search_configuration: Updates the state of a Quick Sight Q Search configuration

View source: R/quicksight_operations.R

quicksight_update_quick_sight_q_search_configurationR Documentation

Updates the state of a Quick Sight Q Search configuration

Description

Updates the state of a Quick Sight Q Search configuration.

See https://www.paws-r-sdk.com/docs/quicksight_update_quick_sight_q_search_configuration/ for full documentation.

Usage

quicksight_update_quick_sight_q_search_configuration(
  AwsAccountId,
  QSearchStatus
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the Quick Sight Q Search configuration that you want to update.

QSearchStatus

[required] The status of the Quick Sight Q Search configuration that the user wants to update.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.