quicksight_update_self_upgrade: Updates a self-upgrade request for a Quick user by approving,...

View source: R/quicksight_operations.R

quicksight_update_self_upgradeR Documentation

Updates a self-upgrade request for a Quick user by approving, denying, or verifying the request

Description

Updates a self-upgrade request for a Quick user by approving, denying, or verifying the request.

See https://www.paws-r-sdk.com/docs/quicksight_update_self_upgrade/ for full documentation.

Usage

quicksight_update_self_upgrade(
  AwsAccountId,
  Namespace,
  UpgradeRequestId,
  Action
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the self-upgrade request.

Namespace

[required] The Quick namespace for the self-upgrade request.

UpgradeRequestId

[required] The ID of the self-upgrade request to update.

Action

[required] The action to perform on the self-upgrade request. Valid values are APPROVE, DENY, or VERIFY.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.