quicksight_update_self_upgrade_configuration: Updates the self-upgrade configuration for a Quick account

View source: R/quicksight_operations.R

quicksight_update_self_upgrade_configurationR Documentation

Updates the self-upgrade configuration for a Quick account

Description

Updates the self-upgrade configuration for a Quick account.

See https://www.paws-r-sdk.com/docs/quicksight_update_self_upgrade_configuration/ for full documentation.

Usage

quicksight_update_self_upgrade_configuration(
  AwsAccountId,
  Namespace,
  SelfUpgradeStatus
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration that you want to update.

Namespace

[required] The Quick namespace that you want to update the Quick self-upgrade configuration for.

SelfUpgradeStatus

[required] The self-upgrade status that you want to set for the Quick account.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.