quicksight_update_space: Updates the metadata of an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_update_spaceR Documentation

Updates the metadata of an Amazon QuickSight space

Description

Updates the metadata of an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_update_space/ for full documentation.

Usage

quicksight_update_space(AwsAccountId, SpaceId, Name = NULL, Description = NULL)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to update.

Name

A new display name for the space.

Description

A new description for the space.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.