quicksight_update_space_permissions: Updates the permissions for an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_update_space_permissionsR Documentation

Updates the permissions for an Amazon QuickSight space

Description

Updates the permissions for an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_update_space_permissions/ for full documentation.

Usage

quicksight_update_space_permissions(
  AwsAccountId,
  SpaceId,
  GrantPermissions = NULL,
  RevokePermissions = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to update permissions for.

GrantPermissions

The permissions that you want to grant on the space.

RevokePermissions

The permissions that you want to revoke from the space.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.