quicksight_update_space_resources: Adds or removes resources from an Amazon QuickSight space

View source: R/quicksight_operations.R

quicksight_update_space_resourcesR Documentation

Adds or removes resources from an Amazon QuickSight space

Description

Adds or removes resources from an Amazon QuickSight space.

See https://www.paws-r-sdk.com/docs/quicksight_update_space_resources/ for full documentation.

Usage

quicksight_update_space_resources(
  AwsAccountId,
  SpaceId,
  AddResources = NULL,
  RemoveResources = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the space.

SpaceId

[required] The ID of the space that you want to update resources for.

AddResources

A list of resources to add to the space.

RemoveResources

A list of resources to remove from the space.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.