quicksight_update_topic: Updates a topic

View source: R/quicksight_operations.R

quicksight_update_topicR Documentation

Updates a topic

Description

Updates a topic.

See https://www.paws-r-sdk.com/docs/quicksight_update_topic/ for full documentation.

Usage

quicksight_update_topic(
  AwsAccountId,
  TopicId,
  Topic,
  CustomInstructions = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the topic that you want to update.

TopicId

[required] The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Topic

[required] The definition of the topic that you want to update.

CustomInstructions

Custom instructions for the topic.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.