quicksight_update_topic_v2: Updates the definition of a Q topic

View source: R/quicksight_operations.R

quicksight_update_topic_v2R Documentation

Updates the definition of a Q topic

Description

Updates the definition of a Q topic.

See https://www.paws-r-sdk.com/docs/quicksight_update_topic_v2/ for full documentation.

Usage

quicksight_update_topic_v2(
  AwsAccountId,
  TopicId,
  Topic,
  CustomInstructions = NULL,
  PublishOption = NULL
)

Arguments

AwsAccountId

[required] The ID of the Amazon Web Services account that contains the topic that you want to update.

TopicId

[required] The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Topic

[required] The definition of the topic that you want to update.

CustomInstructions

Instructions that provide additional guidance and context for response generation.

PublishOption

The publish option for the topic that you want to update.


paws.analytics documentation built on Oct. 8, 2026, 1:09 a.m.