quicksight_update_user: Updates an Amazon Quick Sight user

View source: R/quicksight_operations.R

quicksight_update_userR Documentation

Updates an Amazon Quick Sight user

Description

Updates an Amazon Quick Sight user.

See https://www.paws-r-sdk.com/docs/quicksight_update_user/ for full documentation.

Usage

quicksight_update_user(
  UserName,
  AwsAccountId,
  Namespace,
  Email,
  Role,
  CustomPermissionsName = NULL,
  UnapplyCustomPermissions = NULL,
  ExternalLoginFederationProviderType = NULL,
  CustomFederationProviderUrl = NULL,
  ExternalLoginId = NULL
)

Arguments

UserName

[required] The Amazon Quick Sight user name that you want to update.

AwsAccountId

[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Namespace

[required] The namespace. Currently, you should set this to default.

Email

[required] The email address of the user that you want to update.

Role

[required] The Amazon Quick Sight role of the user. The role can be one of the following default security cohorts:

  • READER: A user who has read-only access to dashboards.

  • AUTHOR: A user who can create data sources, datasets, analyses, and dashboards.

  • ADMIN: A user who is an author, who can also manage Amazon Quick Sight settings.

  • READER_PRO: Reader Pro adds Generative BI capabilities to the Reader role. Reader Pros have access to Amazon Q in Quick Sight, can build stories with Amazon Q, and can generate executive summaries from dashboards.

  • AUTHOR_PRO: Author Pro adds Generative BI capabilities to the Author role. Author Pros can author dashboards with natural language with Amazon Q, build stories with Amazon Q, create Topics for Q&A, and generate executive summaries from dashboards.

  • ADMIN_PRO: Admin Pros are Author Pros who can also manage Amazon Quick Sight administrative settings. Admin Pro users are billed at Author Pro pricing.

The name of the Quick Sight role is invisible to the user except for the console screens dealing with permissions.

CustomPermissionsName

(Enterprise edition only) The name of the custom permissions profile that you want to assign to this user. Customized permissions allows you to control a user's access by restricting access the following operations:

  • Create and update data sources

  • Create and update datasets

  • Create and update email reports

  • Subscribe to email reports

A set of custom permissions includes any combination of these restrictions. Currently, you need to create the profile names for custom permission sets by using the Quick Sight console. Then, you use the register_user API operation to assign the named set of permissions to a Quick Sight user.

Quick Sight custom permissions are applied through IAM policies. Therefore, they override the permissions typically granted by assigning Quick Sight users to one of the default security cohorts in Quick Sight (admin, author, reader).

This feature is available only to Quick Sight Enterprise edition subscriptions.

UnapplyCustomPermissions

A flag that you use to indicate that you want to remove all custom permissions from this user. Using this parameter resets the user to the state it was in before a custom permissions profile was applied. This parameter defaults to NULL and it doesn't accept any other value.

ExternalLoginFederationProviderType

The type of supported external login provider that provides identity to let a user federate into Quick Sight with an associated Identity and Access Management(IAM) role. The type of supported external login provider can be one of the following.

  • COGNITO: Amazon Cognito. The provider URL is cognito-identity.amazonaws.com. When choosing the COGNITO provider type, don’t use the "CustomFederationProviderUrl" parameter which is only needed when the external provider is custom.

  • CUSTOM_OIDC: Custom OpenID Connect (OIDC) provider. When choosing CUSTOM_OIDC type, use the CustomFederationProviderUrl parameter to provide the custom OIDC provider URL.

  • NONE: This clears all the previously saved external login information for a user. Use the describe_user API operation to check the external login information.

CustomFederationProviderUrl

The URL of the custom OpenID Connect (OIDC) provider that provides identity to let a user federate into Quick Sight with an associated Identity and Access Management(IAM) role. This parameter should only be used when ExternalLoginFederationProviderType parameter is set to CUSTOM_OIDC.

ExternalLoginId

The identity ID for a user in the external login provider.


paws.analytics documentation built on May 30, 2026, 9:16 a.m.