View source: R/cloudsearch_operations.R
| cloudsearch_define_analysis_scheme | R Documentation |
Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.
See https://www.paws-r-sdk.com/docs/cloudsearch_define_analysis_scheme/ for full documentation.
cloudsearch_define_analysis_scheme(DomainName, AnalysisScheme)
DomainName |
[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
AnalysisScheme |
[required] Configuration information for an analysis scheme. Each analysis scheme has a unique name and specifies the language of the text to be processed. The following options can be configured for an analysis scheme: |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.