View source: R/cloudsearch_operations.R
| cloudsearch_delete_expression | R Documentation |
Removes an Expression from the search domain. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide.
See https://www.paws-r-sdk.com/docs/cloudsearch_delete_expression/ for full documentation.
cloudsearch_delete_expression(DomainName, ExpressionName)
DomainName |
[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
ExpressionName |
[required] The name of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.