View source: R/cloudsearch_operations.R
| cloudsearch_describe_scaling_parameters | R Documentation |
Gets the scaling parameters configured for a domain. A domain's scaling parameters specify the desired search instance type and replication count. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.
See https://www.paws-r-sdk.com/docs/cloudsearch_describe_scaling_parameters/ for full documentation.
cloudsearch_describe_scaling_parameters(DomainName)
DomainName |
[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.