View source: R/cloudsearch_operations.R
| cloudsearch_index_documents | R Documentation |
Tells the search domain to start indexing its documents using the latest indexing options. This operation must be invoked to activate options whose OptionStatus is RequiresIndexDocuments.
See https://www.paws-r-sdk.com/docs/cloudsearch_index_documents/ for full documentation.
cloudsearch_index_documents(DomainName)
DomainName |
[required] A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.