View source: R/datazone_operations.R
| datazone_accept_subscription_request | R Documentation |
Accepts a subscription request to a specific asset.
See https://www.paws-r-sdk.com/docs/datazone_accept_subscription_request/ for full documentation.
datazone_accept_subscription_request(
domainIdentifier,
identifier,
decisionComment = NULL,
assetScopes = NULL,
assetPermissions = NULL
)
domainIdentifier |
[required] The Amazon DataZone domain where the specified subscription request is being accepted. |
identifier |
[required] The unique identifier of the subscription request that is to be accepted. |
decisionComment |
A description that specifies the reason for accepting the specified subscription request. |
assetScopes |
The asset scopes of the accept subscription request. |
assetPermissions |
The asset permissions of the accept subscription request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.