View source: R/datazone_operations.R
| datazone_associate_governed_terms | R Documentation |
Associates governed terms with an asset.
See https://www.paws-r-sdk.com/docs/datazone_associate_governed_terms/ for full documentation.
datazone_associate_governed_terms(
domainIdentifier,
entityIdentifier,
entityType,
governedGlossaryTerms
)
domainIdentifier |
[required] The ID of the domain where governed terms are to be associated with an asset. |
entityIdentifier |
[required] The ID of the asset with which you want to associate a governed term. |
entityType |
[required] The type of the asset with which you want to associate a governed term. |
governedGlossaryTerms |
[required] The glossary terms in a restricted glossary. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.