View source: R/datazone_operations.R
| datazone_batch_get_attributes_metadata | R Documentation |
Gets the attribute metadata.
See https://www.paws-r-sdk.com/docs/datazone_batch_get_attributes_metadata/ for full documentation.
datazone_batch_get_attributes_metadata(
domainIdentifier,
entityType,
entityIdentifier,
entityRevision = NULL,
attributeIdentifiers
)
domainIdentifier |
[required] The domain ID where you want to get the attribute metadata. |
entityType |
[required] The entity type for which you want to get attribute metadata. |
entityIdentifier |
[required] The entity ID for which you want to get attribute metadata. |
entityRevision |
The entity revision for which you want to get attribute metadata. |
attributeIdentifiers |
[required] The attribute identifier. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.