View source: R/datazone_operations.R
| datazone_create_account_pool | R Documentation |
Creates an account pool.
See https://www.paws-r-sdk.com/docs/datazone_create_account_pool/ for full documentation.
datazone_create_account_pool(
domainIdentifier,
name,
description = NULL,
resolutionStrategy,
accountSource
)
domainIdentifier |
[required] The ID of the domain where the account pool is created. |
name |
[required] The name of the account pool. |
description |
The description of the account pool. |
resolutionStrategy |
[required] The mechanism used to resolve the account selection from the account pool. |
accountSource |
[required] The source of accounts for the account pool. In the current release, it's either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.