View source: R/datazone_operations.R
| datazone_create_asset_revision | R Documentation |
Creates a revision of the asset.
See https://www.paws-r-sdk.com/docs/datazone_create_asset_revision/ for full documentation.
datazone_create_asset_revision(
name,
domainIdentifier,
identifier,
typeRevision = NULL,
description = NULL,
glossaryTerms = NULL,
formsInput = NULL,
predictionConfiguration = NULL,
clientToken = NULL
)
name |
[required] Te revised name of the asset. |
domainIdentifier |
[required] The unique identifier of the domain where the asset is being revised. |
identifier |
[required] The identifier of the asset. |
typeRevision |
The revision type of the asset. |
description |
The revised description of the asset. |
glossaryTerms |
The glossary terms to be attached to the asset as part of asset revision. |
formsInput |
The metadata forms to be attached to the asset as part of asset revision. |
predictionConfiguration |
The configuration of the automatically generated business-friendly metadata for the asset. |
clientToken |
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.