View source: R/datazone_operations.R
| datazone_create_glossary | R Documentation |
Creates an Amazon DataZone business glossary.
See https://www.paws-r-sdk.com/docs/datazone_create_glossary/ for full documentation.
datazone_create_glossary(
domainIdentifier,
name,
owningProjectIdentifier,
description = NULL,
status = NULL,
usageRestrictions = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The ID of the Amazon DataZone domain in which this business glossary is created. |
name |
[required] The name of this business glossary. |
owningProjectIdentifier |
[required] The ID of the project that currently owns business glossary. |
description |
The description of this business glossary. |
status |
The status of this business glossary. |
usageRestrictions |
The usage restriction of the restricted glossary. |
clientToken |
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.