View source: R/datazone_operations.R
| datazone_create_group_profile | R Documentation |
Creates a group profile in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_create_group_profile/ for full documentation.
datazone_create_group_profile(
domainIdentifier,
groupIdentifier = NULL,
rolePrincipalArn = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which the group profile is created. |
groupIdentifier |
The identifier of the group for which the group profile is created. |
rolePrincipalArn |
The ARN of the IAM role that will be associated with the group profile. This role defines the permissions that group members will assume when accessing Amazon DataZone resources. |
clientToken |
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.