View source: R/datazone_operations.R
| datazone_disassociate_governed_terms | R Documentation |
Disassociates restricted terms from an asset.
See https://www.paws-r-sdk.com/docs/datazone_disassociate_governed_terms/ for full documentation.
datazone_disassociate_governed_terms(
domainIdentifier,
entityIdentifier,
entityType,
governedGlossaryTerms
)
domainIdentifier |
[required] The ID of the domain where you want to disassociate restricted terms from an asset. |
entityIdentifier |
[required] The ID of an asset from which you want to disassociate restricted terms. |
entityType |
[required] The type of the asset from which you want to disassociate restricted terms. |
governedGlossaryTerms |
[required] The restricted glossary terms that you want to disassociate from an asset. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.