View source: R/datazone_operations.R
| datazone_get_notebook | R Documentation |
Gets the details of a notebook in Amazon SageMaker Unified Studio.
See https://www.paws-r-sdk.com/docs/datazone_get_notebook/ for full documentation.
datazone_get_notebook(domainIdentifier, identifier)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists. |
identifier |
[required] The identifier of the notebook. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.