View source: R/datazone_operations.R
| datazone_get_notebook_export | R Documentation |
Gets the details of a notebook export in Amazon SageMaker Unified Studio.
See https://www.paws-r-sdk.com/docs/datazone_get_notebook_export/ for full documentation.
datazone_get_notebook_export(domainIdentifier, identifier)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which the notebook export exists. |
identifier |
[required] The identifier of the notebook export. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.