View source: R/datazone_operations.R
| datazone_list_data_source_runs | R Documentation |
Lists data source runs in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_list_data_source_runs/ for full documentation.
datazone_list_data_source_runs(
domainIdentifier,
dataSourceIdentifier,
status = NULL,
nextToken = NULL,
maxResults = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which to invoke the |
dataSourceIdentifier |
[required] The identifier of the data source. |
status |
The status of the data source. |
nextToken |
When the number of runs is greater than the default value for the |
maxResults |
The maximum number of runs to return in a single call to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.