View source: R/datazone_operations.R
| datazone_list_notebooks | R Documentation |
Lists notebooks in Amazon SageMaker Unified Studio.
See https://www.paws-r-sdk.com/docs/datazone_list_notebooks/ for full documentation.
datazone_list_notebooks(
domainIdentifier,
owningProjectIdentifier,
maxResults = NULL,
sortOrder = NULL,
sortBy = NULL,
status = NULL,
nextToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which to list notebooks. |
owningProjectIdentifier |
[required] The identifier of the project that owns the notebooks. |
maxResults |
The maximum number of notebooks to return in a single call. When the number of notebooks exceeds the value of |
sortOrder |
The sort order for the results. |
sortBy |
The field to sort the results by. |
status |
The status to filter notebooks by. |
nextToken |
When the number of notebooks is greater than the default value for the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.