View source: R/datazone_operations.R
| datazone_put_environment_blueprint_configuration | R Documentation |
Writes the configuration for the specified environment blueprint in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_put_environment_blueprint_configuration/ for full documentation.
datazone_put_environment_blueprint_configuration(
domainIdentifier,
environmentBlueprintIdentifier,
provisioningRoleArn = NULL,
manageAccessRoleArn = NULL,
environmentRolePermissionBoundary = NULL,
enabledRegions,
regionalParameters = NULL,
resourceConfigurations = NULL,
allowUserProvidedConfigurations = NULL,
globalParameters = NULL,
provisioningConfigurations = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain. |
environmentBlueprintIdentifier |
[required] The identifier of the environment blueprint. |
provisioningRoleArn |
The ARN of the provisioning role. |
manageAccessRoleArn |
The ARN of the manage access role. |
environmentRolePermissionBoundary |
The environment role permissions boundary. |
enabledRegions |
[required] Specifies the enabled Amazon Web Services Regions. |
regionalParameters |
The regional parameters in the environment blueprint. |
resourceConfigurations |
The resource configurations of the environment blueprint. |
allowUserProvidedConfigurations |
Specifies whether user-provided resource configurations are allowed for the environment blueprint. |
globalParameters |
Region-agnostic environment blueprint parameters. |
provisioningConfigurations |
The provisioning configuration of a blueprint. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.