View source: R/datazone_operations.R
| datazone_query_graph | R Documentation |
Queries entities in the graph store.
See https://www.paws-r-sdk.com/docs/datazone_query_graph/ for full documentation.
datazone_query_graph(
domainIdentifier,
match,
maxResults = NULL,
nextToken = NULL,
additionalAttributes = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain. |
match |
[required] List of query match clauses. |
maxResults |
The maximum number of entities to return in a single call to |
nextToken |
When the number of entities is greater than the default value for the |
additionalAttributes |
Additional details on the queried entity that can be requested in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.