View source: R/datazone_operations.R
| datazone_start_metadata_generation_run | R Documentation |
Starts the metadata generation run.
See https://www.paws-r-sdk.com/docs/datazone_start_metadata_generation_run/ for full documentation.
datazone_start_metadata_generation_run(
domainIdentifier,
type = NULL,
types = NULL,
target,
clientToken = NULL,
owningProjectIdentifier
)
domainIdentifier |
[required] The ID of the Amazon DataZone domain where you want to start a metadata generation run. |
type |
The type of the metadata generation run. |
types |
The types of the metadata generation run. |
target |
[required] The asset for which you want to start a metadata generation run. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided. |
owningProjectIdentifier |
[required] The ID of the project that owns the asset for which you want to start a metadata generation run. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.