View source: R/datazone_operations.R
| datazone_start_notebook_import | R Documentation |
Starts a notebook import in Amazon SageMaker Unified Studio. This operation imports a notebook from an Amazon Simple Storage Service location into a project.
See https://www.paws-r-sdk.com/docs/datazone_start_notebook_import/ for full documentation.
datazone_start_notebook_import(
domainIdentifier,
owningProjectIdentifier,
sourceLocation,
name,
description = NULL,
clientToken = NULL
)
domainIdentifier |
[required] The identifier of the Amazon SageMaker Unified Studio domain in which to import the notebook. |
owningProjectIdentifier |
[required] The identifier of the project that will own the imported notebook. |
sourceLocation |
[required] The source location of the notebook to import. This specifies the Amazon Simple Storage Service URI of the notebook file. |
name |
[required] The name of the imported notebook. The name must be between 1 and 256 characters. |
description |
The description of the imported notebook. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.