View source: R/datazone_operations.R
| datazone_update_account_pool | R Documentation |
Updates the account pool.
See https://www.paws-r-sdk.com/docs/datazone_update_account_pool/ for full documentation.
datazone_update_account_pool(
domainIdentifier,
identifier,
name = NULL,
description = NULL,
resolutionStrategy = NULL,
accountSource = NULL
)
domainIdentifier |
[required] The domain ID where the account pool that is to be updated lives. |
identifier |
[required] The ID of the account pool that is to be updated. |
name |
The name of the account pool that is to be updated. |
description |
The description of the account pool that is to be udpated. |
resolutionStrategy |
The mechanism used to resolve the account selection from the account pool. |
accountSource |
The source of accounts for the account pool. In the current release, it's either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.