View source: R/datazone_operations.R
| datazone_update_environment_blueprint | R Documentation |
Updates an environment blueprint in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_update_environment_blueprint/ for full documentation.
datazone_update_environment_blueprint(
domainIdentifier,
identifier,
description = NULL,
provisioningProperties = NULL,
userParameters = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated. |
identifier |
[required] The identifier of the environment blueprint to be updated. |
description |
The description to be updated as part of the |
provisioningProperties |
The provisioning properties to be updated as part of the |
userParameters |
The user parameters to be updated as part of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.