View source: R/datazone_operations.R
| datazone_update_subscription_target | R Documentation |
Updates the specified subscription target in Amazon DataZone.
See https://www.paws-r-sdk.com/docs/datazone_update_subscription_target/ for full documentation.
datazone_update_subscription_target(
domainIdentifier,
environmentIdentifier,
identifier,
name = NULL,
authorizedPrincipals = NULL,
applicableAssetTypes = NULL,
subscriptionTargetConfig = NULL,
manageAccessRole = NULL,
provider = NULL,
subscriptionGrantCreationMode = NULL
)
domainIdentifier |
[required] The identifier of the Amazon DataZone domain in which a subscription target is to be updated. |
environmentIdentifier |
[required] The identifier of the environment in which a subscription target is to be updated. |
identifier |
[required] Identifier of the subscription target that is to be updated. |
name |
The name to be updated as part of the |
authorizedPrincipals |
The authorized principals to be updated as part of the |
applicableAssetTypes |
The applicable asset types to be updated as part of the |
subscriptionTargetConfig |
The configuration to be updated as part of the |
manageAccessRole |
The manage access role to be updated as part of the |
provider |
The provider to be updated as part of the |
subscriptionGrantCreationMode |
Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.