View source: R/elasticsearchservice_operations.R
| elasticsearchservice_get_compatible_elasticsearch_versions | R Documentation |
Returns a list of upgrade compatible Elastisearch versions. You can optionally pass a DomainName to get all upgrade compatible Elasticsearch versions for that specific domain.
See https://www.paws-r-sdk.com/docs/elasticsearchservice_get_compatible_elasticsearch_versions/ for full documentation.
elasticsearchservice_get_compatible_elasticsearch_versions(DomainName = NULL)
DomainName |
The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.