View source: R/elasticsearchservice_operations.R
| elasticsearchservice_get_upgrade_status | R Documentation |
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
See https://www.paws-r-sdk.com/docs/elasticsearchservice_get_upgrade_status/ for full documentation.
elasticsearchservice_get_upgrade_status(DomainName)
DomainName |
[required] The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.