View source: R/emr_operations.R
| emr_create_persistent_app_ui | R Documentation |
Creates a persistent application user interface.
See https://www.paws-r-sdk.com/docs/emr_create_persistent_app_ui/ for full documentation.
emr_create_persistent_app_ui(
TargetResourceArn,
EMRContainersConfig = NULL,
Tags = NULL,
XReferer = NULL,
ProfilerType = NULL
)
TargetResourceArn |
[required] The unique Amazon Resource Name (ARN) of the target resource. |
EMRContainersConfig |
The EMR containers configuration. |
Tags |
Tags for the persistent application user interface. |
XReferer |
The cross reference for the persistent application user interface. |
ProfilerType |
The profiler type for the persistent application user interface. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.