View source: R/emr_operations.R
| emr_get_persistent_app_ui_presigned_url | R Documentation |
The presigned URL properties for the cluster's application user interface.
See https://www.paws-r-sdk.com/docs/emr_get_persistent_app_ui_presigned_url/ for full documentation.
emr_get_persistent_app_ui_presigned_url(
PersistentAppUIId,
PersistentAppUIType = NULL,
ApplicationId = NULL,
AuthProxyCall = NULL,
ExecutionRoleArn = NULL
)
PersistentAppUIId |
[required] The persistent application user interface ID associated with the presigned URL. |
PersistentAppUIType |
The persistent application user interface type associated with the presigned URL. |
ApplicationId |
The application ID associated with the presigned URL. |
AuthProxyCall |
A boolean that represents if the caller is an authentication proxy call. |
ExecutionRoleArn |
The execution role ARN associated with the presigned URL. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.