View source: R/emr_operations.R
| emr_get_session_endpoint | R Documentation |
Returns the Spark Connect endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a PySpark client to the session. Call this operation again when the token expires to obtain a new one.
See https://www.paws-r-sdk.com/docs/emr_get_session_endpoint/ for full documentation.
emr_get_session_endpoint(ClusterId, SessionId)
ClusterId |
[required] The ID of the cluster that the session belongs to. |
SessionId |
[required] The ID of the session. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.