View source: R/emr_operations.R
| emr_list_sessions | R Documentation |
Lists the sessions on a cluster. You can filter the results by session state. Newer sessions are returned first.
See https://www.paws-r-sdk.com/docs/emr_list_sessions/ for full documentation.
emr_list_sessions(
ClusterId,
SessionStates = NULL,
NextToken = NULL,
MaxResults = NULL
)
ClusterId |
[required] The ID of the cluster to list sessions for. |
SessionStates |
An optional filter that limits the results to sessions in the specified states. |
NextToken |
The pagination token returned by a previous |
MaxResults |
The maximum number of sessions to return in each page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.