View source: R/entityresolution_operations.R
| entityresolution_add_policy_statement | R Documentation |
Adds a policy statement object. To retrieve a list of existing policy statements, use the get_policy API.
See https://www.paws-r-sdk.com/docs/entityresolution_add_policy_statement/ for full documentation.
entityresolution_add_policy_statement(
arn,
statementId,
effect,
action,
principal,
condition = NULL
)
arn |
[required] The Amazon Resource Name (ARN) of the resource that will be accessed by the principal. |
statementId |
[required] A statement identifier that differentiates the statement from others in the same policy. |
effect |
[required] Determines whether the permissions specified in the policy are to be allowed ( If you set the value of the |
action |
[required] The action that the principal can use on the resource. For example, |
principal |
[required] The Amazon Web Services service or Amazon Web Services account that can access the resource defined as ARN. |
condition |
A set of condition keys that you can use in key policies. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.