View source: R/entityresolution_operations.R
| entityresolution_create_matching_workflow | R Documentation |
Creates a matching workflow that defines the configuration for a data processing job. The workflow name must be unique. To modify an existing workflow, use update_matching_workflow.
See https://www.paws-r-sdk.com/docs/entityresolution_create_matching_workflow/ for full documentation.
entityresolution_create_matching_workflow(
workflowName,
description = NULL,
inputSourceConfig,
outputSourceConfig,
resolutionTechniques,
incrementalRunConfig = NULL,
roleArn,
tags = NULL
)
workflowName |
[required] The name of the workflow. There can't be multiple |
description |
A description of the workflow. |
inputSourceConfig |
[required] A list of |
outputSourceConfig |
[required] A list of |
resolutionTechniques |
[required] An object which defines the |
incrementalRunConfig |
Optional. An object that defines the incremental run type. This object contains only the For workflows where |
roleArn |
[required] The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this role to create resources on your behalf as part of workflow execution. |
tags |
The tags used to organize, track, or control access for this resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.