View source: R/entityresolution_operations.R
| entityresolution_generate_match_id | R Documentation |
Generates or retrieves Match IDs for records using a rule-based matching workflow. When you call this operation, it processes your records against the workflow's matching rules to identify potential matches. For existing records, it retrieves their Match IDs and associated rules. For records without matches, it generates new Match IDs. The operation saves results to Amazon S3.
See https://www.paws-r-sdk.com/docs/entityresolution_generate_match_id/ for full documentation.
entityresolution_generate_match_id(
workflowName,
records,
processingType = NULL
)
workflowName |
[required] The name of the rule-based matching workflow. |
records |
[required] The records to match. |
processingType |
The processing mode that determines how Match IDs are generated and results are saved. Each mode provides different levels of accuracy, response time, and completeness of results. If not specified, defaults to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.