View source: R/glue_operations.R
| glue_batch_get_data_quality_ruleset_evaluation_run | R Documentation |
Retrieves the details of multiple evaluation runs in a single request.
See https://www.paws-r-sdk.com/docs/glue_batch_get_data_quality_ruleset_evaluation_run/ for full documentation.
glue_batch_get_data_quality_ruleset_evaluation_run(RunIds)
RunIds |
[required] A list of unique run identifiers for the evaluation runs to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.