View source: R/glue_operations.R
| glue_delete_attachment | R Documentation |
Deletes a form attachment from an asset in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_delete_attachment/ for full documentation.
glue_delete_attachment(
AssetIdentifier,
IterableFormName = NULL,
ItemIdentifier = NULL,
AttachmentName
)
AssetIdentifier |
[required] The unique identifier of the asset from which to delete the attachment. |
IterableFormName |
The name of the iterable form. When specified along with |
ItemIdentifier |
The identifier of the item within the iterable form. Required when |
AttachmentName |
[required] The name of the attachment to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.