View source: R/glue_operations.R
| glue_delete_glue_identity_center_configuration | R Documentation |
Deletes the existing Glue Identity Center configuration, removing the integration between Glue and Amazon Web Services IAM Identity Center.
See https://www.paws-r-sdk.com/docs/glue_delete_glue_identity_center_configuration/ for full documentation.
glue_delete_glue_identity_center_configuration()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.