View source: R/glue_operations.R
| glue_describe_connection_type | R Documentation |
The describe_connection_type API provides full details of the supported options for a given connection type in Glue. The response includes authentication configuration details that show supported authentication types and properties, and RestConfiguration for custom REST-based connection types registered via register_connection_type.
See https://www.paws-r-sdk.com/docs/glue_describe_connection_type/ for full documentation.
glue_describe_connection_type(ConnectionType)
ConnectionType |
[required] The name of the connection type to be described. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.