View source: R/glue_operations.R
| glue_disassociate_glossary_terms | R Documentation |
Removes the association of one or more glossary terms from an asset in Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/glue_disassociate_glossary_terms/ for full documentation.
glue_disassociate_glossary_terms(
AssetIdentifier,
IterableFormName = NULL,
ItemIdentifier = NULL,
GlossaryTermIdentifiers,
ClientToken = NULL
)
AssetIdentifier |
[required] The unique identifier of the asset to disassociate glossary terms from. |
IterableFormName |
The name of the iterable form. When specified along with |
ItemIdentifier |
The identifier of the item within the iterable form. Required when |
GlossaryTermIdentifiers |
[required] The list of glossary term identifiers to disassociate from the asset. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.