View source: R/glue_operations.R
| glue_get_dashboard_url | R Documentation |
Retrieves the URL for the Spark monitoring dashboard for a Glue resource.
See https://www.paws-r-sdk.com/docs/glue_get_dashboard_url/ for full documentation.
glue_get_dashboard_url(ResourceId, ResourceType, RequestOrigin = NULL)
ResourceId |
[required] The unique identifier of the resource for which to retrieve the dashboard URL. |
ResourceType |
[required] The type of the resource. Valid values are |
RequestOrigin |
The origin of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.