View source: R/glue_operations.R
| glue_get_data_catalog_export_configuration | R Documentation |
Retrieves the current export configuration for the Glue Data Catalog. The export configuration controls whether catalog metadata is exported to S3 Tables.
See https://www.paws-r-sdk.com/docs/glue_get_data_catalog_export_configuration/ for full documentation.
glue_get_data_catalog_export_configuration()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.