View source: R/glue_operations.R
| glue_get_glue_identity_center_configuration | R Documentation |
Retrieves the current Glue Identity Center configuration details, including the associated Identity Center instance and application information.
See https://www.paws-r-sdk.com/docs/glue_get_glue_identity_center_configuration/ for full documentation.
glue_get_glue_identity_center_configuration()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.