View source: R/glue_operations.R
| glue_get_materialized_view_refresh_task_run | R Documentation |
Get the associated metadata/information for a task run, given a task run ID.
See https://www.paws-r-sdk.com/docs/glue_get_materialized_view_refresh_task_run/ for full documentation.
glue_get_materialized_view_refresh_task_run(
CatalogId,
MaterializedViewRefreshTaskRunId
)
CatalogId |
[required] The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default. |
MaterializedViewRefreshTaskRunId |
[required] The identifier for the particular materialized view refresh task run. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.