View source: R/glue_operations.R
| glue_get_partition | R Documentation |
Retrieves information about a specified partition.
See https://www.paws-r-sdk.com/docs/glue_get_partition/ for full documentation.
glue_get_partition(
CatalogId = NULL,
DatabaseName,
TableName,
PartitionValues,
AuditContext = NULL
)
CatalogId |
The ID of the Data Catalog where the partition in question resides. If none is provided, the Amazon Web Services account ID is used by default. |
DatabaseName |
[required] The name of the catalog database where the partition resides. |
TableName |
[required] The name of the partition's table. |
PartitionValues |
[required] The values that define the partition. |
AuditContext |
A structure containing the Lake Formation audit context. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.