View source: R/glue_operations.R
| glue_list_integration_table_properties | R Documentation |
Lists the integration table properties in your account. This operation supports filtering and pagination.
See https://www.paws-r-sdk.com/docs/glue_list_integration_table_properties/ for full documentation.
glue_list_integration_table_properties(
Marker = NULL,
Filters = NULL,
MaxRecords = NULL
)
Marker |
The pagination token for the next page of results. The initial value is |
Filters |
A list of filters. Supported filter keys are |
MaxRecords |
The maximum number of records to return in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.