View source: R/glue_operations.R
| glue_list_iterable_forms | R Documentation |
Lists the items in an iterable form on an asset in Glue Data Catalog. For example, lists the columns of a table asset.
See https://www.paws-r-sdk.com/docs/glue_list_iterable_forms/ for full documentation.
glue_list_iterable_forms(
AssetIdentifier,
IterableFormName,
MaxResults = NULL,
NextToken = NULL
)
AssetIdentifier |
[required] The unique identifier of the asset. |
IterableFormName |
[required] The name of the iterable form to list items from. |
MaxResults |
The maximum number of results to return in the response. |
NextToken |
A continuation token, if this is a continuation call. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.