View source: R/glue_operations.R
| glue_list_materialized_view_refresh_task_runs | R Documentation |
List all task runs for a particular account.
See https://www.paws-r-sdk.com/docs/glue_list_materialized_view_refresh_task_runs/ for full documentation.
glue_list_materialized_view_refresh_task_runs(
CatalogId,
DatabaseName = NULL,
TableName = NULL,
MaxResults = NULL,
NextToken = NULL
)
CatalogId |
[required] The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default. |
DatabaseName |
The database where the table resides. |
TableName |
The name of the table for which statistics is generated. |
MaxResults |
The maximum size of the response. |
NextToken |
A continuation token, if this is a continuation call. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.