View source: R/glue_operations.R
| glue_put_asset_type | R Documentation |
Creates or updates an asset type in Glue Data Catalog. An asset type defines the structure of assets by specifying which forms they include. If an asset type with the given name already exists, it is updated.
See https://www.paws-r-sdk.com/docs/glue_put_asset_type/ for full documentation.
glue_put_asset_type(Name, Forms, ClientToken = NULL)
Name |
[required] The name of the asset type. |
Forms |
[required] The forms that make up the asset type, keyed by form name. Each entry references the form type that defines the form's schema. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.