View source: R/glue_operations.R
| glue_put_attachment | R Documentation |
Attaches a form to an asset or an iterable form item in Glue Data Catalog. If an attachment with the same name already exists, it is overwritten.
See https://www.paws-r-sdk.com/docs/glue_put_attachment/ for full documentation.
glue_put_attachment(
AssetIdentifier,
IterableFormName = NULL,
ItemIdentifier = NULL,
AttachmentName,
Content,
FormTypeId,
ClientToken = NULL
)
AssetIdentifier |
[required] The unique identifier of the asset to attach the form to. |
IterableFormName |
The name of the iterable form. When specified along with |
ItemIdentifier |
The identifier of the item within the iterable form. Required when |
AttachmentName |
[required] The name of the attachment. |
Content |
[required] The JSON content of the form, conforming to the schema of the specified form type. |
FormTypeId |
[required] The identifier of the form type for this attachment. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.