View source: R/glue_operations.R
| glue_put_data_catalog_export_configuration | R Documentation |
Creates or updates the export configuration for the Glue Data Catalog. Use this operation to enable or disable the export of catalog metadata to S3 Tables.
See https://www.paws-r-sdk.com/docs/glue_put_data_catalog_export_configuration/ for full documentation.
glue_put_data_catalog_export_configuration(
ExportSetting,
EncryptionConfiguration = NULL,
ClientToken = NULL
)
ExportSetting |
[required] The export setting for the data catalog. Specify |
EncryptionConfiguration |
The encryption configuration for the exported data. If not specified, the default encryption settings are used. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.