View source: R/glue_operations.R
| glue_put_form_type | R Documentation |
Creates or updates a form type in Glue Data Catalog. A form type defines the schema for structured metadata that can be attached to assets.
See https://www.paws-r-sdk.com/docs/glue_put_form_type/ for full documentation.
glue_put_form_type(Name, Schema, ClientToken = NULL)
Name |
[required] The name of the form type. Must start with an uppercase letter. |
Schema |
[required] The Smithy IDL schema definition for the form type. |
ClientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.