View source: R/glue_operations.R
| glue_register_connection_type | R Documentation |
Registers a custom connection type in Glue based on the configuration provided. This operation enables customers to configure custom connectors for any data source with REST-based APIs, eliminating the need for building custom Lambda connectors.
See https://www.paws-r-sdk.com/docs/glue_register_connection_type/ for full documentation.
glue_register_connection_type(
ConnectionType,
IntegrationType,
Description = NULL,
ConnectionProperties,
ConnectorAuthenticationConfiguration,
RestConfiguration,
Tags = NULL
)
ConnectionType |
[required] The name of the connection type. Must be between 1 and 255 characters and must be prefixed with "REST-" to indicate it is a REST-based connector. |
IntegrationType |
[required] The integration type for the connection. Currently only "REST" protocol is supported. |
Description |
A description of the connection type. Can be up to 2048 characters and provides details about the purpose and functionality of the connection type. |
ConnectionProperties |
[required] Defines the base URL and additional request parameters needed during connection creation for this connection type. |
ConnectorAuthenticationConfiguration |
[required] Defines the supported authentication types and required properties for this connection type, including Basic, OAuth2, and Custom authentication methods. |
RestConfiguration |
[required] Defines the HTTP request and response configuration, validation endpoint, and entity configurations for REST API interactions. |
Tags |
The tags you assign to the connection type. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.