View source: R/glue_operations.R
| glue_search_assets | R Documentation |
Searches for assets in Glue Data Catalog using full-text search, filters, sorting, and aggregations. Returns matching assets with relevance-ranked results.
See https://www.paws-r-sdk.com/docs/glue_search_assets/ for full documentation.
glue_search_assets(
SearchText = NULL,
MaxResults = NULL,
NextToken = NULL,
Sort = NULL,
FilterClause = NULL
)
SearchText |
The text to search for. At least one of |
MaxResults |
The maximum number of results to return in the response. |
NextToken |
A continuation token, if this is a continuation call. |
Sort |
The sort criteria for the search results. |
FilterClause |
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.