View source: R/glue_operations.R
| glue_stop_materialized_view_refresh_task_run | R Documentation |
Stops a materialized view refresh task run, for a specified table and columns.
See https://www.paws-r-sdk.com/docs/glue_stop_materialized_view_refresh_task_run/ for full documentation.
glue_stop_materialized_view_refresh_task_run(
CatalogId,
DatabaseName,
TableName
)
CatalogId |
[required] The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default. |
DatabaseName |
[required] The name of the database where the table resides. |
TableName |
[required] The name of the table to generate statistics. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.