View source: R/glue_operations.R
| glue_update_glue_identity_center_configuration | R Documentation |
Updates the existing Glue Identity Center configuration, allowing modification of scopes and permissions for the integration.
See https://www.paws-r-sdk.com/docs/glue_update_glue_identity_center_configuration/ for full documentation.
glue_update_glue_identity_center_configuration(
Scopes = NULL,
UserBackgroundSessionsEnabled = NULL
)
Scopes |
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration. |
UserBackgroundSessionsEnabled |
Specifies whether users can run background sessions when using Identity Center authentication with Glue services. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.