View source: R/healthlake_operations.R
| healthlake_get_data_transformation_profile | R Documentation |
Retrieves a data transformation profile's metadata and profile content at a specific version. Specify version 0 to retrieve the DRAFT, a version number between 1 and 99 to retrieve a specific published version, or omit the version to retrieve the latest published version.
See https://www.paws-r-sdk.com/docs/healthlake_get_data_transformation_profile/ for full documentation.
healthlake_get_data_transformation_profile(ProfileId, ProfileVersion = NULL)
ProfileId |
[required] The unique identifier of the profile to retrieve. |
ProfileVersion |
The version number to retrieve. Specify 0 to retrieve the DRAFT version. If you omit this parameter, the service returns the latest published version. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.