View source: R/healthlake_operations.R
| healthlake_list_data_transformation_profile_versions | R Documentation |
Lists all versions of a specific data transformation profile (DRAFT and published), in reverse chronological order (newest first). Use get_data_transformation_profile to retrieve profile content. Results are paginated. Use the NextToken parameter to retrieve additional results.
See https://www.paws-r-sdk.com/docs/healthlake_list_data_transformation_profile_versions/ for full documentation.
healthlake_list_data_transformation_profile_versions(
ProfileId,
MaxResults = NULL,
NextToken = NULL
)
ProfileId |
[required] The unique identifier of the profile whose versions to list. |
MaxResults |
The maximum number of profile versions to return per page. If you don't specify a value, the service returns up to 100 results. |
NextToken |
The pagination token from a previous response. Pass this value to retrieve the next page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.