View source: R/healthlake_operations.R
| healthlake_list_fhir_import_jobs | R Documentation |
List all FHIR import jobs associated with an account and their statuses.
See https://www.paws-r-sdk.com/docs/healthlake_list_fhir_import_jobs/ for full documentation.
healthlake_list_fhir_import_jobs(
DatastoreId,
NextToken = NULL,
MaxResults = NULL,
JobName = NULL,
JobStatus = NULL,
SubmittedBefore = NULL,
SubmittedAfter = NULL
)
DatastoreId |
[required] Limits the response to the import job with the specified data store ID. |
NextToken |
The pagination token used to identify the next page of results to return. |
MaxResults |
Limits the number of results returned for |
JobName |
Limits the response to the import job with the specified job name. |
JobStatus |
Limits the response to the import job with the specified job status. |
SubmittedBefore |
Limits the response to FHIR import jobs submitted before a user- specified date. |
SubmittedAfter |
Limits the response to FHIR import jobs submitted after a user-specified date. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.