View source: R/healthlake_operations.R
| healthlake_restore_fhir_datastore | R Documentation |
Restore a backup-enabled data store to a point in time. Creates a new data store from the backup.
See https://www.paws-r-sdk.com/docs/healthlake_restore_fhir_datastore/ for full documentation.
healthlake_restore_fhir_datastore(
SourceDatastoreId,
RestoreConfiguration,
DatastoreName = NULL,
SseConfiguration = NULL,
ClientToken = NULL,
Tags = NULL,
IdentityProviderConfiguration = NULL,
AnalyticsConfiguration = NULL,
NlpConfiguration = NULL,
ProfileConfiguration = NULL
)
SourceDatastoreId |
[required] The identifier of the source data store to restore from. |
RestoreConfiguration |
[required] The restore configuration specifying the type and parameters for the restore. |
DatastoreName |
The name for the restored data store. |
SseConfiguration |
The server-side encryption key configuration for the restored data store. |
ClientToken |
An optional user-provided token to ensure API idempotency of the restore. |
Tags |
The resource tags applied to the restored data store. |
IdentityProviderConfiguration |
The identity provider configuration for the restored data store. |
AnalyticsConfiguration |
The analytics configuration for the restored data store. |
NlpConfiguration |
The NLP configuration for the restored data store. |
ProfileConfiguration |
The profile configuration for the restored data store. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.