View source: R/healthlake_operations.R
| healthlake_start_fhir_export_job | R Documentation |
Start a FHIR export job.
See https://www.paws-r-sdk.com/docs/healthlake_start_fhir_export_job/ for full documentation.
healthlake_start_fhir_export_job(
JobName = NULL,
OutputDataConfig,
DatastoreId,
DataAccessRoleArn,
ClientToken = NULL
)
JobName |
The export job name. |
OutputDataConfig |
[required] The output data configuration supplied when the export job was started. |
DatastoreId |
[required] The data store identifier from which files are being exported. |
DataAccessRoleArn |
[required] The Amazon Resource Name (ARN) used during initiation of the export job. |
ClientToken |
An optional user provided token used for ensuring API idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.