View source: R/healthlake_operations.R
| healthlake_start_fhir_import_job | R Documentation |
Start importing bulk FHIR data into an ACTIVE data store. The import job imports FHIR data found in the InputDataConfig object and stores processing results in the JobOutputDataConfig object.
See https://www.paws-r-sdk.com/docs/healthlake_start_fhir_import_job/ for full documentation.
healthlake_start_fhir_import_job(
JobName = NULL,
InputDataConfig,
JobOutputDataConfig,
DatastoreId,
DataAccessRoleArn,
ClientToken = NULL,
ValidationLevel = NULL
)
JobName |
The import job name. |
InputDataConfig |
[required] The input properties for the import job request. |
JobOutputDataConfig |
[required] The output data configuration supplied when the export job was created. |
DatastoreId |
[required] The data store identifier. |
DataAccessRoleArn |
[required] The Amazon Resource Name (ARN) that grants access permission to AWS HealthLake. |
ClientToken |
The optional user-provided token used for ensuring API idempotency. |
ValidationLevel |
The validation level of the import job. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.