View source: R/healthlake_operations.R
| healthlake_untag_resource | R Documentation |
Remove a user-specifed key and value tag from a data store.
See https://www.paws-r-sdk.com/docs/healthlake_untag_resource/ for full documentation.
healthlake_untag_resource(ResourceARN, TagKeys)
ResourceARN |
[required] The Amazon Resource Name (ARN) of the data store from which tags are being removed. |
TagKeys |
[required] The keys for the tags to be removed from the data store. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.