Creates a new channel and an associated stream key to start streaming.
See https://www.paws-r-sdk.com/docs/ivs_create_channel/ for full documentation.
ivs_create_channel(
authorized = NULL,
insecureIngest = NULL,
latencyMode = NULL,
name = NULL,
playbackRestrictionPolicyArn = NULL,
preset = NULL,
recordingConfigurationArn = NULL,
tags = NULL,
type = NULL
)Whether the channel is private (enabled for playback authorization).
Default: false.
Whether the channel allows insecure RTMP and SRT ingest. Default:
false.
Channel latency mode. Use NORMAL to broadcast and deliver live video
up to Full HD. Use LOW for near-real-time interaction with viewers.
Default: LOW.
Channel name.
Playback-restriction-policy ARN. A valid ARN value here both specifies the ARN and enables playback restriction. Default: "" (empty string, no playback restriction policy is applied).
Optional transcode preset for the channel. This is selectable only for
ADVANCED_HD and ADVANCED_SD channel types. For those channel types,
the default preset is HIGHER_BANDWIDTH_DELIVERY. For other channel
types (BASIC and STANDARD), preset is the empty string ("").
Recording-configuration ARN. A valid ARN value here both specifies the ARN and enables recording. Default: "" (empty string, recording is disabled).
Array of 1-50 maps, each of the form string:string (key:value). See
Tagging Amazon Web Services Resources
for more information, including restrictions that apply to tags and "Tag
naming limits and requirements"; Amazon IVS has no service-specific
constraints beyond what is documented there.
Channel type, which determines the allowable resolution and bitrate. If
you exceed the allowable input resolution or bitrate, the stream
probably will disconnect immediately. Default: STANDARD. For details,
see Channel Types.