View source: R/ivs_operations.R
| ivs_insert_ad_break | R Documentation |
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
See https://www.paws-r-sdk.com/docs/ivs_insert_ad_break/ for full documentation.
ivs_insert_ad_break(channelArn, durationSeconds)
channelArn |
[required] ARN of the channel into which the ad break is inserted. |
durationSeconds |
[required] Maximum duration of the ad break, in seconds. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.