View source: R/ivsrealtime_operations.R
| ivsrealtime_list_participant_replicas | R Documentation |
Lists all the replicas for a participant from a source stage.
See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participant_replicas/ for full documentation.
ivsrealtime_list_participant_replicas(
sourceStageArn,
participantId,
nextToken = NULL,
maxResults = NULL
)
sourceStageArn |
[required] ARN of the stage where the participant is publishing. |
participantId |
[required] Participant ID of the publisher that has been replicated. This is assigned by IVS and returned by |
nextToken |
The first participant to retrieve. This is used for pagination; see the |
maxResults |
Maximum number of results to return. Default: 50. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.