Learn R Programming

paws.analytics (version 0.6.0)

ivsrealtime_list_participants: Lists all participants in a specified stage session

Description

Lists all participants in a specified stage session.

See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participants/ for full documentation.

Usage

ivsrealtime_list_participants(
  filterByPublished = NULL,
  filterByState = NULL,
  filterByUserId = NULL,
  maxResults = NULL,
  nextToken = NULL,
  sessionId,
  stageArn
)

Arguments

filterByPublished

Filters the response list to only show participants who published during the stage session. Only one of filterByUserId, filterByPublished, or filterByState can be provided per request.

filterByState

Filters the response list to only show participants in the specified state. Only one of filterByUserId, filterByPublished, or filterByState can be provided per request.

filterByUserId

Filters the response list to match the specified user ID. Only one of filterByUserId, filterByPublished, or filterByState can be provided per request. A userId is a customer-assigned name to help identify the token; this can be used to link a participant to a user in the customer’s own systems.

maxResults

Maximum number of results to return. Default: 50.

nextToken

The first participant to retrieve. This is used for pagination; see the nextToken response field.

sessionId

[required] ID of the session within the stage.

stageArn

[required] Stage ARN.