Lists all participants in a specified stage session.
See https://www.paws-r-sdk.com/docs/ivsrealtime_list_participants/ for full documentation.
ivsrealtime_list_participants(
filterByPublished = NULL,
filterByState = NULL,
filterByUserId = NULL,
maxResults = NULL,
nextToken = NULL,
sessionId,
stageArn
)Filters the response list to only show participants who published during
the stage session. Only one of filterByUserId, filterByPublished, or
filterByState can be provided per request.
Filters the response list to only show participants in the specified
state. Only one of filterByUserId, filterByPublished, or
filterByState can be provided per request.
Filters the response list to match the specified user ID. Only one of
filterByUserId, filterByPublished, or filterByState can be
provided per request. A userId is a customer-assigned name to help
identify the token; this can be used to link a participant to a user in
the customer’s own systems.
Maximum number of results to return. Default: 50.
The first participant to retrieve. This is used for pagination; see the
nextToken response field.
[required] ID of the session within the stage.
[required] Stage ARN.