View source: R/ivsrealtime_operations.R
| ivsrealtime_stop_participant_replication | R Documentation |
Stops a replicated participant session.
See https://www.paws-r-sdk.com/docs/ivsrealtime_stop_participant_replication/ for full documentation.
ivsrealtime_stop_participant_replication(
sourceStageArn,
destinationStageArn,
participantId
)
sourceStageArn |
[required] ARN of the stage where the participant is publishing. |
destinationStageArn |
[required] ARN of the stage where the participant has been replicated. |
participantId |
[required] Participant ID of the publisher that has been replicated. This is assigned by IVS and returned by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.