View source: R/ivsrealtime_operations.R
| ivsrealtime_untag_resource | R Documentation |
Removes tags from the resource with the specified ARN.
See https://www.paws-r-sdk.com/docs/ivsrealtime_untag_resource/ for full documentation.
ivsrealtime_untag_resource(resourceArn, tagKeys)
resourceArn |
[required] The ARN of the resource to be untagged. The ARN must be URL-encoded. |
tagKeys |
[required] Array of tag keys (strings) for the tags to be removed. See Best practices and strategies in Tagging AWS Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no constraints on tags beyond what is documented there. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.