View source: R/kafka_operations.R
| kafka_describe_topic | R Documentation |
Returns topic details of this topic on a MSK cluster.
See https://www.paws-r-sdk.com/docs/kafka_describe_topic/ for full documentation.
kafka_describe_topic(ClusterArn, TopicName)
ClusterArn |
[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster. |
TopicName |
[required] The Kafka topic name that uniquely identifies the topic. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.