View source: R/kafka_operations.R
| kafka_describe_topic_partitions | R Documentation |
Returns partition details of this topic on a MSK cluster.
See https://www.paws-r-sdk.com/docs/kafka_describe_topic_partitions/ for full documentation.
kafka_describe_topic_partitions(
ClusterArn,
TopicName,
MaxResults = NULL,
NextToken = NULL
)
ClusterArn |
[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster. |
TopicName |
[required] The Kafka topic name that uniquely identifies the topic. |
MaxResults |
The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter. |
NextToken |
The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response. To get the next batch, provide this token in your next request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.