View source: R/kafka_operations.R
| kafka_update_channel | R Documentation |
Updates the destination configuration of an existing channel. Exactly one of icebergDestinationUpdate or s3DestinationUpdate must be supplied.
See https://www.paws-r-sdk.com/docs/kafka_update_channel/ for full documentation.
kafka_update_channel(
ChannelArn,
ClusterArn,
IcebergDestinationUpdate = NULL,
S3DestinationUpdate = NULL
)
ChannelArn |
[required] The Amazon Resource Name (ARN) that uniquely identifies the channel. |
ClusterArn |
[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster. |
IcebergDestinationUpdate |
Updates fields on an Apache Iceberg destination. Use only when the channel was created with an Iceberg destination. |
S3DestinationUpdate |
Updates fields on an Amazon S3 destination. Use only when the channel was created with an Amazon S3 destination. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.