View source: R/kafka_operations.R
| kafka_update_rebalancing | R Documentation |
Use this resource to update the intelligent rebalancing status of an Amazon MSK Provisioned cluster with Express brokers.
See https://www.paws-r-sdk.com/docs/kafka_update_rebalancing/ for full documentation.
kafka_update_rebalancing(ClusterArn, CurrentVersion, Rebalancing)
ClusterArn |
[required] The Amazon Resource Name (ARN) of the cluster. |
CurrentVersion |
[required] The current version of the cluster. |
Rebalancing |
[required] Specifies if intelligent rebalancing should be turned on for your cluster. The default intelligent rebalancing status is ACTIVE for all new MSK Provisioned clusters that you create with Express brokers. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.