View source: R/kafka_operations.R
| kafka_update_topic | R Documentation |
Updates the configuration of the specified topic.
See https://www.paws-r-sdk.com/docs/kafka_update_topic/ for full documentation.
kafka_update_topic(
ClusterArn,
TopicName,
Configs = NULL,
PartitionCount = NULL
)
ClusterArn |
[required] The Amazon Resource Name (ARN) that uniquely identifies the cluster. |
TopicName |
[required] The name of the topic to update configuration for. |
Configs |
The new topic configurations encoded as a Base64 string. |
PartitionCount |
The new total number of partitions for the topic. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.