View source: R/kafkaconnect_operations.R
| kafkaconnect_list_tags_for_resource | R Documentation |
Lists all the tags attached to the specified resource.
See https://www.paws-r-sdk.com/docs/kafkaconnect_list_tags_for_resource/ for full documentation.
kafkaconnect_list_tags_for_resource(resourceArn)
resourceArn |
[required] The Amazon Resource Name (ARN) of the resource for which you want to list all attached tags. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.