View source: R/kafkaconnect_operations.R
| kafkaconnect_restart_connector | R Documentation |
Restarts the specified connector. By default, this operation restarts the connector and all of its tasks. This operation is asynchronous and returns a connector operation ARN that you can pass to describe_connector_operation to track the state of the restart.
See https://www.paws-r-sdk.com/docs/kafkaconnect_restart_connector/ for full documentation.
kafkaconnect_restart_connector(connectorArn, onlyFailedTasks = NULL)
connectorArn |
[required] The Amazon Resource Name (ARN) of the connector that you want to restart. |
onlyFailedTasks |
Specifies whether to restart only the connector's failed tasks. If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.