View source: R/kinesis_operations.R
| kinesis_create_channel | R Documentation |
Creates a channel that delivers records from a Kinesis data stream to a destination. A channel reads records from the specified stream and writes them to streaming tables on Apache Iceberg (Amazon S3 Tables) or to a general purpose Amazon S3 bucket.
See https://www.paws-r-sdk.com/docs/kinesis_create_channel/ for full documentation.
kinesis_create_channel(
ChannelName,
ServiceExecutionRoleARN,
StreamConfigurationList,
S3DestinationConfiguration = NULL,
S3TablesDestinationConfiguration = NULL,
EncryptionConfiguration = NULL,
Tags = NULL,
LoggingConfiguration = NULL
)
ChannelName |
[required] The name of the channel. The name is unique within your Amazon Web Services account and Amazon Web Services Region. |
ServiceExecutionRoleARN |
[required] The Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Data Streams assumes to write records to the destination. |
StreamConfigurationList |
[required] The source stream configuration for the channel. Currently, one stream is supported per channel. |
S3DestinationConfiguration |
The configuration for delivery to a general purpose Amazon S3 bucket. Specify this parameter when |
S3TablesDestinationConfiguration |
The configuration for delivery to streaming tables on Apache Iceberg in Amazon S3 Tables. Specify this parameter when |
EncryptionConfiguration |
The server-side encryption configuration that uses an Amazon Web Services KMS key to encrypt data delivered to the destination. |
Tags |
A set of key-value pairs to assign to the channel. A tag consists of a required key and an optional value. |
LoggingConfiguration |
The Amazon CloudWatch Logs configuration for the channel. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.