View source: R/kinesis_operations.R
| kinesis_delete_channel | R Documentation |
Deletes the specified channel. Deleting a channel stops delivery from the source stream to the destination. Data already delivered to the destination is not deleted.
See https://www.paws-r-sdk.com/docs/kinesis_delete_channel/ for full documentation.
kinesis_delete_channel(ChannelARN)
ChannelARN |
[required] The Amazon Resource Name (ARN) of the channel to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.