View source: R/kinesis_operations.R
| kinesis_list_channels | R Documentation |
Lists the channels in your account. You can filter the results by source stream. The results are paginated. Use the NextToken value returned in the response to retrieve additional results.
See https://www.paws-r-sdk.com/docs/kinesis_list_channels/ for full documentation.
kinesis_list_channels(StreamFilter = NULL, MaxResults = NULL, NextToken = NULL)
StreamFilter |
Filters the results to channels associated with the specified streams. |
MaxResults |
The maximum number of channels to return in a single call. The default value is 100. If you specify a value greater than 100, at most 100 results are returned. |
NextToken |
The pagination token returned by a previous call. Specify this token to retrieve the next page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.