View source: R/kinesis_operations.R
| kinesis_untag_resource | R Documentation |
Removes tags from the specified Kinesis resource. Removed tags are deleted and can't be recovered after this operation completes successfully.
See https://www.paws-r-sdk.com/docs/kinesis_untag_resource/ for full documentation.
kinesis_untag_resource(TagKeys, ResourceARN, StreamId = NULL)
TagKeys |
[required] A list of tag key-value pairs. Existing tags of the resource whose keys are members of this list will be removed from the Kinesis resource. |
ResourceARN |
[required] The Amazon Resource Name (ARN) of the Kinesis resource from which to remove tags. |
StreamId |
Not Implemented. Reserved for future use. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.