View source: R/kinesis_operations.R
| kinesis_update_channel | R Documentation |
Updates the data freshness interval or the Amazon CloudWatch Logs configuration of an existing channel. You cannot change the destination, source stream, record format, schema, encryption configuration, or service execution role of an existing channel. To change any other setting, delete the channel and create a new one.
See https://www.paws-r-sdk.com/docs/kinesis_update_channel/ for full documentation.
kinesis_update_channel(
ChannelARN,
S3DestinationConfiguration = NULL,
S3TablesDestinationConfiguration = NULL,
LoggingConfiguration = NULL
)
ChannelARN |
[required] The Amazon Resource Name (ARN) of the channel to update. |
S3DestinationConfiguration |
The updated configuration for a general purpose Amazon S3 destination. Specify this parameter when the channel delivers to a general purpose Amazon S3 bucket. Only |
S3TablesDestinationConfiguration |
The updated configuration for a streaming table destination. Specify this parameter when the channel delivers to streaming tables on Apache Iceberg in Amazon S3 Tables. Only |
LoggingConfiguration |
The updated Amazon CloudWatch Logs configuration for the channel. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.