View source: R/kinesis_operations.R
| kinesis_update_max_record_size | R Documentation |
This allows you to update the MaxRecordSize of a single record that you can write to, and read from a stream. You can ingest and digest single records up to 10240 KiB.
See https://www.paws-r-sdk.com/docs/kinesis_update_max_record_size/ for full documentation.
kinesis_update_max_record_size(
StreamARN = NULL,
StreamId = NULL,
MaxRecordSizeInKiB
)
StreamARN |
The Amazon Resource Name (ARN) of the stream for the |
StreamId |
Not Implemented. Reserved for future use. |
MaxRecordSizeInKiB |
[required] The maximum record size of a single record in KiB that you can write to, and read from a stream. Specify a value between 1024 and 10240 KiB (1 to 10 MiB). If you specify a value that is out of this range, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.