View source: R/kinesis_operations.R
| kinesis_update_stream_record_distribution_strategy | R Documentation |
Updates the record distribution strategy for the specified Amazon Kinesis Data Streams on-demand data stream. The record distribution strategy determines how Amazon Kinesis Data Streams distributes records across the shards in a stream.
See https://www.paws-r-sdk.com/docs/kinesis_update_stream_record_distribution_strategy/ for full documentation.
kinesis_update_stream_record_distribution_strategy(
StreamARN,
StreamId = NULL,
RecordDistributionStrategy
)
StreamARN |
[required] The Amazon Resource Name (ARN) of the stream to update. |
StreamId |
Not Implemented. Reserved for future use. |
RecordDistributionStrategy |
[required] The record distribution strategy to apply to the stream. Specify one of the following values:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.