View source: R/kinesis_operations.R
| kinesis_update_stream_warm_throughput | R Documentation |
Updates the warm throughput configuration for the specified Amazon Kinesis Data Streams on-demand data stream. This operation allows you to proactively scale your on-demand data stream to a specified throughput level, enabling better performance for sudden traffic spikes.
See https://www.paws-r-sdk.com/docs/kinesis_update_stream_warm_throughput/ for full documentation.
kinesis_update_stream_warm_throughput(
StreamARN = NULL,
StreamName = NULL,
StreamId = NULL,
WarmThroughputMiBps
)
StreamARN |
The ARN of the stream to be updated. |
StreamName |
The name of the stream to be updated. |
StreamId |
Not Implemented. Reserved for future use. |
WarmThroughputMiBps |
[required] The target warm throughput in MB/s that the stream should be scaled to handle. This represents the throughput capacity that will be immediately available for write operations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.