View source: R/kinesisanalyticsv2_operations.R
| kinesisanalyticsv2_list_application_operations | R Documentation |
Lists all the operations performed for the specified application such as UpdateApplication, StartApplication etc. The response also includes a summary of the operation.
See https://www.paws-r-sdk.com/docs/kinesisanalyticsv2_list_application_operations/ for full documentation.
kinesisanalyticsv2_list_application_operations(
ApplicationName,
Limit = NULL,
NextToken = NULL,
Operation = NULL,
OperationStatus = NULL
)
ApplicationName |
[required] The name of the application. |
Limit |
The limit on the number of records to be returned in the response. |
NextToken |
A pagination token that can be used in a subsequent request. |
Operation |
The type of operation that is performed on an application. |
OperationStatus |
The status of the operation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.