View source: R/opensearchingestion_operations.R
| opensearchingestion_create_pipeline_endpoint | R Documentation |
Creates a VPC endpoint for an OpenSearch Ingestion pipeline. Pipeline endpoints allow you to ingest data from your VPC into pipelines that you have access to.
See https://www.paws-r-sdk.com/docs/opensearchingestion_create_pipeline_endpoint/ for full documentation.
opensearchingestion_create_pipeline_endpoint(PipelineArn, VpcOptions)
PipelineArn |
[required] The Amazon Resource Name (ARN) of the pipeline to create the endpoint for. |
VpcOptions |
[required] Container for the VPC configuration for the pipeline endpoint, including subnet IDs and security group IDs. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.