View source: R/opensearchingestion_operations.R
| opensearchingestion_list_pipeline_endpoint_connections | R Documentation |
Lists the pipeline endpoints connected to pipelines in your account.
See https://www.paws-r-sdk.com/docs/opensearchingestion_list_pipeline_endpoint_connections/ for full documentation.
opensearchingestion_list_pipeline_endpoint_connections(
MaxResults = NULL,
NextToken = NULL
)
MaxResults |
The maximum number of pipeline endpoint connections to return in the response. |
NextToken |
If your initial |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.