View source: R/opensearchingestion_operations.R
| opensearchingestion_revoke_pipeline_endpoint_connections | R Documentation |
Revokes pipeline endpoints from specified endpoint IDs.
See https://www.paws-r-sdk.com/docs/opensearchingestion_revoke_pipeline_endpoint_connections/ for full documentation.
opensearchingestion_revoke_pipeline_endpoint_connections(
PipelineArn,
EndpointIds
)
PipelineArn |
[required] The Amazon Resource Name (ARN) of the pipeline from which to revoke endpoint connections. |
EndpointIds |
[required] A list of endpoint IDs for which to revoke access to the pipeline. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.