View source: R/opensearchservice_operations.R
| opensearchservice_delete_index | R Documentation |
Deletes an OpenSearch index. This operation permanently removes the index and cannot be undone.
See https://www.paws-r-sdk.com/docs/opensearchservice_delete_index/ for full documentation.
opensearchservice_delete_index(DomainName, IndexName)
DomainName |
[required] The name of an OpenSearch Service domain. Domain names are unique across the domains owned by an account within an Amazon Web Services Region. |
IndexName |
[required] The name of the index to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.