View source: R/opensearchservice_operations.R
| opensearchservice_describe_data_source_attachment | R Documentation |
Returns the current status and details of a specific data source attachment for an OpenSearch application. Throws a ResourceNotFoundException if no attachment record exists for the specified application and data source combination.
See https://www.paws-r-sdk.com/docs/opensearchservice_describe_data_source_attachment/ for full documentation.
opensearchservice_describe_data_source_attachment(id, dataSourceArn)
id |
[required] The unique identifier or name of the OpenSearch application. |
dataSourceArn |
[required] The Amazon Resource Name (ARN) of the domain. See Identifiers for IAM Entities in Using Amazon Web Services Identity and Access Management for more information. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.