View source: R/opensearchservice_operations.R
| opensearchservice_get_migration | R Documentation |
Retrieves the current status and progress of a migration job, including the number of exported and imported objects and error details if the migration failed.
See https://www.paws-r-sdk.com/docs/opensearchservice_get_migration/ for full documentation.
opensearchservice_get_migration(migrationId)
migrationId |
[required] The unique identifier of the migration job to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.