View source: R/opensearchservice_operations.R
| opensearchservice_put_default_application_setting | R Documentation |
Sets the default application to the application with the specified ARN.
See https://www.paws-r-sdk.com/docs/opensearchservice_put_default_application_setting/ for full documentation.
opensearchservice_put_default_application_setting(applicationArn, setAsDefault)
applicationArn |
[required] The Amazon Resource Name (ARN) of the domain. See Identifiers for IAM Entities in Using Amazon Web Services Identity and Access Management for more information. |
setAsDefault |
[required] Set to true to set the specified ARN as the default application. Set to false to clear the default application. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.