View source: R/opensearchservice_operations.R
| opensearchservice_rollback_service_software_update | R Documentation |
Rolls back a service software update for a domain to the previous version. For more information, see Service software updates in Amazon OpenSearch Service.
See https://www.paws-r-sdk.com/docs/opensearchservice_rollback_service_software_update/ for full documentation.
opensearchservice_rollback_service_software_update(DomainName)
DomainName |
[required] The name of the domain to roll back the service software update on. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.