View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_batch_get_collection_group | R Documentation |
Returns attributes for one or more collection groups, including capacity limits and the number of collections in each group. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_batch_get_collection_group/ for full documentation.
opensearchserviceserverless_batch_get_collection_group(
ids = NULL,
names = NULL
)
ids |
A list of collection group IDs. You can't provide names and IDs in the same request. |
names |
A list of collection group names. You can't provide names and IDs in the same request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.