View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_create_collection_group | R Documentation |
Creates a collection group within OpenSearch Serverless. Collection groups let you manage OpenSearch Compute Units (OCUs) at a group level, with multiple collections sharing the group's capacity limits.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_create_collection_group/ for full documentation.
opensearchserviceserverless_create_collection_group(
name,
standbyReplicas,
description = NULL,
tags = NULL,
capacityLimits = NULL,
clientToken = NULL
)
name |
[required] The name of the collection group. |
standbyReplicas |
[required] Indicates whether standby replicas should be used for a collection group. |
description |
A description of the collection group. |
tags |
An arbitrary set of tags (key–value pairs) to associate with the OpenSearch Serverless collection group. |
capacityLimits |
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs). These limits control the maximum and minimum capacity for collections within the group. |
clientToken |
Unique, case-sensitive identifier to ensure idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.