View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_delete_index | R Documentation |
Deletes an index from an OpenSearch Serverless collection. Be aware that the index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_delete_index/ for full documentation.
opensearchserviceserverless_delete_index(id, indexName)
id |
[required] The unique identifier of the collection containing the index to delete. |
indexName |
[required] The name of the index to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.