View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_get_index | R Documentation |
Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition. The index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_get_index/ for full documentation.
opensearchserviceserverless_get_index(id, indexName)
id |
[required] The unique identifier of the collection containing the index. |
indexName |
[required] The name of the index to retrieve information about. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.