View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_update_account_settings | R Documentation |
Update the OpenSearch Serverless settings for the current Amazon Web Services account. For more information, see Managing capacity limits for Amazon OpenSearch Serverless.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_update_account_settings/ for full documentation.
opensearchserviceserverless_update_account_settings(capacityLimits = NULL)
capacityLimits |
The maximum capacity limits for all OpenSearch Serverless collections, in OpenSearch Compute Units (OCUs). These limits are used to scale your collections based on the current workload. For more information, see Managing capacity limits for Amazon OpenSearch Serverless. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.