View source: R/opensearchserviceserverless_operations.R
| opensearchserviceserverless_update_collection_group | R Documentation |
Updates the description and capacity limits of a collection group.
See https://www.paws-r-sdk.com/docs/opensearchserviceserverless_update_collection_group/ for full documentation.
opensearchserviceserverless_update_collection_group(
id,
description = NULL,
capacityLimits = NULL,
clientToken = NULL
)
id |
[required] The unique identifier of the collection group to update. |
description |
A new description for the collection group. |
capacityLimits |
Updated capacity limits for the collection group, in OpenSearch Compute Units (OCUs). |
clientToken |
Unique, case-sensitive identifier to ensure idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.