View source: R/quicksight_operations.R
| quicksight_create_account_customization | R Documentation |
Creates Amazon Quick Sight customizations. Currently, you can add a custom default theme by using the create_account_customization or update_account_customization API operation. To further customize Amazon Quick Sight by removing Amazon Quick Sight sample assets and videos for all new users, see Customizing Quick Sight in the Amazon Quick Sight User Guide.
See https://www.paws-r-sdk.com/docs/quicksight_create_account_customization/ for full documentation.
quicksight_create_account_customization(
AwsAccountId,
Namespace = NULL,
AccountCustomization,
Tags = NULL
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that you want to customize Quick Sight for. |
Namespace |
The Quick Sight namespace that you want to add customizations to. |
AccountCustomization |
[required] The Quick Sight customizations you're adding. You can add these to an Amazon Web Services account and a QuickSight namespace. For example, you can add a default theme by setting |
Tags |
A list of the tags that you want to attach to this resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.