View source: R/quicksight_operations.R
| quicksight_create_approval_policy | R Documentation |
Creates an approval policy in Quick Sight.
See https://www.paws-r-sdk.com/docs/quicksight_create_approval_policy/ for full documentation.
quicksight_create_approval_policy(
PolicyId,
Name,
Description = NULL,
Actions,
AssetTypes,
ApplicableTo,
ApprovalGroups
)
PolicyId |
[required] The unique identifier to assign to the approval policy. You cannot change this value after you create the policy. |
Name |
[required] The name of the approval policy. |
Description |
A description of the approval policy. |
Actions |
[required] The list of governed actions that trigger the approval workflow. |
AssetTypes |
[required] The list of asset types that the approval policy applies to. |
ApplicableTo |
[required] The scoping configuration that determines who the approval policy applies to. |
ApprovalGroups |
[required] The list of group ARNs whose members can approve requests. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.