View source: R/quicksight_operations.R
| quicksight_create_group_membership | R Documentation |
Adds an Amazon Quick Sight user to an Amazon Quick Sight group.
See https://www.paws-r-sdk.com/docs/quicksight_create_group_membership/ for full documentation.
quicksight_create_group_membership(
MemberName,
GroupName,
AwsAccountId,
Namespace
)
MemberName |
[required] The name of the user that you want to add to the group membership. |
GroupName |
[required] The name of the group that you want to add the user to. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace that you want the user to be a part of. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.