View source: R/quicksight_operations.R
| quicksight_create_o_auth_client_application | R Documentation |
Creates an OAuthClientApplication.
See https://www.paws-r-sdk.com/docs/quicksight_create_o_auth_client_application/ for full documentation.
quicksight_create_o_auth_client_application(
AwsAccountId,
OAuthClientApplicationId,
Name,
OAuthClientAuthenticationType,
ClientId,
ClientSecret,
OAuthTokenEndpointUrl,
OAuthAuthorizationEndpointUrl = NULL,
OAuthScopes = NULL,
DataSourceType = NULL,
IdentityProviderVpcConnectionProperties = NULL,
Tags = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID. |
OAuthClientApplicationId |
[required] An ID for the OAuthClientApplication that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account. |
Name |
[required] The display name for the OAuthClientApplication. |
OAuthClientAuthenticationType |
[required] The authentication type to use for the OAuthClientApplication. This determines the OAuth 2.0 grant flow that is used when the data source connects to the identity provider. Valid values are |
ClientId |
[required] The client ID of the OAuth application that is registered with the identity provider. |
ClientSecret |
[required] The client secret of the OAuth application that is registered with the identity provider. |
OAuthTokenEndpointUrl |
[required] The token endpoint URL of the identity provider that is used to obtain access tokens. |
OAuthAuthorizationEndpointUrl |
The authorization endpoint URL of the identity provider that is used to obtain authorization codes. |
OAuthScopes |
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider. |
DataSourceType |
The type of data source that the OAuthClientApplication is used with. Valid values are |
IdentityProviderVpcConnectionProperties |
VPC connection properties. |
Tags |
Contains a map of the key-value pairs for the resource tag or tags assigned to the OAuthClientApplication. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.