View source: R/quicksight_operations.R
| quicksight_create_space | R Documentation |
Creates a new Amazon QuickSight space. A space is a collection of resources that can be used to organize and manage QuickSight assets.
See https://www.paws-r-sdk.com/docs/quicksight_create_space/ for full documentation.
quicksight_create_space(AwsAccountId, SpaceId, Name, Description = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the space. |
SpaceId |
[required] The ID of the space. This ID is unique per Amazon Web Services Region for each Amazon Web Services account. |
Name |
[required] A display name for the space. |
Description |
A description of the space. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.