View source: R/quicksight_operations.R
| quicksight_delete_account_custom_permission | R Documentation |
Unapplies a custom permissions profile from an account.
See https://www.paws-r-sdk.com/docs/quicksight_delete_account_custom_permission/ for full documentation.
quicksight_delete_account_custom_permission(AwsAccountId)
AwsAccountId |
[required] The ID of the Amazon Web Services account from which you want to unapply the custom permissions profile. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.