View source: R/quicksight_operations.R
| quicksight_delete_account_customization | R Documentation |
This API permanently deletes all Quick Sight customizations for the specified Amazon Web Services account and namespace. When you delete account customizations:
See https://www.paws-r-sdk.com/docs/quicksight_delete_account_customization/ for full documentation.
quicksight_delete_account_customization(AwsAccountId, Namespace = NULL)
AwsAccountId |
[required] The ID for the Amazon Web Services account that you want to delete Quick Sight customizations from. |
Namespace |
The Quick Sight namespace that you're deleting the customizations from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.