View source: R/quicksight_operations.R
| quicksight_delete_app | R Documentation |
Deletes an app.
See https://www.paws-r-sdk.com/docs/quicksight_delete_app/ for full documentation.
quicksight_delete_app(AwsAccountId, AppId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the app. |
AppId |
[required] The ID of the app that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.