View source: R/quicksight_operations.R
| quicksight_delete_dlp_setting | R Documentation |
Deletes a DLP setting configuration from an Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/quicksight_delete_dlp_setting/ for full documentation.
quicksight_delete_dlp_setting(AwsAccountId, DlpSettingId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the DLP setting that you want to delete. |
DlpSettingId |
[required] The ID of the DLP setting that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.