View source: R/quicksight_operations.R
| quicksight_delete_flow | R Documentation |
Permanently deletes a flow from the specified Amazon Web Services account. This operation cannot be undone.
See https://www.paws-r-sdk.com/docs/quicksight_delete_flow/ for full documentation.
quicksight_delete_flow(AwsAccountId, FlowId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow that you are deleting. |
FlowId |
[required] The unique identifier of the flow to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.