View source: R/quicksight_operations.R
| quicksight_delete_group | R Documentation |
Removes a user group from Amazon Quick Sight.
See https://www.paws-r-sdk.com/docs/quicksight_delete_group/ for full documentation.
quicksight_delete_group(GroupName, AwsAccountId, Namespace)
GroupName |
[required] The name of the group that you want to delete. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace of the group that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.