View source: R/quicksight_operations.R
| quicksight_delete_limits_profile | R Documentation |
Deletes a limits profile.
See https://www.paws-r-sdk.com/docs/quicksight_delete_limits_profile/ for full documentation.
quicksight_delete_limits_profile(profileId, accountId)
profileId |
[required] The unique identifier for the limits profile to delete. |
accountId |
[required] The ID of the Amazon Web Services account that contains the limits profile. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.