View source: R/quicksight_operations.R
| quicksight_delete_space | R Documentation |
Deletes an Amazon QuickSight space.
See https://www.paws-r-sdk.com/docs/quicksight_delete_space/ for full documentation.
quicksight_delete_space(AwsAccountId, SpaceId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the space. |
SpaceId |
[required] The ID of the space that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.