View source: R/quicksight_operations.R
| quicksight_delete_user | R Documentation |
Deletes the Amazon Quick Sight user that is associated with the identity of the IAM user or role that's making the call. The IAM user isn't deleted as a result of this call.
See https://www.paws-r-sdk.com/docs/quicksight_delete_user/ for full documentation.
quicksight_delete_user(UserName, AwsAccountId, Namespace)
UserName |
[required] The name of the user that you want to delete. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace. Currently, you should set this to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.