View source: R/quicksight_operations.R
| quicksight_describe_account_customization | R Documentation |
Describes the customizations associated with the provided Amazon Web Services account and Amazon Quick Sight namespace. The Quick Sight console evaluates which customizations to apply by running this API operation with the Resolved flag included.
See https://www.paws-r-sdk.com/docs/quicksight_describe_account_customization/ for full documentation.
quicksight_describe_account_customization(
AwsAccountId,
Namespace = NULL,
Resolved = NULL
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that you want to describe Quick Sight customizations for. |
Namespace |
The Quick Sight namespace that you want to describe Quick Sight customizations for. |
Resolved |
The |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.