View source: R/quicksight_operations.R
| quicksight_describe_flow | R Documentation |
Returns the full details of a flow for the latest version of the requested publish state.
See https://www.paws-r-sdk.com/docs/quicksight_describe_flow/ for full documentation.
quicksight_describe_flow(AwsAccountId, FlowId, PublishState)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow that you are describing. |
FlowId |
[required] The unique identifier of the flow. |
PublishState |
[required] The publish state of the flow version to describe. Valid values are |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.