View source: R/quicksight_operations.R
| quicksight_describe_self_upgrade_configuration | R Documentation |
Describes the self-upgrade configuration for a Quick account.
See https://www.paws-r-sdk.com/docs/quicksight_describe_self_upgrade_configuration/ for full documentation.
quicksight_describe_self_upgrade_configuration(AwsAccountId, Namespace)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration. |
Namespace |
[required] The Quick namespace that you want to describe the Quick self-upgrade configuration for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.