View source: R/quicksight_operations.R
| quicksight_describe_space | R Documentation |
Describes an Amazon QuickSight space.
See https://www.paws-r-sdk.com/docs/quicksight_describe_space/ for full documentation.
quicksight_describe_space(AwsAccountId, SpaceId, MaxContributors = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the space. |
SpaceId |
[required] The ID of the space that you want to describe. |
MaxContributors |
The maximum number of contributors to include in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.