View source: R/quicksight_operations.R
| quicksight_describe_space_permissions | R Documentation |
Describes the permissions for an Amazon QuickSight space.
See https://www.paws-r-sdk.com/docs/quicksight_describe_space_permissions/ for full documentation.
quicksight_describe_space_permissions(AwsAccountId, SpaceId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the space. |
SpaceId |
[required] The ID of the space that you want to describe permissions for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.