View source: R/quicksight_operations.R
| quicksight_get_flow_metadata | R Documentation |
Retrieves the metadata of a flow, not including its definition specifying the steps.
See https://www.paws-r-sdk.com/docs/quicksight_get_flow_metadata/ for full documentation.
quicksight_get_flow_metadata(AwsAccountId, FlowId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow that you are getting metadata for. |
FlowId |
[required] The unique identifier of the flow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.