View source: R/quicksight_operations.R
| quicksight_get_flow_permissions | R Documentation |
Get permissions for a flow.
See https://www.paws-r-sdk.com/docs/quicksight_get_flow_permissions/ for full documentation.
quicksight_get_flow_permissions(AwsAccountId, FlowId)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow that you are getting permissions for. |
FlowId |
[required] The unique identifier of the flow to get permissions from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.