View source: R/quicksight_operations.R
| quicksight_get_identity_context | R Documentation |
Retrieves the identity context for a Quick Sight user in a specified namespace, allowing you to obtain identity tokens that can be used with identity-enhanced IAM role sessions to call identity-aware APIs.
See https://www.paws-r-sdk.com/docs/quicksight_get_identity_context/ for full documentation.
quicksight_get_identity_context(
AwsAccountId,
UserIdentifier,
Namespace = NULL,
SessionExpiresAt = NULL,
ContextRegion = NULL
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in. Currently, you use the ID for the Amazon Web Services account that contains your Quick Sight account. |
UserIdentifier |
[required] The identifier for the user whose identity context you want to retrieve. |
Namespace |
The namespace of the user that you want to get identity context for. This parameter is required when the UserIdentifier is specified using Email or UserName. |
SessionExpiresAt |
The timestamp at which the session will expire. |
ContextRegion |
The region in which the context is to be used. Use this parameter to obtain an identity context for cross-region use. The specified region must meet the following conditions:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.