View source: R/quicksight_operations.R
| quicksight_list_action_connectors | R Documentation |
Lists all action connectors in the specified Amazon Web Services account. Returns summary information for each connector including its name, type, creation time, and status.
See https://www.paws-r-sdk.com/docs/quicksight_list_action_connectors/ for full documentation.
quicksight_list_action_connectors(
AwsAccountId,
MaxResults = NULL,
NextToken = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID for which to list action connectors. |
MaxResults |
The maximum number of action connectors to return in a single response. Valid range is 1 to 100. |
NextToken |
A pagination token to retrieve the next set of results. Use the token returned from a previous call to continue listing action connectors. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.