View source: R/quicksight_operations.R
| quicksight_list_agents | R Documentation |
Lists all agents in an Amazon QuickSight account.
See https://www.paws-r-sdk.com/docs/quicksight_list_agents/ for full documentation.
quicksight_list_agents(AwsAccountId, MaxResults = NULL, NextToken = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the agents. |
MaxResults |
The maximum number of results to return. |
NextToken |
The token for the next set of results, or null if there are no more results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.