View source: R/quicksight_operations.R
| quicksight_list_approval_policies | R Documentation |
Lists all approval policies in the specified Quick Sight account. The results are paginated. If the response includes a NextToken value, pass it in a subsequent call to retrieve the next set of results.
See https://www.paws-r-sdk.com/docs/quicksight_list_approval_policies/ for full documentation.
quicksight_list_approval_policies(NextToken = NULL, MaxResults = NULL)
NextToken |
The token for the next set of results, or null if there are no more results. |
MaxResults |
The maximum number of results to return in a single call. If you don't specify a value, the service returns a default number of results. Use the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.