View source: R/quicksight_operations.R
| quicksight_list_apps | R Documentation |
Lists the apps in an Amazon Web Services account. Results are paginated; use the NextToken parameter to retrieve additional results.
See https://www.paws-r-sdk.com/docs/quicksight_list_apps/ for full documentation.
quicksight_list_apps(AwsAccountId, MaxResults = NULL, NextToken = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the apps. |
MaxResults |
The maximum number of results to return in a single request. Valid range is 1 to 100. If you don't specify a value, the default is 20. |
NextToken |
The token for the next set of results, or null if there are no more results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.