View source: R/quicksight_operations.R
| quicksight_list_flows | R Documentation |
Lists flows in an Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/quicksight_list_flows/ for full documentation.
quicksight_list_flows(AwsAccountId, NextToken = NULL, MaxResults = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow list that you are getting. |
NextToken |
The token to request the next set of results, or null if you want to retrieve the first set. |
MaxResults |
The maximum number of results to be returned per request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.