View source: R/quicksight_operations.R
| quicksight_list_limits_profiles | R Documentation |
Lists all limits profiles in an Amazon Quick Sight account. Results are paginated. Use the maxResults parameter to limit the number of results returned in a single call, and use the nextToken parameter to retrieve the next page of results.
See https://www.paws-r-sdk.com/docs/quicksight_list_limits_profiles/ for full documentation.
quicksight_list_limits_profiles(
accountId,
resourceType = NULL,
maxResults = NULL,
nextToken = NULL
)
accountId |
[required] The ID of the Amazon Web Services account that contains the limits profiles. |
resourceType |
An optional filter that limits the results to profiles that contain the specified resource type. If you don't specify a value, the operation returns all profiles. |
maxResults |
The maximum number of results to return in a single call. If you don't specify a value, the service uses the default maximum. |
nextToken |
The token for the next set of results, or null if there are no more results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.