View source: R/quicksight_operations.R
| quicksight_list_o_auth_client_applications | R Documentation |
Lists all OAuthClientApplications in the current Amazon Web Services Region that belong to this Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/quicksight_list_o_auth_client_applications/ for full documentation.
quicksight_list_o_auth_client_applications(
AwsAccountId,
NextToken = NULL,
MaxResults = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID. |
NextToken |
A pagination token that can be used in a subsequent request. |
MaxResults |
The maximum number of results to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.