View source: R/quicksight_operations.R
| quicksight_list_self_upgrades | R Documentation |
Lists all self-upgrade requests for a Quick account.
See https://www.paws-r-sdk.com/docs/quicksight_list_self_upgrades/ for full documentation.
quicksight_list_self_upgrades(
AwsAccountId,
Namespace,
NextToken = NULL,
MaxResults = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the self-upgrade requests. |
Namespace |
[required] The Quick namespace for the self-upgrade requests. |
NextToken |
The token for the next set of results, or null if there are no more results. |
MaxResults |
The maximum number of results to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.