View source: R/quicksight_operations.R
| quicksight_list_spaces | R Documentation |
Lists all Amazon QuickSight spaces in an Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/quicksight_list_spaces/ for full documentation.
quicksight_list_spaces(AwsAccountId, NextToken = NULL, MaxResults = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the spaces. |
NextToken |
The token for the next set of results, or null if there are no more results. |
MaxResults |
The maximum number of results to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.