View source: R/quicksight_operations.R
| quicksight_list_topics_v2 | R Documentation |
Lists all of the Q topics in the specified Amazon Web Services account in an Amazon Web Services Region.
See https://www.paws-r-sdk.com/docs/quicksight_list_topics_v2/ for full documentation.
quicksight_list_topics_v2(AwsAccountId, NextToken = NULL, MaxResults = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the topics that you want to list. |
NextToken |
The token for the next set of results, or null if there are no more results. |
MaxResults |
The maximum number of results to be returned per request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.