View source: R/quicksight_operations.R
| quicksight_search_agents | R Documentation |
Searches for agents based on specified filters.
See https://www.paws-r-sdk.com/docs/quicksight_search_agents/ for full documentation.
quicksight_search_agents(
AwsAccountId,
Filters,
MaxResults = NULL,
NextToken = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the agents. |
Filters |
[required] The filters to apply when searching agents. |
MaxResults |
The maximum number of results to return. |
NextToken |
The token for the next set of results, or null if there are no more results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.