View source: R/quicksight_operations.R
| quicksight_search_flows | R Documentation |
Search for the flows in an Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/quicksight_search_flows/ for full documentation.
quicksight_search_flows(
AwsAccountId,
Filters,
NextToken = NULL,
MaxResults = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account where you are searching for flows from. |
Filters |
[required] The filters applied to the search when searching for flows in the Amazon Web Services account. |
NextToken |
The token to request the next set of results, or null if you want to retrieve the first set. |
MaxResults |
The maximum number of results to be returned per request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.