View source: R/quicksight_operations.R
| quicksight_start_automation_job | R Documentation |
Starts a new job for a specified automation. The job runs the automation with the provided input payload.
See https://www.paws-r-sdk.com/docs/quicksight_start_automation_job/ for full documentation.
quicksight_start_automation_job(
AwsAccountId,
AutomationGroupId,
AutomationId,
InputPayload = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the automation. |
AutomationGroupId |
[required] The ID of the automation group that contains the automation to run. |
AutomationId |
[required] The ID of the automation to run. |
InputPayload |
The input payload for the automation job, provided as a JSON string. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.