View source: R/quicksight_operations.R
| quicksight_start_dashboard_snapshot_job | R Documentation |
Starts an asynchronous job that generates a snapshot of a dashboard's output. You can request one or several of the following format configurations in each API call.
See https://www.paws-r-sdk.com/docs/quicksight_start_dashboard_snapshot_job/ for full documentation.
quicksight_start_dashboard_snapshot_job(
AwsAccountId,
DashboardId,
SnapshotJobId,
UserConfiguration = NULL,
SnapshotConfiguration
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that the dashboard snapshot job is executed in. |
DashboardId |
[required] The ID of the dashboard that you want to start a snapshot job for. |
SnapshotJobId |
[required] An ID for the dashboard snapshot job. This ID is unique to the dashboard while the job is running. This ID can be used to poll the status of a job with a |
UserConfiguration |
A structure that contains information about the users that the dashboard snapshot is generated for. The users can be either anonymous users or registered users. Anonymous users cannot be used together with registered users. When using identity-enhanced session credentials, set the UserConfiguration request attribute to null. Otherwise, the request will be invalid. |
SnapshotConfiguration |
[required] A structure that describes the configuration of the dashboard snapshot. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.