View source: R/quicksight_operations.R
| quicksight_update_account_customization | R Documentation |
Updates Amazon Quick Sight customizations. Currently, the only customization that you can use is a theme.
See https://www.paws-r-sdk.com/docs/quicksight_update_account_customization/ for full documentation.
quicksight_update_account_customization(
AwsAccountId,
Namespace = NULL,
AccountCustomization
)
AwsAccountId |
[required] The ID for the Amazon Web Services account that you want to update Quick Sight customizations for. |
Namespace |
The namespace that you want to update Quick Sight customizations for. |
AccountCustomization |
[required] The Quick Sight customizations you're updating. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.