View source: R/quicksight_operations.R
| quicksight_update_app_permissions | R Documentation |
Updates the resource permissions for an app. You can grant or revoke permissions and, optionally, change the app's visibility.
See https://www.paws-r-sdk.com/docs/quicksight_update_app_permissions/ for full documentation.
quicksight_update_app_permissions(
AwsAccountId,
AppId,
GrantPermissions = NULL,
RevokePermissions = NULL,
Visibility = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the app. |
AppId |
[required] The ID of the app. |
GrantPermissions |
The permissions that you want to grant on the app. |
RevokePermissions |
The permissions that you want to revoke from the app. |
Visibility |
The visibility to set for the app. Currently, only |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.