View source: R/quicksight_operations.R
| quicksight_update_approval_policy | R Documentation |
Updates an approval policy in Quick Sight.
See https://www.paws-r-sdk.com/docs/quicksight_update_approval_policy/ for full documentation.
quicksight_update_approval_policy(
PolicyId,
Name = NULL,
Description = NULL,
Actions = NULL,
AssetTypes = NULL,
ApplicableTo = NULL,
ApprovalGroups = NULL
)
PolicyId |
[required] The unique identifier of the approval policy to update. |
Name |
The name of the approval policy. |
Description |
A description of the approval policy. |
Actions |
The list of governed actions that trigger the approval workflow. |
AssetTypes |
The list of asset types that the approval policy applies to. |
ApplicableTo |
The scoping configuration that determines who the approval policy applies to. |
ApprovalGroups |
The list of group ARNs whose members can approve requests. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.