View source: R/quicksight_operations.R
| quicksight_update_flow_permissions | R Documentation |
Updates permissions against principals on a flow.
See https://www.paws-r-sdk.com/docs/quicksight_update_flow_permissions/ for full documentation.
quicksight_update_flow_permissions(
AwsAccountId,
FlowId,
GrantPermissions = NULL,
RevokePermissions = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the flow you are updating permissions against. |
FlowId |
[required] The unique identifier of the flow to update permissions for. |
GrantPermissions |
The permissions that you want to grant on this flow. |
RevokePermissions |
The permissions that you want to revoke from this flow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.