View source: R/quicksight_operations.R
| quicksight_update_knowledge_base | R Documentation |
Updates the properties of an existing knowledge base.
See https://www.paws-r-sdk.com/docs/quicksight_update_knowledge_base/ for full documentation.
quicksight_update_knowledge_base(
AwsAccountId,
KnowledgeBaseId,
Name = NULL,
Description = NULL,
KnowledgeBaseConfiguration = NULL,
MediaExtractionConfiguration = NULL,
IsEmailNotificationOptedForIngestionFailures = NULL,
AccessControlConfiguration = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the knowledge base. |
KnowledgeBaseId |
[required] The unique identifier for the knowledge base. |
Name |
The name of the knowledge base. If you don't specify a name, the existing name is retained. |
Description |
A description for the knowledge base. If you don't specify a description, the existing description is retained. |
KnowledgeBaseConfiguration |
The configuration settings for a knowledge base. |
MediaExtractionConfiguration |
The configuration for media extraction from knowledge base documents. |
IsEmailNotificationOptedForIngestionFailures |
Specifies whether email notifications are enabled for ingestion failures. |
AccessControlConfiguration |
The access control configuration for the knowledge base. If you don't specify this parameter, the existing setting is retained. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.