View source: R/quicksight_operations.R
| quicksight_update_knowledge_base_permissions | R Documentation |
Updates the resource permissions for a knowledge base.
See https://www.paws-r-sdk.com/docs/quicksight_update_knowledge_base_permissions/ for full documentation.
quicksight_update_knowledge_base_permissions(
AwsAccountId,
KnowledgeBaseId,
GrantPermissions = NULL,
RevokePermissions = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the knowledge base. |
KnowledgeBaseId |
[required] The unique identifier for the knowledge base. |
GrantPermissions |
The resource permissions that you want to grant on the knowledge base. |
RevokePermissions |
The resource permissions that you want to revoke from the knowledge base. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.