View source: R/quicksight_operations.R
| quicksight_update_o_auth_client_application | R Documentation |
Updates an OAuthClientApplication.
See https://www.paws-r-sdk.com/docs/quicksight_update_o_auth_client_application/ for full documentation.
quicksight_update_o_auth_client_application(
AwsAccountId,
OAuthClientApplicationId,
Name,
ClientId = NULL,
ClientSecret = NULL,
OAuthTokenEndpointUrl = NULL,
OAuthAuthorizationEndpointUrl = NULL,
OAuthScopes = NULL,
DataSourceType = NULL,
IdentityProviderVpcConnectionProperties = NULL
)
AwsAccountId |
[required] The Amazon Web Services account ID. |
OAuthClientApplicationId |
[required] The ID of the OAuthClientApplication that you want to update. |
Name |
[required] The display name for the OAuthClientApplication. |
ClientId |
The client ID of the OAuth application that is registered with the identity provider. |
ClientSecret |
The client secret of the OAuth application that is registered with the identity provider. |
OAuthTokenEndpointUrl |
The token endpoint URL of the identity provider that is used to obtain access tokens. |
OAuthAuthorizationEndpointUrl |
The authorization endpoint URL of the identity provider that is used to obtain authorization codes. |
OAuthScopes |
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider. |
DataSourceType |
The type of data source that the OAuthClientApplication is used with. Valid values are |
IdentityProviderVpcConnectionProperties |
VPC connection properties. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.