View source: R/quicksight_operations.R
| quicksight_update_self_upgrade | R Documentation |
Updates a self-upgrade request for a Quick user by approving, denying, or verifying the request.
See https://www.paws-r-sdk.com/docs/quicksight_update_self_upgrade/ for full documentation.
quicksight_update_self_upgrade(
AwsAccountId,
Namespace,
UpgradeRequestId,
Action
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the self-upgrade request. |
Namespace |
[required] The Quick namespace for the self-upgrade request. |
UpgradeRequestId |
[required] The ID of the self-upgrade request to update. |
Action |
[required] The action to perform on the self-upgrade request. Valid values are |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.