View source: R/quicksight_operations.R
| quicksight_update_space | R Documentation |
Updates the metadata of an Amazon QuickSight space.
See https://www.paws-r-sdk.com/docs/quicksight_update_space/ for full documentation.
quicksight_update_space(AwsAccountId, SpaceId, Name = NULL, Description = NULL)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the space. |
SpaceId |
[required] The ID of the space that you want to update. |
Name |
A new display name for the space. |
Description |
A new description for the space. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.