View source: R/quicksight_operations.R
| quicksight_update_topic_v2 | R Documentation |
Updates the definition of a Q topic.
See https://www.paws-r-sdk.com/docs/quicksight_update_topic_v2/ for full documentation.
quicksight_update_topic_v2(
AwsAccountId,
TopicId,
Topic,
CustomInstructions = NULL,
PublishOption = NULL
)
AwsAccountId |
[required] The ID of the Amazon Web Services account that contains the topic that you want to update. |
TopicId |
[required] The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account. |
Topic |
[required] The definition of the topic that you want to update. |
CustomInstructions |
Instructions that provide additional guidance and context for response generation. |
PublishOption |
The publish option for the topic that you want to update. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.