View source: R/quicksight_operations.R
| quicksight_update_user | R Documentation |
Updates an Amazon Quick Sight user.
See https://www.paws-r-sdk.com/docs/quicksight_update_user/ for full documentation.
quicksight_update_user(
UserName,
AwsAccountId,
Namespace,
Email,
Role,
CustomPermissionsName = NULL,
UnapplyCustomPermissions = NULL,
ExternalLoginFederationProviderType = NULL,
CustomFederationProviderUrl = NULL,
ExternalLoginId = NULL
)
UserName |
[required] The Amazon Quick Sight user name that you want to update. |
AwsAccountId |
[required] The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account. |
Namespace |
[required] The namespace. Currently, you should set this to |
Email |
[required] The email address of the user that you want to update. |
Role |
[required] The Amazon Quick Sight role of the user. The role can be one of the following default security cohorts:
The name of the Quick Sight role is invisible to the user except for the console screens dealing with permissions. |
CustomPermissionsName |
(Enterprise edition only) The name of the custom permissions profile that you want to assign to this user. Customized permissions allows you to control a user's access by restricting access the following operations:
A set of custom permissions includes any combination of these restrictions. Currently, you need to create the profile names for custom permission sets by using the Quick Sight console. Then, you use the Quick Sight custom permissions are applied through IAM policies. Therefore, they override the permissions typically granted by assigning Quick Sight users to one of the default security cohorts in Quick Sight (admin, author, reader). This feature is available only to Quick Sight Enterprise edition subscriptions. |
UnapplyCustomPermissions |
A flag that you use to indicate that you want to remove all custom permissions from this user. Using this parameter resets the user to the state it was in before a custom permissions profile was applied. This parameter defaults to NULL and it doesn't accept any other value. |
ExternalLoginFederationProviderType |
The type of supported external login provider that provides identity to let a user federate into Quick Sight with an associated Identity and Access Management(IAM) role. The type of supported external login provider can be one of the following.
|
CustomFederationProviderUrl |
The URL of the custom OpenID Connect (OIDC) provider that provides identity to let a user federate into Quick Sight with an associated Identity and Access Management(IAM) role. This parameter should only be used when |
ExternalLoginId |
The identity ID for a user in the external login provider. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.